import { type Admin } from '../models/admin';
import { EdgeRequestBuilder } from './edge/edgeRequestBuilder';
import { PeopleRequestBuilder } from './people/peopleRequestBuilder';
import { ServiceAnnouncementRequestBuilder } from './serviceAnnouncement/serviceAnnouncementRequestBuilder';
import { SharepointRequestBuilder } from './sharepoint/sharepointRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AdminRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AdminRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AdminRequestBuilderGetQueryParameters;
}
export interface AdminRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the admin singleton.
 */
export declare class AdminRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the edge property of the microsoft.graph.admin entity.
     */
    get edge(): EdgeRequestBuilder;
    /**
     * Provides operations to manage the people property of the microsoft.graph.admin entity.
     */
    get people(): PeopleRequestBuilder;
    /**
     * Provides operations to manage the serviceAnnouncement property of the microsoft.graph.admin entity.
     */
    get serviceAnnouncement(): ServiceAnnouncementRequestBuilder;
    /**
     * Provides operations to manage the sharepoint property of the microsoft.graph.admin entity.
     */
    get sharepoint(): SharepointRequestBuilder;
    /**
     * Instantiates a new AdminRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Admin
     */
    get(requestConfiguration?: AdminRequestBuilderGetRequestConfiguration | undefined): Promise<Admin | undefined>;
    /**
     * Update admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Admin
     */
    patch(body: Admin, requestConfiguration?: AdminRequestBuilderPatchRequestConfiguration | undefined): Promise<Admin | undefined>;
    /**
     * Get admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AdminRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Admin, requestConfiguration?: AdminRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a adminRequestBuilder
     */
    withUrl(rawUrl: string): AdminRequestBuilder;
}
