import { type InternetExplorerMode } from '../../../models/internetExplorerMode';
import { SiteListsRequestBuilder } from './siteLists/siteListsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface InternetExplorerModeRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface InternetExplorerModeRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface InternetExplorerModeRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: InternetExplorerModeRequestBuilderGetQueryParameters;
}
export interface InternetExplorerModeRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the internetExplorerMode property of the microsoft.graph.edge entity.
 */
export declare class InternetExplorerModeRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the siteLists property of the microsoft.graph.internetExplorerMode entity.
     */
    get siteLists(): SiteListsRequestBuilder;
    /**
     * Instantiates a new InternetExplorerModeRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property internetExplorerMode for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: InternetExplorerModeRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * A container for Internet Explorer mode resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternetExplorerMode
     */
    get(requestConfiguration?: InternetExplorerModeRequestBuilderGetRequestConfiguration | undefined): Promise<InternetExplorerMode | undefined>;
    /**
     * Update the navigation property internetExplorerMode in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternetExplorerMode
     */
    patch(body: InternetExplorerMode, requestConfiguration?: InternetExplorerModeRequestBuilderPatchRequestConfiguration | undefined): Promise<InternetExplorerMode | undefined>;
    /**
     * Delete navigation property internetExplorerMode for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: InternetExplorerModeRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * A container for Internet Explorer mode resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: InternetExplorerModeRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property internetExplorerMode in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: InternetExplorerMode, requestConfiguration?: InternetExplorerModeRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a internetExplorerModeRequestBuilder
     */
    withUrl(rawUrl: string): InternetExplorerModeRequestBuilder;
}
