import { type BrowserSiteListCollectionResponse } from '../../../../models/';
import { type BrowserSiteList } from '../../../../models/browserSiteList';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { BrowserSiteListItemRequestBuilder } from './item/browserSiteListItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SiteListsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface SiteListsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SiteListsRequestBuilderGetQueryParameters;
}
export interface SiteListsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the siteLists property of the microsoft.graph.internetExplorerMode entity.
 */
export declare class SiteListsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the siteLists property of the microsoft.graph.internetExplorerMode entity.
     * @param browserSiteListId The unique identifier of browserSiteList
     * @returns a BrowserSiteListItemRequestBuilder
     */
    byBrowserSiteListId(browserSiteListId: string): BrowserSiteListItemRequestBuilder;
    /**
     * Instantiates a new SiteListsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the browserSiteList objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSiteListCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/internetexplorermode-list-sitelists?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SiteListsRequestBuilderGetRequestConfiguration | undefined): Promise<BrowserSiteListCollectionResponse | undefined>;
    /**
     * Create a new browserSiteList object to support Internet Explorer mode. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSiteList
     * @see {@link https://learn.microsoft.com/graph/api/internetexplorermode-post-sitelists?view=graph-rest-1.0|Find more info here}
     */
    post(body: BrowserSiteList, requestConfiguration?: SiteListsRequestBuilderPostRequestConfiguration | undefined): Promise<BrowserSiteList | undefined>;
    /**
     * Get a list of the browserSiteList objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SiteListsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new browserSiteList object to support Internet Explorer mode. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: BrowserSiteList, requestConfiguration?: SiteListsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a siteListsRequestBuilder
     */
    withUrl(rawUrl: string): SiteListsRequestBuilder;
}
