import { type PeopleAdminSettings } from '../../models/peopleAdminSettings';
import { ProfileCardPropertiesRequestBuilder } from './profileCardProperties/profileCardPropertiesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PeopleRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PeopleRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PeopleRequestBuilderGetQueryParameters;
}
export interface PeopleRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the people property of the microsoft.graph.admin entity.
 */
export declare class PeopleRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the profileCardProperties property of the microsoft.graph.peopleAdminSettings entity.
     */
    get profileCardProperties(): ProfileCardPropertiesRequestBuilder;
    /**
     * Instantiates a new PeopleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get people from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PeopleAdminSettings
     */
    get(requestConfiguration?: PeopleRequestBuilderGetRequestConfiguration | undefined): Promise<PeopleAdminSettings | undefined>;
    /**
     * Update the navigation property people in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PeopleAdminSettings
     */
    patch(body: PeopleAdminSettings, requestConfiguration?: PeopleRequestBuilderPatchRequestConfiguration | undefined): Promise<PeopleAdminSettings | undefined>;
    /**
     * Get people from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PeopleRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property people in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PeopleAdminSettings, requestConfiguration?: PeopleRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a peopleRequestBuilder
     */
    withUrl(rawUrl: string): PeopleRequestBuilder;
}
