import { type ProfileCardPropertyCollectionResponse } from '../../../models/';
import { type ProfileCardProperty } from '../../../models/profileCardProperty';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ProfileCardPropertyItemRequestBuilder } from './item/profileCardPropertyItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ProfileCardPropertiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ProfileCardPropertiesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ProfileCardPropertiesRequestBuilderGetQueryParameters;
}
export interface ProfileCardPropertiesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the profileCardProperties property of the microsoft.graph.peopleAdminSettings entity.
 */
export declare class ProfileCardPropertiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the profileCardProperties property of the microsoft.graph.peopleAdminSettings entity.
     * @param profileCardPropertyId The unique identifier of profileCardProperty
     * @returns a ProfileCardPropertyItemRequestBuilder
     */
    byProfileCardPropertyId(profileCardPropertyId: string): ProfileCardPropertyItemRequestBuilder;
    /**
     * Instantiates a new ProfileCardPropertiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get profileCardProperties from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProfileCardPropertyCollectionResponse
     */
    get(requestConfiguration?: ProfileCardPropertiesRequestBuilderGetRequestConfiguration | undefined): Promise<ProfileCardPropertyCollectionResponse | undefined>;
    /**
     * Create new navigation property to profileCardProperties for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProfileCardProperty
     */
    post(body: ProfileCardProperty, requestConfiguration?: ProfileCardPropertiesRequestBuilderPostRequestConfiguration | undefined): Promise<ProfileCardProperty | undefined>;
    /**
     * Get profileCardProperties from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ProfileCardPropertiesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to profileCardProperties for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ProfileCardProperty, requestConfiguration?: ProfileCardPropertiesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a profileCardPropertiesRequestBuilder
     */
    withUrl(rawUrl: string): ProfileCardPropertiesRequestBuilder;
}
