import { type FavoritePostRequestBody } from './favoritePostRequestBody';
import { type FavoritePostResponse } from './favoritePostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface FavoriteRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the favorite method.
 */
export declare class FavoriteRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new FavoriteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Change the status of a list of serviceUpdateMessages to favorite for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FavoritePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-favorite?view=graph-rest-1.0|Find more info here}
     */
    post(body: FavoritePostRequestBody, requestConfiguration?: FavoriteRequestBuilderPostRequestConfiguration | undefined): Promise<FavoritePostResponse | undefined>;
    /**
     * Change the status of a list of serviceUpdateMessages to favorite for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: FavoritePostRequestBody, requestConfiguration?: FavoriteRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a favoriteRequestBuilder
     */
    withUrl(rawUrl: string): FavoriteRequestBuilder;
}
