import { type MarkReadPostRequestBody } from './markReadPostRequestBody';
import { type MarkReadPostResponse } from './markReadPostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface MarkReadRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the markRead method.
 */
export declare class MarkReadRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new MarkReadRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Mark a list of serviceUpdateMessages as read for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MarkReadPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-markread?view=graph-rest-1.0|Find more info here}
     */
    post(body: MarkReadPostRequestBody, requestConfiguration?: MarkReadRequestBuilderPostRequestConfiguration | undefined): Promise<MarkReadPostResponse | undefined>;
    /**
     * Mark a list of serviceUpdateMessages as read for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MarkReadPostRequestBody, requestConfiguration?: MarkReadRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a markReadRequestBuilder
     */
    withUrl(rawUrl: string): MarkReadRequestBuilder;
}
