import { type MarkUnreadPostRequestBody } from './markUnreadPostRequestBody';
import { type MarkUnreadPostResponse } from './markUnreadPostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface MarkUnreadRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the markUnread method.
 */
export declare class MarkUnreadRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new MarkUnreadRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Mark a list of serviceUpdateMessages as unread for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MarkUnreadPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-markunread?view=graph-rest-1.0|Find more info here}
     */
    post(body: MarkUnreadPostRequestBody, requestConfiguration?: MarkUnreadRequestBuilderPostRequestConfiguration | undefined): Promise<MarkUnreadPostResponse | undefined>;
    /**
     * Mark a list of serviceUpdateMessages as unread for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MarkUnreadPostRequestBody, requestConfiguration?: MarkUnreadRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a markUnreadRequestBuilder
     */
    withUrl(rawUrl: string): MarkUnreadRequestBuilder;
}
