"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessagesRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const serviceUpdateMessage_1 = require("../../../models/serviceUpdateMessage");
const serviceUpdateMessageCollectionResponse_1 = require("../../../models/serviceUpdateMessageCollectionResponse");
const archiveRequestBuilder_1 = require("./archive/archiveRequestBuilder");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const favoriteRequestBuilder_1 = require("./favorite/favoriteRequestBuilder");
const serviceUpdateMessageItemRequestBuilder_1 = require("./item/serviceUpdateMessageItemRequestBuilder");
const markReadRequestBuilder_1 = require("./markRead/markReadRequestBuilder");
const markUnreadRequestBuilder_1 = require("./markUnread/markUnreadRequestBuilder");
const unarchiveRequestBuilder_1 = require("./unarchive/unarchiveRequestBuilder");
const unfavoriteRequestBuilder_1 = require("./unfavorite/unfavoriteRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.
 */
class MessagesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the archive method.
     */
    get archive() {
        return new archiveRequestBuilder_1.ArchiveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the favorite method.
     */
    get favorite() {
        return new favoriteRequestBuilder_1.FavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the markRead method.
     */
    get markRead() {
        return new markReadRequestBuilder_1.MarkReadRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the markUnread method.
     */
    get markUnread() {
        return new markUnreadRequestBuilder_1.MarkUnreadRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the unarchive method.
     */
    get unarchive() {
        return new unarchiveRequestBuilder_1.UnarchiveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the unfavorite method.
     */
    get unfavorite() {
        return new unfavoriteRequestBuilder_1.UnfavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.
     * @param serviceUpdateMessageId The unique identifier of serviceUpdateMessage
     * @returns a ServiceUpdateMessageItemRequestBuilder
     */
    byServiceUpdateMessageId(serviceUpdateMessageId) {
        if (!serviceUpdateMessageId)
            throw new Error("serviceUpdateMessageId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["serviceUpdateMessage%2Did"] = serviceUpdateMessageId;
        return new serviceUpdateMessageItemRequestBuilder_1.ServiceUpdateMessageItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new MessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Retrieve the serviceUpdateMessage resources from the messages navigation property. This operation retrieves all service update messages that exist for the tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceUpdateMessageCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceannouncement-list-messages?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, serviceUpdateMessageCollectionResponse_1.createServiceUpdateMessageCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to messages for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceUpdateMessage
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, serviceUpdateMessage_1.createServiceUpdateMessageFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve the serviceUpdateMessage resources from the messages navigation property. This operation retrieves all service update messages that exist for the tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to messages for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serviceUpdateMessage_1.serializeServiceUpdateMessage);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a messagesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new MessagesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.MessagesRequestBuilder = MessagesRequestBuilder;
// tslint:enable
// eslint-enable
