import { type UnarchivePostRequestBody } from './unarchivePostRequestBody';
import { type UnarchivePostResponse } from './unarchivePostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface UnarchiveRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the unarchive method.
 */
export declare class UnarchiveRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new UnarchiveRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Unarchive a list of serviceUpdateMessages for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnarchivePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-unarchive?view=graph-rest-1.0|Find more info here}
     */
    post(body: UnarchivePostRequestBody, requestConfiguration?: UnarchiveRequestBuilderPostRequestConfiguration | undefined): Promise<UnarchivePostResponse | undefined>;
    /**
     * Unarchive a list of serviceUpdateMessages for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UnarchivePostRequestBody, requestConfiguration?: UnarchiveRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unarchiveRequestBuilder
     */
    withUrl(rawUrl: string): UnarchiveRequestBuilder;
}
