import { type UnfavoritePostRequestBody } from './unfavoritePostRequestBody';
import { type UnfavoritePostResponse } from './unfavoritePostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface UnfavoriteRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the unfavorite method.
 */
export declare class UnfavoriteRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new UnfavoriteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Remove the favorite status of serviceUpdateMessages for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnfavoritePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-unfavorite?view=graph-rest-1.0|Find more info here}
     */
    post(body: UnfavoritePostRequestBody, requestConfiguration?: UnfavoriteRequestBuilderPostRequestConfiguration | undefined): Promise<UnfavoritePostResponse | undefined>;
    /**
     * Remove the favorite status of serviceUpdateMessages for the signed in user. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UnfavoritePostRequestBody, requestConfiguration?: UnfavoriteRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unfavoriteRequestBuilder
     */
    withUrl(rawUrl: string): UnfavoriteRequestBuilder;
}
