import { type Sharepoint } from '../../models/sharepoint';
import { SettingsRequestBuilder } from './settings/settingsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SharepointRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SharepointRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SharepointRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SharepointRequestBuilderGetQueryParameters;
}
export interface SharepointRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the sharepoint property of the microsoft.graph.admin entity.
 */
export declare class SharepointRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the settings property of the microsoft.graph.sharepoint entity.
     */
    get settings(): SettingsRequestBuilder;
    /**
     * Instantiates a new SharepointRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property sharepoint for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SharepointRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get sharepoint from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Sharepoint
     */
    get(requestConfiguration?: SharepointRequestBuilderGetRequestConfiguration | undefined): Promise<Sharepoint | undefined>;
    /**
     * Update the navigation property sharepoint in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Sharepoint
     */
    patch(body: Sharepoint, requestConfiguration?: SharepointRequestBuilderPatchRequestConfiguration | undefined): Promise<Sharepoint | undefined>;
    /**
     * Delete navigation property sharepoint for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SharepointRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get sharepoint from admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SharepointRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property sharepoint in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Sharepoint, requestConfiguration?: SharepointRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sharepointRequestBuilder
     */
    withUrl(rawUrl: string): SharepointRequestBuilder;
}
