import { type TeamworkBot } from '../../../../../../models/teamworkBot';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface BotRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface BotRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface BotRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: BotRequestBuilderGetQueryParameters;
}
export interface BotRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the bot property of the microsoft.graph.teamsAppDefinition entity.
 */
export declare class BotRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new BotRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property bot for appCatalogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: BotRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the bot associated with a specific definition of the  TeamsApp. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkBot
     * @see {@link https://learn.microsoft.com/graph/api/teamworkbot-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: BotRequestBuilderGetRequestConfiguration | undefined): Promise<TeamworkBot | undefined>;
    /**
     * Update the navigation property bot in appCatalogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkBot
     */
    patch(body: TeamworkBot, requestConfiguration?: BotRequestBuilderPatchRequestConfiguration | undefined): Promise<TeamworkBot | undefined>;
    /**
     * Delete navigation property bot for appCatalogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: BotRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the bot associated with a specific definition of the  TeamsApp. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: BotRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property bot in appCatalogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: TeamworkBot, requestConfiguration?: BotRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a botRequestBuilder
     */
    withUrl(rawUrl: string): BotRequestBuilder;
}
