import { type ApplicationTemplateCollectionResponse } from '../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ApplicationTemplateItemRequestBuilder } from './item/applicationTemplateItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ApplicationTemplatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ApplicationTemplatesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ApplicationTemplatesRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the collection of applicationTemplate entities.
 */
export declare class ApplicationTemplatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of applicationTemplate entities.
     * @param applicationTemplateId The unique identifier of applicationTemplate
     * @returns a ApplicationTemplateItemRequestBuilder
     */
    byApplicationTemplateId(applicationTemplateId: string): ApplicationTemplateItemRequestBuilder;
    /**
     * Instantiates a new ApplicationTemplatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of applicationTemplate objects from the Microsoft Entra application gallery. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ApplicationTemplateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/applicationtemplate-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ApplicationTemplatesRequestBuilderGetRequestConfiguration | undefined): Promise<ApplicationTemplateCollectionResponse | undefined>;
    /**
     * Retrieve a list of applicationTemplate objects from the Microsoft Entra application gallery. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ApplicationTemplatesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a applicationTemplatesRequestBuilder
     */
    withUrl(rawUrl: string): ApplicationTemplatesRequestBuilder;
}
