"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationTemplateItemRequestBuilder = void 0;
const applicationTemplate_1 = require("../../models/applicationTemplate");
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const instantiateRequestBuilder_1 = require("./instantiate/instantiateRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the collection of applicationTemplate entities.
 */
class ApplicationTemplateItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the instantiate method.
     */
    get instantiate() {
        return new instantiateRequestBuilder_1.InstantiateRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new ApplicationTemplateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/applicationTemplates/{applicationTemplate%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Retrieve the properties of an applicationTemplate object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ApplicationTemplate
     * @see {@link https://learn.microsoft.com/graph/api/applicationtemplate-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, applicationTemplate_1.createApplicationTemplateFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve the properties of an applicationTemplate object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ApplicationTemplateItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ApplicationTemplateItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ApplicationTemplateItemRequestBuilder = ApplicationTemplateItemRequestBuilder;
// tslint:enable
// eslint-enable
