import { type PasswordCredential } from '../../../models/passwordCredential';
import { type AddPasswordPostRequestBody } from './addPasswordPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AddPasswordRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the addPassword method.
 */
export declare class AddPasswordRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AddPasswordRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Adds a strong password or secret to an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PasswordCredential
     * @see {@link https://learn.microsoft.com/graph/api/application-addpassword?view=graph-rest-1.0|Find more info here}
     */
    post(body: AddPasswordPostRequestBody, requestConfiguration?: AddPasswordRequestBuilderPostRequestConfiguration | undefined): Promise<PasswordCredential | undefined>;
    /**
     * Adds a strong password or secret to an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AddPasswordPostRequestBody, requestConfiguration?: AddPasswordRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addPasswordRequestBuilder
     */
    withUrl(rawUrl: string): AddPasswordRequestBuilder;
}
