import { type DirectoryDefinition } from '../../../../../../../../models/directoryDefinition';
import { DiscoverRequestBuilder } from './discover/discoverRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DirectoryDefinitionItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface DirectoryDefinitionItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DirectoryDefinitionItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DirectoryDefinitionItemRequestBuilderGetQueryParameters;
}
export interface DirectoryDefinitionItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the directories property of the microsoft.graph.synchronizationSchema entity.
 */
export declare class DirectoryDefinitionItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the discover method.
     */
    get discover(): DiscoverRequestBuilder;
    /**
     * Instantiates a new DirectoryDefinitionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property directories for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: DirectoryDefinitionItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Contains the collection of directories and all of their objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryDefinition
     */
    get(requestConfiguration?: DirectoryDefinitionItemRequestBuilderGetRequestConfiguration | undefined): Promise<DirectoryDefinition | undefined>;
    /**
     * Update the navigation property directories in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryDefinition
     */
    patch(body: DirectoryDefinition, requestConfiguration?: DirectoryDefinitionItemRequestBuilderPatchRequestConfiguration | undefined): Promise<DirectoryDefinition | undefined>;
    /**
     * Delete navigation property directories for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: DirectoryDefinitionItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Contains the collection of directories and all of their objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DirectoryDefinitionItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property directories in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DirectoryDefinition, requestConfiguration?: DirectoryDefinitionItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DirectoryDefinitionItemRequestBuilder
     */
    withUrl(rawUrl: string): DirectoryDefinitionItemRequestBuilder;
}
