import { type SynchronizationJob } from '../../../../../models/synchronizationJob';
import { PauseRequestBuilder } from './pause/pauseRequestBuilder';
import { ProvisionOnDemandRequestBuilder } from './provisionOnDemand/provisionOnDemandRequestBuilder';
import { RestartRequestBuilder } from './restart/restartRequestBuilder';
import { SchemaRequestBuilder } from './schema/schemaRequestBuilder';
import { StartRequestBuilder } from './start/startRequestBuilder';
import { ValidateCredentialsRequestBuilder } from './validateCredentials/validateCredentialsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SynchronizationJobItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SynchronizationJobItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SynchronizationJobItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SynchronizationJobItemRequestBuilderGetQueryParameters;
}
export interface SynchronizationJobItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the jobs property of the microsoft.graph.synchronization entity.
 */
export declare class SynchronizationJobItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the pause method.
     */
    get pause(): PauseRequestBuilder;
    /**
     * Provides operations to call the provisionOnDemand method.
     */
    get provisionOnDemand(): ProvisionOnDemandRequestBuilder;
    /**
     * Provides operations to call the restart method.
     */
    get restart(): RestartRequestBuilder;
    /**
     * Provides operations to manage the schema property of the microsoft.graph.synchronizationJob entity.
     */
    get schema(): SchemaRequestBuilder;
    /**
     * Provides operations to call the start method.
     */
    get start(): StartRequestBuilder;
    /**
     * Provides operations to call the validateCredentials method.
     */
    get validateCredentials(): ValidateCredentialsRequestBuilder;
    /**
     * Instantiates a new SynchronizationJobItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Stop the synchronization job, and permanently delete all the state associated with it. Synchronized accounts are left as-is. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationjob-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: SynchronizationJobItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the existing synchronization job and its properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationJob
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationjob-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SynchronizationJobItemRequestBuilderGetRequestConfiguration | undefined): Promise<SynchronizationJob | undefined>;
    /**
     * Update the navigation property jobs in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationJob
     */
    patch(body: SynchronizationJob, requestConfiguration?: SynchronizationJobItemRequestBuilderPatchRequestConfiguration | undefined): Promise<SynchronizationJob | undefined>;
    /**
     * Stop the synchronization job, and permanently delete all the state associated with it. Synchronized accounts are left as-is. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SynchronizationJobItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the existing synchronization job and its properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SynchronizationJobItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property jobs in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SynchronizationJob, requestConfiguration?: SynchronizationJobItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SynchronizationJobItemRequestBuilder
     */
    withUrl(rawUrl: string): SynchronizationJobItemRequestBuilder;
}
