import { type SynchronizationTemplate } from '../../../../../models/synchronizationTemplate';
import { SchemaRequestBuilder } from './schema/schemaRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SynchronizationTemplateItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SynchronizationTemplateItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SynchronizationTemplateItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SynchronizationTemplateItemRequestBuilderGetQueryParameters;
}
export interface SynchronizationTemplateItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the templates property of the microsoft.graph.synchronization entity.
 */
export declare class SynchronizationTemplateItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the schema property of the microsoft.graph.synchronizationTemplate entity.
     */
    get schema(): SchemaRequestBuilder;
    /**
     * Instantiates a new SynchronizationTemplateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property templates for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SynchronizationTemplateItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Preconfigured synchronization settings for a particular application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationTemplate
     */
    get(requestConfiguration?: SynchronizationTemplateItemRequestBuilderGetRequestConfiguration | undefined): Promise<SynchronizationTemplate | undefined>;
    /**
     * Update (override) the synchronization template associated with a given application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationTemplate
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationtemplate-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: SynchronizationTemplate, requestConfiguration?: SynchronizationTemplateItemRequestBuilderPatchRequestConfiguration | undefined): Promise<SynchronizationTemplate | undefined>;
    /**
     * Delete navigation property templates for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SynchronizationTemplateItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Preconfigured synchronization settings for a particular application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SynchronizationTemplateItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update (override) the synchronization template associated with a given application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SynchronizationTemplate, requestConfiguration?: SynchronizationTemplateItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SynchronizationTemplateItemRequestBuilder
     */
    withUrl(rawUrl: string): SynchronizationTemplateItemRequestBuilder;
}
