import { type AuditLogRoot } from '../models/auditLogRoot';
import { DirectoryAuditsRequestBuilder } from './directoryAudits/directoryAuditsRequestBuilder';
import { ProvisioningRequestBuilder } from './provisioning/provisioningRequestBuilder';
import { SignInsRequestBuilder } from './signIns/signInsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AuditLogsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AuditLogsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AuditLogsRequestBuilderGetQueryParameters;
}
export interface AuditLogsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the auditLogRoot singleton.
 */
export declare class AuditLogsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the directoryAudits property of the microsoft.graph.auditLogRoot entity.
     */
    get directoryAudits(): DirectoryAuditsRequestBuilder;
    /**
     * Provides operations to manage the provisioning property of the microsoft.graph.auditLogRoot entity.
     */
    get provisioning(): ProvisioningRequestBuilder;
    /**
     * Provides operations to manage the signIns property of the microsoft.graph.auditLogRoot entity.
     */
    get signIns(): SignInsRequestBuilder;
    /**
     * Instantiates a new AuditLogsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get auditLogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuditLogRoot
     */
    get(requestConfiguration?: AuditLogsRequestBuilderGetRequestConfiguration | undefined): Promise<AuditLogRoot | undefined>;
    /**
     * Update auditLogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuditLogRoot
     */
    patch(body: AuditLogRoot, requestConfiguration?: AuditLogsRequestBuilderPatchRequestConfiguration | undefined): Promise<AuditLogRoot | undefined>;
    /**
     * Get auditLogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AuditLogsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update auditLogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AuditLogRoot, requestConfiguration?: AuditLogsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a auditLogsRequestBuilder
     */
    withUrl(rawUrl: string): AuditLogsRequestBuilder;
}
