import { type ChatMessage } from '../../../../../../models/chatMessage';
import { HostedContentsRequestBuilder } from './hostedContents/hostedContentsRequestBuilder';
import { SetReactionRequestBuilder } from './setReaction/setReactionRequestBuilder';
import { SoftDeleteRequestBuilder } from './softDelete/softDeleteRequestBuilder';
import { UndoSoftDeleteRequestBuilder } from './undoSoftDelete/undoSoftDeleteRequestBuilder';
import { UnsetReactionRequestBuilder } from './unsetReaction/unsetReactionRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ChatMessageItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ChatMessageItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ChatMessageItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ChatMessageItemRequestBuilderGetQueryParameters;
}
export interface ChatMessageItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the replies property of the microsoft.graph.chatMessage entity.
 */
export declare class ChatMessageItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the hostedContents property of the microsoft.graph.chatMessage entity.
     */
    get hostedContents(): HostedContentsRequestBuilder;
    /**
     * Provides operations to call the setReaction method.
     */
    get setReaction(): SetReactionRequestBuilder;
    /**
     * Provides operations to call the softDelete method.
     */
    get softDelete(): SoftDeleteRequestBuilder;
    /**
     * Provides operations to call the undoSoftDelete method.
     */
    get undoSoftDelete(): UndoSoftDeleteRequestBuilder;
    /**
     * Provides operations to call the unsetReaction method.
     */
    get unsetReaction(): UnsetReactionRequestBuilder;
    /**
     * Instantiates a new ChatMessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property replies for chats
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ChatMessageItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve a single message or a message reply in a channel or a chat. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessage
     * @see {@link https://learn.microsoft.com/graph/api/chatmessage-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ChatMessageItemRequestBuilderGetRequestConfiguration | undefined): Promise<ChatMessage | undefined>;
    /**
     * Update the navigation property replies in chats
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessage
     */
    patch(body: ChatMessage, requestConfiguration?: ChatMessageItemRequestBuilderPatchRequestConfiguration | undefined): Promise<ChatMessage | undefined>;
    /**
     * Delete navigation property replies for chats
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ChatMessageItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a single message or a message reply in a channel or a chat. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ChatMessageItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property replies in chats
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ChatMessage, requestConfiguration?: ChatMessageItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ChatMessageItemRequestBuilder
     */
    withUrl(rawUrl: string): ChatMessageItemRequestBuilder;
}
