import { type AddLargeGalleryViewOperation } from '../../../../models/addLargeGalleryViewOperation';
import { type AddLargeGalleryViewPostRequestBody } from './addLargeGalleryViewPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AddLargeGalleryViewRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the addLargeGalleryView method.
 */
export declare class AddLargeGalleryViewRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AddLargeGalleryViewRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Add the large gallery view to a call.  For details about how to identify a large gallery view participant in a roster so that you can retrieve the relevant data to subscribe to the video feed, see Identify large gallery view participants in a roster. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AddLargeGalleryViewOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-addlargegalleryview?view=graph-rest-1.0|Find more info here}
     */
    post(body: AddLargeGalleryViewPostRequestBody, requestConfiguration?: AddLargeGalleryViewRequestBuilderPostRequestConfiguration | undefined): Promise<AddLargeGalleryViewOperation | undefined>;
    /**
     * Add the large gallery view to a call.  For details about how to identify a large gallery view participant in a roster so that you can retrieve the relevant data to subscribe to the video feed, see Identify large gallery view participants in a roster. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AddLargeGalleryViewPostRequestBody, requestConfiguration?: AddLargeGalleryViewRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addLargeGalleryViewRequestBuilder
     */
    withUrl(rawUrl: string): AddLargeGalleryViewRequestBuilder;
}
