import { type Call } from '../../../models/call';
import { AddLargeGalleryViewRequestBuilder } from './addLargeGalleryView/addLargeGalleryViewRequestBuilder';
import { AnswerRequestBuilder } from './answer/answerRequestBuilder';
import { AudioRoutingGroupsRequestBuilder } from './audioRoutingGroups/audioRoutingGroupsRequestBuilder';
import { CancelMediaProcessingRequestBuilder } from './cancelMediaProcessing/cancelMediaProcessingRequestBuilder';
import { ChangeScreenSharingRoleRequestBuilder } from './changeScreenSharingRole/changeScreenSharingRoleRequestBuilder';
import { ContentSharingSessionsRequestBuilder } from './contentSharingSessions/contentSharingSessionsRequestBuilder';
import { KeepAliveRequestBuilder } from './keepAlive/keepAliveRequestBuilder';
import { MuteRequestBuilder } from './mute/muteRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { ParticipantsRequestBuilder } from './participants/participantsRequestBuilder';
import { PlayPromptRequestBuilder } from './playPrompt/playPromptRequestBuilder';
import { RecordResponseRequestBuilder } from './recordResponse/recordResponseRequestBuilder';
import { RedirectRequestBuilder } from './redirect/redirectRequestBuilder';
import { RejectRequestBuilder } from './reject/rejectRequestBuilder';
import { SubscribeToToneRequestBuilder } from './subscribeToTone/subscribeToToneRequestBuilder';
import { TransferRequestBuilder } from './transfer/transferRequestBuilder';
import { UnmuteRequestBuilder } from './unmute/unmuteRequestBuilder';
import { UpdateRecordingStatusRequestBuilder } from './updateRecordingStatus/updateRecordingStatusRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface CallItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface CallItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface CallItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: CallItemRequestBuilderGetQueryParameters;
}
export interface CallItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
 */
export declare class CallItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the addLargeGalleryView method.
     */
    get addLargeGalleryView(): AddLargeGalleryViewRequestBuilder;
    /**
     * Provides operations to call the answer method.
     */
    get answer(): AnswerRequestBuilder;
    /**
     * Provides operations to manage the audioRoutingGroups property of the microsoft.graph.call entity.
     */
    get audioRoutingGroups(): AudioRoutingGroupsRequestBuilder;
    /**
     * Provides operations to call the cancelMediaProcessing method.
     */
    get cancelMediaProcessing(): CancelMediaProcessingRequestBuilder;
    /**
     * Provides operations to call the changeScreenSharingRole method.
     */
    get changeScreenSharingRole(): ChangeScreenSharingRoleRequestBuilder;
    /**
     * Provides operations to manage the contentSharingSessions property of the microsoft.graph.call entity.
     */
    get contentSharingSessions(): ContentSharingSessionsRequestBuilder;
    /**
     * Provides operations to call the keepAlive method.
     */
    get keepAlive(): KeepAliveRequestBuilder;
    /**
     * Provides operations to call the mute method.
     */
    get mute(): MuteRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.call entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the participants property of the microsoft.graph.call entity.
     */
    get participants(): ParticipantsRequestBuilder;
    /**
     * Provides operations to call the playPrompt method.
     */
    get playPrompt(): PlayPromptRequestBuilder;
    /**
     * Provides operations to call the recordResponse method.
     */
    get recordResponse(): RecordResponseRequestBuilder;
    /**
     * Provides operations to call the redirect method.
     */
    get redirect(): RedirectRequestBuilder;
    /**
     * Provides operations to call the reject method.
     */
    get reject(): RejectRequestBuilder;
    /**
     * Provides operations to call the subscribeToTone method.
     */
    get subscribeToTone(): SubscribeToToneRequestBuilder;
    /**
     * Provides operations to call the transfer method.
     */
    get transfer(): TransferRequestBuilder;
    /**
     * Provides operations to call the unmute method.
     */
    get unmute(): UnmuteRequestBuilder;
    /**
     * Provides operations to call the updateRecordingStatus method.
     */
    get updateRecordingStatus(): UpdateRecordingStatusRequestBuilder;
    /**
     * Instantiates a new CallItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete or hang up an active call. For group calls, this will only delete your call leg and the underlying group call will still continue. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: CallItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a call object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Call
     * @see {@link https://learn.microsoft.com/graph/api/call-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: CallItemRequestBuilderGetRequestConfiguration | undefined): Promise<Call | undefined>;
    /**
     * Update the navigation property calls in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Call
     */
    patch(body: Call, requestConfiguration?: CallItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Call | undefined>;
    /**
     * Delete or hang up an active call. For group calls, this will only delete your call leg and the underlying group call will still continue. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: CallItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a call object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: CallItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property calls in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Call, requestConfiguration?: CallItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a CallItemRequestBuilder
     */
    withUrl(rawUrl: string): CallItemRequestBuilder;
}
