import { type PlayPromptOperation } from '../../../../models/playPromptOperation';
import { type PlayPromptPostRequestBody } from './playPromptPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PlayPromptRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the playPrompt method.
 */
export declare class PlayPromptRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PlayPromptRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Play a prompt in the call. For more information about how to handle operations, see commsOperation This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlayPromptOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-playprompt?view=graph-rest-1.0|Find more info here}
     */
    post(body: PlayPromptPostRequestBody, requestConfiguration?: PlayPromptRequestBuilderPostRequestConfiguration | undefined): Promise<PlayPromptOperation | undefined>;
    /**
     * Play a prompt in the call. For more information about how to handle operations, see commsOperation This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PlayPromptPostRequestBody, requestConfiguration?: PlayPromptRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a playPromptRequestBuilder
     */
    withUrl(rawUrl: string): PlayPromptRequestBuilder;
}
