import { type Presence } from '../../../models/presence';
import { ClearPresenceRequestBuilder } from './clearPresence/clearPresenceRequestBuilder';
import { ClearUserPreferredPresenceRequestBuilder } from './clearUserPreferredPresence/clearUserPreferredPresenceRequestBuilder';
import { SetPresenceRequestBuilder } from './setPresence/setPresenceRequestBuilder';
import { SetStatusMessageRequestBuilder } from './setStatusMessage/setStatusMessageRequestBuilder';
import { SetUserPreferredPresenceRequestBuilder } from './setUserPreferredPresence/setUserPreferredPresenceRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PresenceItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PresenceItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PresenceItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PresenceItemRequestBuilderGetQueryParameters;
}
export interface PresenceItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the presences property of the microsoft.graph.cloudCommunications entity.
 */
export declare class PresenceItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clearPresence method.
     */
    get clearPresence(): ClearPresenceRequestBuilder;
    /**
     * Provides operations to call the clearUserPreferredPresence method.
     */
    get clearUserPreferredPresence(): ClearUserPreferredPresenceRequestBuilder;
    /**
     * Provides operations to call the setPresence method.
     */
    get setPresence(): SetPresenceRequestBuilder;
    /**
     * Provides operations to call the setStatusMessage method.
     */
    get setStatusMessage(): SetStatusMessageRequestBuilder;
    /**
     * Provides operations to call the setUserPreferredPresence method.
     */
    get setUserPreferredPresence(): SetUserPreferredPresenceRequestBuilder;
    /**
     * Instantiates a new PresenceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property presences for communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PresenceItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get a user's presence information. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Presence
     * @see {@link https://learn.microsoft.com/graph/api/presence-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PresenceItemRequestBuilderGetRequestConfiguration | undefined): Promise<Presence | undefined>;
    /**
     * Update the navigation property presences in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Presence
     */
    patch(body: Presence, requestConfiguration?: PresenceItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Presence | undefined>;
    /**
     * Delete navigation property presences for communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PresenceItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get a user's presence information. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PresenceItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property presences in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Presence, requestConfiguration?: PresenceItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PresenceItemRequestBuilder
     */
    withUrl(rawUrl: string): PresenceItemRequestBuilder;
}
