import { type PresenceCollectionResponse } from '../../models/';
import { type Presence } from '../../models/presence';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { PresenceItemRequestBuilder } from './item/presenceItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PresencesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface PresencesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PresencesRequestBuilderGetQueryParameters;
}
export interface PresencesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the presences property of the microsoft.graph.cloudCommunications entity.
 */
export declare class PresencesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the presences property of the microsoft.graph.cloudCommunications entity.
     * @param presenceId The unique identifier of presence
     * @returns a PresenceItemRequestBuilder
     */
    byPresenceId(presenceId: string): PresenceItemRequestBuilder;
    /**
     * Instantiates a new PresencesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a user's presence information. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PresenceCollectionResponse
     */
    get(requestConfiguration?: PresencesRequestBuilderGetRequestConfiguration | undefined): Promise<PresenceCollectionResponse | undefined>;
    /**
     * Create new navigation property to presences for communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Presence
     */
    post(body: Presence, requestConfiguration?: PresencesRequestBuilderPostRequestConfiguration | undefined): Promise<Presence | undefined>;
    /**
     * Get a user's presence information. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PresencesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to presences for communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Presence, requestConfiguration?: PresencesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a presencesRequestBuilder
     */
    withUrl(rawUrl: string): PresencesRequestBuilder;
}
