import { type ExternalGroup } from '../../../../models/externalConnectors/externalGroup';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ExternalGroupItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ExternalGroupItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ExternalGroupItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ExternalGroupItemRequestBuilderGetQueryParameters;
}
export interface ExternalGroupItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the groups property of the microsoft.graph.externalConnectors.externalConnection entity.
 */
export declare class ExternalGroupItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the members property of the microsoft.graph.externalConnectors.externalGroup entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Instantiates a new ExternalGroupItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an externalGroup object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/externalconnectors-externalgroup-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: ExternalGroupItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get an externalGroup object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExternalGroup
     * @see {@link https://learn.microsoft.com/graph/api/externalconnectors-externalgroup-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ExternalGroupItemRequestBuilderGetRequestConfiguration | undefined): Promise<ExternalGroup | undefined>;
    /**
     * Update the properties of an externalGroup object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExternalGroup
     * @see {@link https://learn.microsoft.com/graph/api/externalconnectors-externalgroup-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ExternalGroup, requestConfiguration?: ExternalGroupItemRequestBuilderPatchRequestConfiguration | undefined): Promise<ExternalGroup | undefined>;
    /**
     * Delete an externalGroup object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ExternalGroupItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get an externalGroup object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ExternalGroupItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an externalGroup object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ExternalGroup, requestConfiguration?: ExternalGroupItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ExternalGroupItemRequestBuilder
     */
    withUrl(rawUrl: string): ExternalGroupItemRequestBuilder;
}
