"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrgContactItemRequestBuilder = void 0;
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const orgContact_1 = require("../../models/orgContact");
const checkMemberGroupsRequestBuilder_1 = require("./checkMemberGroups/checkMemberGroupsRequestBuilder");
const checkMemberObjectsRequestBuilder_1 = require("./checkMemberObjects/checkMemberObjectsRequestBuilder");
const directReportsRequestBuilder_1 = require("./directReports/directReportsRequestBuilder");
const getMemberGroupsRequestBuilder_1 = require("./getMemberGroups/getMemberGroupsRequestBuilder");
const getMemberObjectsRequestBuilder_1 = require("./getMemberObjects/getMemberObjectsRequestBuilder");
const managerRequestBuilder_1 = require("./manager/managerRequestBuilder");
const memberOfRequestBuilder_1 = require("./memberOf/memberOfRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const retryServiceProvisioningRequestBuilder_1 = require("./retryServiceProvisioning/retryServiceProvisioningRequestBuilder");
const serviceProvisioningErrorsRequestBuilder_1 = require("./serviceProvisioningErrors/serviceProvisioningErrorsRequestBuilder");
const transitiveMemberOfRequestBuilder_1 = require("./transitiveMemberOf/transitiveMemberOfRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the collection of orgContact entities.
 */
class OrgContactItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the checkMemberGroups method.
     */
    get checkMemberGroups() {
        return new checkMemberGroupsRequestBuilder_1.CheckMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the checkMemberObjects method.
     */
    get checkMemberObjects() {
        return new checkMemberObjectsRequestBuilder_1.CheckMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the directReports property of the microsoft.graph.orgContact entity.
     */
    get directReports() {
        return new directReportsRequestBuilder_1.DirectReportsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getMemberGroups method.
     */
    get getMemberGroups() {
        return new getMemberGroupsRequestBuilder_1.GetMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getMemberObjects method.
     */
    get getMemberObjects() {
        return new getMemberObjectsRequestBuilder_1.GetMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the manager property of the microsoft.graph.orgContact entity.
     */
    get manager() {
        return new managerRequestBuilder_1.ManagerRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the memberOf property of the microsoft.graph.orgContact entity.
     */
    get memberOf() {
        return new memberOfRequestBuilder_1.MemberOfRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the restore method.
     */
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the retryServiceProvisioning method.
     */
    get retryServiceProvisioning() {
        return new retryServiceProvisioningRequestBuilder_1.RetryServiceProvisioningRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * The serviceProvisioningErrors property
     */
    get serviceProvisioningErrors() {
        return new serviceProvisioningErrorsRequestBuilder_1.ServiceProvisioningErrorsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the transitiveMemberOf property of the microsoft.graph.orgContact entity.
     */
    get transitiveMemberOf() {
        return new transitiveMemberOfRequestBuilder_1.TransitiveMemberOfRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new OrgContactItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/contacts/{orgContact%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Delete entity from contacts
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Get the properties and relationships of an organizational contact. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrgContact
     * @see {@link https://learn.microsoft.com/graph/api/orgcontact-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, orgContact_1.createOrgContactFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update entity in contacts
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrgContact
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, orgContact_1.createOrgContactFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete entity from contacts
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        requestInfo.tryAddRequestHeaders("Accept", "application/json, application/json");
        return requestInfo;
    }
    ;
    /**
     * Get the properties and relationships of an organizational contact. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Update entity in contacts
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, orgContact_1.serializeOrgContact);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OrgContactItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new OrgContactItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.OrgContactItemRequestBuilder = OrgContactItemRequestBuilder;
// tslint:enable
// eslint-enable
