import { type DataPolicyOperationCollectionResponse } from '../models/';
import { type DataPolicyOperation } from '../models/dataPolicyOperation';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DataPolicyOperationItemRequestBuilder } from './item/dataPolicyOperationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DataPolicyOperationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DataPolicyOperationsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DataPolicyOperationsRequestBuilderGetQueryParameters;
}
export interface DataPolicyOperationsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of dataPolicyOperation entities.
 */
export declare class DataPolicyOperationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of dataPolicyOperation entities.
     * @param dataPolicyOperationId The unique identifier of dataPolicyOperation
     * @returns a DataPolicyOperationItemRequestBuilder
     */
    byDataPolicyOperationId(dataPolicyOperationId: string): DataPolicyOperationItemRequestBuilder;
    /**
     * Instantiates a new DataPolicyOperationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties of a dataPolicyOperation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataPolicyOperationCollectionResponse
     */
    get(requestConfiguration?: DataPolicyOperationsRequestBuilderGetRequestConfiguration | undefined): Promise<DataPolicyOperationCollectionResponse | undefined>;
    /**
     * Add new entity to dataPolicyOperations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataPolicyOperation
     */
    post(body: DataPolicyOperation, requestConfiguration?: DataPolicyOperationsRequestBuilderPostRequestConfiguration | undefined): Promise<DataPolicyOperation | undefined>;
    /**
     * Retrieve the properties of a dataPolicyOperation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DataPolicyOperationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to dataPolicyOperations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DataPolicyOperation, requestConfiguration?: DataPolicyOperationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a dataPolicyOperationsRequestBuilder
     */
    withUrl(rawUrl: string): DataPolicyOperationsRequestBuilder;
}
