import { type DeviceAppManagement } from '../models/deviceAppManagement';
import { AndroidManagedAppProtectionsRequestBuilder } from './androidManagedAppProtections/androidManagedAppProtectionsRequestBuilder';
import { DefaultManagedAppProtectionsRequestBuilder } from './defaultManagedAppProtections/defaultManagedAppProtectionsRequestBuilder';
import { IosManagedAppProtectionsRequestBuilder } from './iosManagedAppProtections/iosManagedAppProtectionsRequestBuilder';
import { ManagedAppPoliciesRequestBuilder } from './managedAppPolicies/managedAppPoliciesRequestBuilder';
import { ManagedAppRegistrationsRequestBuilder } from './managedAppRegistrations/managedAppRegistrationsRequestBuilder';
import { ManagedAppStatusesRequestBuilder } from './managedAppStatuses/managedAppStatusesRequestBuilder';
import { ManagedEBooksRequestBuilder } from './managedEBooks/managedEBooksRequestBuilder';
import { MdmWindowsInformationProtectionPoliciesRequestBuilder } from './mdmWindowsInformationProtectionPolicies/mdmWindowsInformationProtectionPoliciesRequestBuilder';
import { MobileAppCategoriesRequestBuilder } from './mobileAppCategories/mobileAppCategoriesRequestBuilder';
import { MobileAppConfigurationsRequestBuilder } from './mobileAppConfigurations/mobileAppConfigurationsRequestBuilder';
import { MobileAppsRequestBuilder } from './mobileApps/mobileAppsRequestBuilder';
import { SyncMicrosoftStoreForBusinessAppsRequestBuilder } from './syncMicrosoftStoreForBusinessApps/syncMicrosoftStoreForBusinessAppsRequestBuilder';
import { TargetedManagedAppConfigurationsRequestBuilder } from './targetedManagedAppConfigurations/targetedManagedAppConfigurationsRequestBuilder';
import { VppTokensRequestBuilder } from './vppTokens/vppTokensRequestBuilder';
import { WindowsInformationProtectionPoliciesRequestBuilder } from './windowsInformationProtectionPolicies/windowsInformationProtectionPoliciesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DeviceAppManagementRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DeviceAppManagementRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DeviceAppManagementRequestBuilderGetQueryParameters;
}
export interface DeviceAppManagementRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the deviceAppManagement singleton.
 */
export declare class DeviceAppManagementRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the androidManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get androidManagedAppProtections(): AndroidManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the defaultManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get defaultManagedAppProtections(): DefaultManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the iosManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get iosManagedAppProtections(): IosManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the managedAppPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppPolicies(): ManagedAppPoliciesRequestBuilder;
    /**
     * Provides operations to manage the managedAppRegistrations property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppRegistrations(): ManagedAppRegistrationsRequestBuilder;
    /**
     * Provides operations to manage the managedAppStatuses property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppStatuses(): ManagedAppStatusesRequestBuilder;
    /**
     * Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedEBooks(): ManagedEBooksRequestBuilder;
    /**
     * Provides operations to manage the mdmWindowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get mdmWindowsInformationProtectionPolicies(): MdmWindowsInformationProtectionPoliciesRequestBuilder;
    /**
     * Provides operations to manage the mobileAppCategories property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileAppCategories(): MobileAppCategoriesRequestBuilder;
    /**
     * Provides operations to manage the mobileAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileAppConfigurations(): MobileAppConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileApps(): MobileAppsRequestBuilder;
    /**
     * Provides operations to call the syncMicrosoftStoreForBusinessApps method.
     */
    get syncMicrosoftStoreForBusinessApps(): SyncMicrosoftStoreForBusinessAppsRequestBuilder;
    /**
     * Provides operations to manage the targetedManagedAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
     */
    get targetedManagedAppConfigurations(): TargetedManagedAppConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the vppTokens property of the microsoft.graph.deviceAppManagement entity.
     */
    get vppTokens(): VppTokensRequestBuilder;
    /**
     * Provides operations to manage the windowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get windowsInformationProtectionPolicies(): WindowsInformationProtectionPoliciesRequestBuilder;
    /**
     * Instantiates a new DeviceAppManagementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read properties and relationships of the deviceAppManagement object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceAppManagement
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-deviceappmanagement-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: DeviceAppManagementRequestBuilderGetRequestConfiguration | undefined): Promise<DeviceAppManagement | undefined>;
    /**
     * Update the properties of a deviceAppManagement object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceAppManagement
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-deviceappmanagement-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: DeviceAppManagement, requestConfiguration?: DeviceAppManagementRequestBuilderPatchRequestConfiguration | undefined): Promise<DeviceAppManagement | undefined>;
    /**
     * Read properties and relationships of the deviceAppManagement object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DeviceAppManagementRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a deviceAppManagement object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DeviceAppManagement, requestConfiguration?: DeviceAppManagementRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceAppManagementRequestBuilder
     */
    withUrl(rawUrl: string): DeviceAppManagementRequestBuilder;
}
