import { type ManagedAppPolicy } from '../../../../../models/managedAppPolicy';
import { TargetAppsRequestBuilder } from './targetApps/targetAppsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ManagedAppPolicyItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ManagedAppPolicyItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ManagedAppPolicyItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ManagedAppPolicyItemRequestBuilderGetQueryParameters;
}
export interface ManagedAppPolicyItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the appliedPolicies property of the microsoft.graph.managedAppRegistration entity.
 */
export declare class ManagedAppPolicyItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the targetApps method.
     */
    get targetApps(): TargetAppsRequestBuilder;
    /**
     * Instantiates a new ManagedAppPolicyItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property appliedPolicies for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ManagedAppPolicyItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Zero or more policys already applied on the registered app when it last synchronized with managment service.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppPolicy
     */
    get(requestConfiguration?: ManagedAppPolicyItemRequestBuilderGetRequestConfiguration | undefined): Promise<ManagedAppPolicy | undefined>;
    /**
     * Update the navigation property appliedPolicies in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppPolicy
     */
    patch(body: ManagedAppPolicy, requestConfiguration?: ManagedAppPolicyItemRequestBuilderPatchRequestConfiguration | undefined): Promise<ManagedAppPolicy | undefined>;
    /**
     * Delete navigation property appliedPolicies for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ManagedAppPolicyItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Zero or more policys already applied on the registered app when it last synchronized with managment service.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ManagedAppPolicyItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property appliedPolicies in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ManagedAppPolicy, requestConfiguration?: ManagedAppPolicyItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ManagedAppPolicyItemRequestBuilder
     */
    withUrl(rawUrl: string): ManagedAppPolicyItemRequestBuilder;
}
