import { type ManagedAppOperationCollectionResponse } from '../../../../models/';
import { type ManagedAppOperation } from '../../../../models/managedAppOperation';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ManagedAppOperationItemRequestBuilder } from './item/managedAppOperationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OperationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface OperationsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OperationsRequestBuilderGetQueryParameters;
}
export interface OperationsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the operations property of the microsoft.graph.managedAppRegistration entity.
 */
export declare class OperationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.managedAppRegistration entity.
     * @param managedAppOperationId The unique identifier of managedAppOperation
     * @returns a ManagedAppOperationItemRequestBuilder
     */
    byManagedAppOperationId(managedAppOperationId: string): ManagedAppOperationItemRequestBuilder;
    /**
     * Instantiates a new OperationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the managedAppOperation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppOperationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedappoperation-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: OperationsRequestBuilderGetRequestConfiguration | undefined): Promise<ManagedAppOperationCollectionResponse | undefined>;
    /**
     * Create a new managedAppOperation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppOperation
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedappoperation-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: ManagedAppOperation, requestConfiguration?: OperationsRequestBuilderPostRequestConfiguration | undefined): Promise<ManagedAppOperation | undefined>;
    /**
     * List properties and relationships of the managedAppOperation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OperationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new managedAppOperation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ManagedAppOperation, requestConfiguration?: OperationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a operationsRequestBuilder
     */
    withUrl(rawUrl: string): OperationsRequestBuilder;
}
