import { type DeviceInstallState } from '../../../../../models/deviceInstallState';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DeviceInstallStateItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface DeviceInstallStateItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DeviceInstallStateItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DeviceInstallStateItemRequestBuilderGetQueryParameters;
}
export interface DeviceInstallStateItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the deviceStates property of the microsoft.graph.managedEBook entity.
 */
export declare class DeviceInstallStateItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new DeviceInstallStateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a deviceInstallState.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-deviceinstallstate-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: DeviceInstallStateItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read properties and relationships of the deviceInstallState object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceInstallState
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-deviceinstallstate-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: DeviceInstallStateItemRequestBuilderGetRequestConfiguration | undefined): Promise<DeviceInstallState | undefined>;
    /**
     * Update the properties of a deviceInstallState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceInstallState
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-deviceinstallstate-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: DeviceInstallState, requestConfiguration?: DeviceInstallStateItemRequestBuilderPatchRequestConfiguration | undefined): Promise<DeviceInstallState | undefined>;
    /**
     * Deletes a deviceInstallState.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: DeviceInstallStateItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read properties and relationships of the deviceInstallState object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DeviceInstallStateItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a deviceInstallState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DeviceInstallState, requestConfiguration?: DeviceInstallStateItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DeviceInstallStateItemRequestBuilder
     */
    withUrl(rawUrl: string): DeviceInstallStateItemRequestBuilder;
}
