"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MdmWindowsInformationProtectionPoliciesRequestBuilder = void 0;
const mdmWindowsInformationProtectionPolicy_1 = require("../../models/mdmWindowsInformationProtectionPolicy");
const mdmWindowsInformationProtectionPolicyCollectionResponse_1 = require("../../models/mdmWindowsInformationProtectionPolicyCollectionResponse");
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const mdmWindowsInformationProtectionPolicyItemRequestBuilder_1 = require("./item/mdmWindowsInformationProtectionPolicyItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the mdmWindowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
 */
class MdmWindowsInformationProtectionPoliciesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the mdmWindowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
     * @param mdmWindowsInformationProtectionPolicyId The unique identifier of mdmWindowsInformationProtectionPolicy
     * @returns a MdmWindowsInformationProtectionPolicyItemRequestBuilder
     */
    byMdmWindowsInformationProtectionPolicyId(mdmWindowsInformationProtectionPolicyId) {
        if (!mdmWindowsInformationProtectionPolicyId)
            throw new Error("mdmWindowsInformationProtectionPolicyId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["mdmWindowsInformationProtectionPolicy%2Did"] = mdmWindowsInformationProtectionPolicyId;
        return new mdmWindowsInformationProtectionPolicyItemRequestBuilder_1.MdmWindowsInformationProtectionPolicyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new MdmWindowsInformationProtectionPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceAppManagement/mdmWindowsInformationProtectionPolicies{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * List properties and relationships of the mdmWindowsInformationProtectionPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MdmWindowsInformationProtectionPolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-mdmwindowsinformationprotectionpolicy-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, mdmWindowsInformationProtectionPolicyCollectionResponse_1.createMdmWindowsInformationProtectionPolicyCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create a new mdmWindowsInformationProtectionPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MdmWindowsInformationProtectionPolicy
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-mdmwindowsinformationprotectionpolicy-create?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, mdmWindowsInformationProtectionPolicy_1.createMdmWindowsInformationProtectionPolicyFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * List properties and relationships of the mdmWindowsInformationProtectionPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create a new mdmWindowsInformationProtectionPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, mdmWindowsInformationProtectionPolicy_1.serializeMdmWindowsInformationProtectionPolicy);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a mdmWindowsInformationProtectionPoliciesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new MdmWindowsInformationProtectionPoliciesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.MdmWindowsInformationProtectionPoliciesRequestBuilder = MdmWindowsInformationProtectionPoliciesRequestBuilder;
// tslint:enable
// eslint-enable
