import { type ManagedDeviceMobileAppConfigurationUserStatusCollectionResponse } from '../../../../models/';
import { type ManagedDeviceMobileAppConfigurationUserStatus } from '../../../../models/managedDeviceMobileAppConfigurationUserStatus';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ManagedDeviceMobileAppConfigurationUserStatusItemRequestBuilder } from './item/managedDeviceMobileAppConfigurationUserStatusItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface UserStatusesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface UserStatusesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: UserStatusesRequestBuilderGetQueryParameters;
}
export interface UserStatusesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the userStatuses property of the microsoft.graph.managedDeviceMobileAppConfiguration entity.
 */
export declare class UserStatusesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userStatuses property of the microsoft.graph.managedDeviceMobileAppConfiguration entity.
     * @param managedDeviceMobileAppConfigurationUserStatusId The unique identifier of managedDeviceMobileAppConfigurationUserStatus
     * @returns a ManagedDeviceMobileAppConfigurationUserStatusItemRequestBuilder
     */
    byManagedDeviceMobileAppConfigurationUserStatusId(managedDeviceMobileAppConfigurationUserStatusId: string): ManagedDeviceMobileAppConfigurationUserStatusItemRequestBuilder;
    /**
     * Instantiates a new UserStatusesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the managedDeviceMobileAppConfigurationUserStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedDeviceMobileAppConfigurationUserStatusCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-manageddevicemobileappconfigurationuserstatus-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: UserStatusesRequestBuilderGetRequestConfiguration | undefined): Promise<ManagedDeviceMobileAppConfigurationUserStatusCollectionResponse | undefined>;
    /**
     * Create a new managedDeviceMobileAppConfigurationUserStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedDeviceMobileAppConfigurationUserStatus
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-manageddevicemobileappconfigurationuserstatus-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: ManagedDeviceMobileAppConfigurationUserStatus, requestConfiguration?: UserStatusesRequestBuilderPostRequestConfiguration | undefined): Promise<ManagedDeviceMobileAppConfigurationUserStatus | undefined>;
    /**
     * List properties and relationships of the managedDeviceMobileAppConfigurationUserStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: UserStatusesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new managedDeviceMobileAppConfigurationUserStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ManagedDeviceMobileAppConfigurationUserStatus, requestConfiguration?: UserStatusesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userStatusesRequestBuilder
     */
    withUrl(rawUrl: string): UserStatusesRequestBuilder;
}
