import { type MobileAppContentCollectionResponse } from '../../../../../models/';
import { type MobileAppContent } from '../../../../../models/mobileAppContent';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { MobileAppContentItemRequestBuilder } from './item/mobileAppContentItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ContentVersionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ContentVersionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ContentVersionsRequestBuilderGetQueryParameters;
}
export interface ContentVersionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the contentVersions property of the microsoft.graph.mobileLobApp entity.
 */
export declare class ContentVersionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the contentVersions property of the microsoft.graph.mobileLobApp entity.
     * @param mobileAppContentId The unique identifier of mobileAppContent
     * @returns a MobileAppContentItemRequestBuilder
     */
    byMobileAppContentId(mobileAppContentId: string): MobileAppContentItemRequestBuilder;
    /**
     * Instantiates a new ContentVersionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The list of content versions for this app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContentCollectionResponse
     */
    get(requestConfiguration?: ContentVersionsRequestBuilderGetRequestConfiguration | undefined): Promise<MobileAppContentCollectionResponse | undefined>;
    /**
     * Create new navigation property to contentVersions for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContent
     */
    post(body: MobileAppContent, requestConfiguration?: ContentVersionsRequestBuilderPostRequestConfiguration | undefined): Promise<MobileAppContent | undefined>;
    /**
     * The list of content versions for this app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ContentVersionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to contentVersions for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MobileAppContent, requestConfiguration?: ContentVersionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a contentVersionsRequestBuilder
     */
    withUrl(rawUrl: string): ContentVersionsRequestBuilder;
}
