"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphIosStoreAppRequestBuilder = void 0;
const iosStoreApp_1 = require("../../../../models/iosStoreApp");
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const assignmentsRequestBuilder_1 = require("./assignments/assignmentsRequestBuilder");
const categoriesRequestBuilder_1 = require("./categories/categoriesRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Casts the previous resource to iosStoreApp.
 */
class GraphIosStoreAppRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.mobileApp entity.
     */
    get assignments() {
        return new assignmentsRequestBuilder_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the categories property of the microsoft.graph.mobileApp entity.
     */
    get categories() {
        return new categoriesRequestBuilder_1.CategoriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new GraphIosStoreAppRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceAppManagement/mobileApps/{mobileApp%2Did}/graph.iosStoreApp{?%24select,%24expand}");
    }
    ;
    /**
     * Get the item of type microsoft.graph.mobileApp as microsoft.graph.iosStoreApp
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IosStoreApp
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, iosStoreApp_1.createIosStoreAppFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get the item of type microsoft.graph.mobileApp as microsoft.graph.iosStoreApp
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a graphIosStoreAppRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new GraphIosStoreAppRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.GraphIosStoreAppRequestBuilder = GraphIosStoreAppRequestBuilder;
// tslint:enable
// eslint-enable
