import { type MobileAppContent } from '../../../../../../models/mobileAppContent';
import { ContainedAppsRequestBuilder } from './containedApps/containedAppsRequestBuilder';
import { FilesRequestBuilder } from './files/filesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface MobileAppContentItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface MobileAppContentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface MobileAppContentItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: MobileAppContentItemRequestBuilderGetQueryParameters;
}
export interface MobileAppContentItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the contentVersions property of the microsoft.graph.mobileLobApp entity.
 */
export declare class MobileAppContentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the containedApps property of the microsoft.graph.mobileAppContent entity.
     */
    get containedApps(): ContainedAppsRequestBuilder;
    /**
     * Provides operations to manage the files property of the microsoft.graph.mobileAppContent entity.
     */
    get files(): FilesRequestBuilder;
    /**
     * Instantiates a new MobileAppContentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property contentVersions for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: MobileAppContentItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The list of content versions for this app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContent
     */
    get(requestConfiguration?: MobileAppContentItemRequestBuilderGetRequestConfiguration | undefined): Promise<MobileAppContent | undefined>;
    /**
     * Update the navigation property contentVersions in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContent
     */
    patch(body: MobileAppContent, requestConfiguration?: MobileAppContentItemRequestBuilderPatchRequestConfiguration | undefined): Promise<MobileAppContent | undefined>;
    /**
     * Delete navigation property contentVersions for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: MobileAppContentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The list of content versions for this app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: MobileAppContentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property contentVersions in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: MobileAppContent, requestConfiguration?: MobileAppContentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a MobileAppContentItemRequestBuilder
     */
    withUrl(rawUrl: string): MobileAppContentItemRequestBuilder;
}
