import { type AuditEventCollectionResponse } from '../../models/';
import { type AuditEvent } from '../../models/auditEvent';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { GetAuditActivityTypesWithCategoryRequestBuilder } from './getAuditActivityTypesWithCategory/getAuditActivityTypesWithCategoryRequestBuilder';
import { GetAuditCategoriesRequestBuilder } from './getAuditCategories/getAuditCategoriesRequestBuilder';
import { AuditEventItemRequestBuilder } from './item/auditEventItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AuditEventsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface AuditEventsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AuditEventsRequestBuilderGetQueryParameters;
}
export interface AuditEventsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the auditEvents property of the microsoft.graph.deviceManagement entity.
 */
export declare class AuditEventsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the getAuditCategories method.
     */
    get getAuditCategories(): GetAuditCategoriesRequestBuilder;
    /**
     * Provides operations to manage the auditEvents property of the microsoft.graph.deviceManagement entity.
     * @param auditEventId The unique identifier of auditEvent
     * @returns a AuditEventItemRequestBuilder
     */
    byAuditEventId(auditEventId: string): AuditEventItemRequestBuilder;
    /**
     * Instantiates a new AuditEventsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the auditEvent objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuditEventCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-auditing-auditevent-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AuditEventsRequestBuilderGetRequestConfiguration | undefined): Promise<AuditEventCollectionResponse | undefined>;
    /**
     * Provides operations to call the getAuditActivityTypes method.
     * @param category Usage: category='{category}'
     * @returns a getAuditActivityTypesWithCategoryRequestBuilder
     */
    getAuditActivityTypesWithCategory(category: string | undefined): GetAuditActivityTypesWithCategoryRequestBuilder;
    /**
     * Create a new auditEvent object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuditEvent
     * @see {@link https://learn.microsoft.com/graph/api/intune-auditing-auditevent-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: AuditEvent, requestConfiguration?: AuditEventsRequestBuilderPostRequestConfiguration | undefined): Promise<AuditEvent | undefined>;
    /**
     * List properties and relationships of the auditEvent objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AuditEventsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new auditEvent object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AuditEvent, requestConfiguration?: AuditEventsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a auditEventsRequestBuilder
     */
    withUrl(rawUrl: string): AuditEventsRequestBuilder;
}
