import { type DeviceConfigurationUserStatusCollectionResponse } from '../../../../models/';
import { type DeviceConfigurationUserStatus } from '../../../../models/deviceConfigurationUserStatus';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DeviceConfigurationUserStatusItemRequestBuilder } from './item/deviceConfigurationUserStatusItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface UserStatusesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface UserStatusesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: UserStatusesRequestBuilderGetQueryParameters;
}
export interface UserStatusesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the userStatuses property of the microsoft.graph.deviceConfiguration entity.
 */
export declare class UserStatusesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userStatuses property of the microsoft.graph.deviceConfiguration entity.
     * @param deviceConfigurationUserStatusId The unique identifier of deviceConfigurationUserStatus
     * @returns a DeviceConfigurationUserStatusItemRequestBuilder
     */
    byDeviceConfigurationUserStatusId(deviceConfigurationUserStatusId: string): DeviceConfigurationUserStatusItemRequestBuilder;
    /**
     * Instantiates a new UserStatusesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceConfigurationUserStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationUserStatusCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-deviceconfigurationuserstatus-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: UserStatusesRequestBuilderGetRequestConfiguration | undefined): Promise<DeviceConfigurationUserStatusCollectionResponse | undefined>;
    /**
     * Create a new deviceConfigurationUserStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationUserStatus
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-deviceconfigurationuserstatus-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceConfigurationUserStatus, requestConfiguration?: UserStatusesRequestBuilderPostRequestConfiguration | undefined): Promise<DeviceConfigurationUserStatus | undefined>;
    /**
     * List properties and relationships of the deviceConfigurationUserStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: UserStatusesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new deviceConfigurationUserStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceConfigurationUserStatus, requestConfiguration?: UserStatusesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userStatusesRequestBuilder
     */
    withUrl(rawUrl: string): UserStatusesRequestBuilder;
}
