import { type DeviceConfigurationStateCollectionResponse } from '../../../../models/';
import { type DeviceConfigurationState } from '../../../../models/deviceConfigurationState';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DeviceConfigurationStateItemRequestBuilder } from './item/deviceConfigurationStateItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DeviceConfigurationStatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DeviceConfigurationStatesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DeviceConfigurationStatesRequestBuilderGetQueryParameters;
}
export interface DeviceConfigurationStatesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
 */
export declare class DeviceConfigurationStatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
     * @param deviceConfigurationStateId The unique identifier of deviceConfigurationState
     * @returns a DeviceConfigurationStateItemRequestBuilder
     */
    byDeviceConfigurationStateId(deviceConfigurationStateId: string): DeviceConfigurationStateItemRequestBuilder;
    /**
     * Instantiates a new DeviceConfigurationStatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Device configuration states for this device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationStateCollectionResponse
     */
    get(requestConfiguration?: DeviceConfigurationStatesRequestBuilderGetRequestConfiguration | undefined): Promise<DeviceConfigurationStateCollectionResponse | undefined>;
    /**
     * Create new navigation property to deviceConfigurationStates for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationState
     */
    post(body: DeviceConfigurationState, requestConfiguration?: DeviceConfigurationStatesRequestBuilderPostRequestConfiguration | undefined): Promise<DeviceConfigurationState | undefined>;
    /**
     * Device configuration states for this device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DeviceConfigurationStatesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to deviceConfigurationStates for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceConfigurationState, requestConfiguration?: DeviceConfigurationStatesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceConfigurationStatesRequestBuilder
     */
    withUrl(rawUrl: string): DeviceConfigurationStatesRequestBuilder;
}
