"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserExperienceAnalyticsDevicePerformanceRequestBuilder = void 0;
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const userExperienceAnalyticsDevicePerformance_1 = require("../../models/userExperienceAnalyticsDevicePerformance");
const userExperienceAnalyticsDevicePerformanceCollectionResponse_1 = require("../../models/userExperienceAnalyticsDevicePerformanceCollectionResponse");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const userExperienceAnalyticsDevicePerformanceItemRequestBuilder_1 = require("./item/userExperienceAnalyticsDevicePerformanceItemRequestBuilder");
const summarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder_1 = require("./summarizeDevicePerformanceDevicesWithSummarizeBy/summarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
 */
class UserExperienceAnalyticsDevicePerformanceRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
     * @param userExperienceAnalyticsDevicePerformanceId The unique identifier of userExperienceAnalyticsDevicePerformance
     * @returns a UserExperienceAnalyticsDevicePerformanceItemRequestBuilder
     */
    byUserExperienceAnalyticsDevicePerformanceId(userExperienceAnalyticsDevicePerformanceId) {
        if (!userExperienceAnalyticsDevicePerformanceId)
            throw new Error("userExperienceAnalyticsDevicePerformanceId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["userExperienceAnalyticsDevicePerformance%2Did"] = userExperienceAnalyticsDevicePerformanceId;
        return new userExperienceAnalyticsDevicePerformanceItemRequestBuilder_1.UserExperienceAnalyticsDevicePerformanceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new UserExperienceAnalyticsDevicePerformanceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceManagement/userExperienceAnalyticsDevicePerformance{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * User experience analytics device performance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsDevicePerformanceCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, userExperienceAnalyticsDevicePerformanceCollectionResponse_1.createUserExperienceAnalyticsDevicePerformanceCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsDevicePerformance
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, userExperienceAnalyticsDevicePerformance_1.createUserExperienceAnalyticsDevicePerformanceFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the summarizeDevicePerformanceDevices method.
     * @param summarizeBy Usage: summarizeBy='{summarizeBy}'
     * @returns a summarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder
     */
    summarizeDevicePerformanceDevicesWithSummarizeBy(summarizeBy) {
        if (!summarizeBy)
            throw new Error("summarizeBy cannot be undefined");
        return new summarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder_1.SummarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder(this.pathParameters, this.requestAdapter, summarizeBy);
    }
    ;
    /**
     * User experience analytics device performance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, userExperienceAnalyticsDevicePerformance_1.serializeUserExperienceAnalyticsDevicePerformance);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userExperienceAnalyticsDevicePerformanceRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UserExperienceAnalyticsDevicePerformanceRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UserExperienceAnalyticsDevicePerformanceRequestBuilder = UserExperienceAnalyticsDevicePerformanceRequestBuilder;
// tslint:enable
// eslint-enable
