"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceItemRequestBuilder = void 0;
// tslint:disable
// eslint-disable
// Generated by Microsoft Kiota
const device_1 = require("../../models/device");
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const checkMemberGroupsRequestBuilder_1 = require("./checkMemberGroups/checkMemberGroupsRequestBuilder");
const checkMemberObjectsRequestBuilder_1 = require("./checkMemberObjects/checkMemberObjectsRequestBuilder");
const extensionsRequestBuilder_1 = require("./extensions/extensionsRequestBuilder");
const getMemberGroupsRequestBuilder_1 = require("./getMemberGroups/getMemberGroupsRequestBuilder");
const getMemberObjectsRequestBuilder_1 = require("./getMemberObjects/getMemberObjectsRequestBuilder");
const memberOfRequestBuilder_1 = require("./memberOf/memberOfRequestBuilder");
const registeredOwnersRequestBuilder_1 = require("./registeredOwners/registeredOwnersRequestBuilder");
const registeredUsersRequestBuilder_1 = require("./registeredUsers/registeredUsersRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const transitiveMemberOfRequestBuilder_1 = require("./transitiveMemberOf/transitiveMemberOfRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the collection of device entities.
 */
class DeviceItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the checkMemberGroups method.
     */
    get checkMemberGroups() {
        return new checkMemberGroupsRequestBuilder_1.CheckMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the checkMemberObjects method.
     */
    get checkMemberObjects() {
        return new checkMemberObjectsRequestBuilder_1.CheckMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the extensions property of the microsoft.graph.device entity.
     */
    get extensions() {
        return new extensionsRequestBuilder_1.ExtensionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getMemberGroups method.
     */
    get getMemberGroups() {
        return new getMemberGroupsRequestBuilder_1.GetMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getMemberObjects method.
     */
    get getMemberObjects() {
        return new getMemberObjectsRequestBuilder_1.GetMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the memberOf property of the microsoft.graph.device entity.
     */
    get memberOf() {
        return new memberOfRequestBuilder_1.MemberOfRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the registeredOwners property of the microsoft.graph.device entity.
     */
    get registeredOwners() {
        return new registeredOwnersRequestBuilder_1.RegisteredOwnersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the registeredUsers property of the microsoft.graph.device entity.
     */
    get registeredUsers() {
        return new registeredUsersRequestBuilder_1.RegisteredUsersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the restore method.
     */
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the transitiveMemberOf property of the microsoft.graph.device entity.
     */
    get transitiveMemberOf() {
        return new transitiveMemberOfRequestBuilder_1.TransitiveMemberOfRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new DeviceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/devices/{device%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Delete a registered device. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/device-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Get the properties and relationships of a device object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Device
     * @see {@link https://learn.microsoft.com/graph/api/device-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, device_1.createDeviceFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the properties of a registered device. Only certain properties of a device can be updated through approved Mobile Device Managment (MDM) apps. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Device
     * @see {@link https://learn.microsoft.com/graph/api/device-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, device_1.createDeviceFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete a registered device. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        requestInfo.tryAddRequestHeaders("Accept", "application/json, application/json");
        return requestInfo;
    }
    ;
    /**
     * Get the properties and relationships of a device object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Update the properties of a registered device. Only certain properties of a device can be updated through approved Mobile Device Managment (MDM) apps. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, device_1.serializeDevice);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DeviceItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DeviceItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DeviceItemRequestBuilder = DeviceItemRequestBuilder;
// tslint:enable
// eslint-enable
