import { type AttributeSet } from '../../../models/attributeSet';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AttributeSetItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AttributeSetItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AttributeSetItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AttributeSetItemRequestBuilderGetQueryParameters;
}
export interface AttributeSetItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the attributeSets property of the microsoft.graph.directory entity.
 */
export declare class AttributeSetItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AttributeSetItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property attributeSets for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AttributeSetItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an attributeSet object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttributeSet
     * @see {@link https://learn.microsoft.com/graph/api/attributeset-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AttributeSetItemRequestBuilderGetRequestConfiguration | undefined): Promise<AttributeSet | undefined>;
    /**
     * Update the properties of an attributeSet object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttributeSet
     * @see {@link https://learn.microsoft.com/graph/api/attributeset-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: AttributeSet, requestConfiguration?: AttributeSetItemRequestBuilderPatchRequestConfiguration | undefined): Promise<AttributeSet | undefined>;
    /**
     * Delete navigation property attributeSets for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AttributeSetItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an attributeSet object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AttributeSetItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an attributeSet object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AttributeSet, requestConfiguration?: AttributeSetItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AttributeSetItemRequestBuilder
     */
    withUrl(rawUrl: string): AttributeSetItemRequestBuilder;
}
