import { type CustomSecurityAttributeDefinitionCollectionResponse } from '../../models/';
import { type CustomSecurityAttributeDefinition } from '../../models/customSecurityAttributeDefinition';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { CustomSecurityAttributeDefinitionItemRequestBuilder } from './item/customSecurityAttributeDefinitionItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface CustomSecurityAttributeDefinitionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface CustomSecurityAttributeDefinitionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: CustomSecurityAttributeDefinitionsRequestBuilderGetQueryParameters;
}
export interface CustomSecurityAttributeDefinitionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the customSecurityAttributeDefinitions property of the microsoft.graph.directory entity.
 */
export declare class CustomSecurityAttributeDefinitionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the customSecurityAttributeDefinitions property of the microsoft.graph.directory entity.
     * @param customSecurityAttributeDefinitionId The unique identifier of customSecurityAttributeDefinition
     * @returns a CustomSecurityAttributeDefinitionItemRequestBuilder
     */
    byCustomSecurityAttributeDefinitionId(customSecurityAttributeDefinitionId: string): CustomSecurityAttributeDefinitionItemRequestBuilder;
    /**
     * Instantiates a new CustomSecurityAttributeDefinitionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the customSecurityAttributeDefinition objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CustomSecurityAttributeDefinitionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/directory-list-customsecurityattributedefinitions?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: CustomSecurityAttributeDefinitionsRequestBuilderGetRequestConfiguration | undefined): Promise<CustomSecurityAttributeDefinitionCollectionResponse | undefined>;
    /**
     * Create a new customSecurityAttributeDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CustomSecurityAttributeDefinition
     * @see {@link https://learn.microsoft.com/graph/api/directory-post-customsecurityattributedefinitions?view=graph-rest-1.0|Find more info here}
     */
    post(body: CustomSecurityAttributeDefinition, requestConfiguration?: CustomSecurityAttributeDefinitionsRequestBuilderPostRequestConfiguration | undefined): Promise<CustomSecurityAttributeDefinition | undefined>;
    /**
     * Get a list of the customSecurityAttributeDefinition objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: CustomSecurityAttributeDefinitionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new customSecurityAttributeDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CustomSecurityAttributeDefinition, requestConfiguration?: CustomSecurityAttributeDefinitionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a customSecurityAttributeDefinitionsRequestBuilder
     */
    withUrl(rawUrl: string): CustomSecurityAttributeDefinitionsRequestBuilder;
}
