import { type Directory } from '../models/directory';
import { AdministrativeUnitsRequestBuilder } from './administrativeUnits/administrativeUnitsRequestBuilder';
import { AttributeSetsRequestBuilder } from './attributeSets/attributeSetsRequestBuilder';
import { CustomSecurityAttributeDefinitionsRequestBuilder } from './customSecurityAttributeDefinitions/customSecurityAttributeDefinitionsRequestBuilder';
import { DeletedItemsRequestBuilder } from './deletedItems/deletedItemsRequestBuilder';
import { FederationConfigurationsRequestBuilder } from './federationConfigurations/federationConfigurationsRequestBuilder';
import { OnPremisesSynchronizationRequestBuilder } from './onPremisesSynchronization/onPremisesSynchronizationRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DirectoryRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DirectoryRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DirectoryRequestBuilderGetQueryParameters;
}
export interface DirectoryRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the directory singleton.
 */
export declare class DirectoryRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the administrativeUnits property of the microsoft.graph.directory entity.
     */
    get administrativeUnits(): AdministrativeUnitsRequestBuilder;
    /**
     * Provides operations to manage the attributeSets property of the microsoft.graph.directory entity.
     */
    get attributeSets(): AttributeSetsRequestBuilder;
    /**
     * Provides operations to manage the customSecurityAttributeDefinitions property of the microsoft.graph.directory entity.
     */
    get customSecurityAttributeDefinitions(): CustomSecurityAttributeDefinitionsRequestBuilder;
    /**
     * Provides operations to manage the deletedItems property of the microsoft.graph.directory entity.
     */
    get deletedItems(): DeletedItemsRequestBuilder;
    /**
     * Provides operations to manage the federationConfigurations property of the microsoft.graph.directory entity.
     */
    get federationConfigurations(): FederationConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the onPremisesSynchronization property of the microsoft.graph.directory entity.
     */
    get onPremisesSynchronization(): OnPremisesSynchronizationRequestBuilder;
    /**
     * Instantiates a new DirectoryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Directory
     */
    get(requestConfiguration?: DirectoryRequestBuilderGetRequestConfiguration | undefined): Promise<Directory | undefined>;
    /**
     * Update directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Directory
     */
    patch(body: Directory, requestConfiguration?: DirectoryRequestBuilderPatchRequestConfiguration | undefined): Promise<Directory | undefined>;
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DirectoryRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Directory, requestConfiguration?: DirectoryRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a directoryRequestBuilder
     */
    withUrl(rawUrl: string): DirectoryRequestBuilder;
}
