import { type OnPremisesDirectorySynchronizationCollectionResponse } from '../../models/';
import { type OnPremisesDirectorySynchronization } from '../../models/onPremisesDirectorySynchronization';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { OnPremisesDirectorySynchronizationItemRequestBuilder } from './item/onPremisesDirectorySynchronizationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OnPremisesSynchronizationRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface OnPremisesSynchronizationRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OnPremisesSynchronizationRequestBuilderGetQueryParameters;
}
export interface OnPremisesSynchronizationRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the onPremisesSynchronization property of the microsoft.graph.directory entity.
 */
export declare class OnPremisesSynchronizationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the onPremisesSynchronization property of the microsoft.graph.directory entity.
     * @param onPremisesDirectorySynchronizationId The unique identifier of onPremisesDirectorySynchronization
     * @returns a OnPremisesDirectorySynchronizationItemRequestBuilder
     */
    byOnPremisesDirectorySynchronizationId(onPremisesDirectorySynchronizationId: string): OnPremisesDirectorySynchronizationItemRequestBuilder;
    /**
     * Instantiates a new OnPremisesSynchronizationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of an onPremisesDirectorySynchronization object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnPremisesDirectorySynchronizationCollectionResponse
     */
    get(requestConfiguration?: OnPremisesSynchronizationRequestBuilderGetRequestConfiguration | undefined): Promise<OnPremisesDirectorySynchronizationCollectionResponse | undefined>;
    /**
     * Create new navigation property to onPremisesSynchronization for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnPremisesDirectorySynchronization
     */
    post(body: OnPremisesDirectorySynchronization, requestConfiguration?: OnPremisesSynchronizationRequestBuilderPostRequestConfiguration | undefined): Promise<OnPremisesDirectorySynchronization | undefined>;
    /**
     * Read the properties and relationships of an onPremisesDirectorySynchronization object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OnPremisesSynchronizationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to onPremisesSynchronization for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: OnPremisesDirectorySynchronization, requestConfiguration?: OnPremisesSynchronizationRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a onPremisesSynchronizationRequestBuilder
     */
    withUrl(rawUrl: string): OnPremisesSynchronizationRequestBuilder;
}
