import { type DomainDnsRecordCollectionResponse } from '../models/';
import { type DomainDnsRecord } from '../models/domainDnsRecord';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DomainDnsRecordItemRequestBuilder } from './item/domainDnsRecordItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DomainDnsRecordsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DomainDnsRecordsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DomainDnsRecordsRequestBuilderGetQueryParameters;
}
export interface DomainDnsRecordsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of domainDnsRecord entities.
 */
export declare class DomainDnsRecordsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of domainDnsRecord entities.
     * @param domainDnsRecordId The unique identifier of domainDnsRecord
     * @returns a DomainDnsRecordItemRequestBuilder
     */
    byDomainDnsRecordId(domainDnsRecordId: string): DomainDnsRecordItemRequestBuilder;
    /**
     * Instantiates a new DomainDnsRecordsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from domainDnsRecords
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DomainDnsRecordCollectionResponse
     */
    get(requestConfiguration?: DomainDnsRecordsRequestBuilderGetRequestConfiguration | undefined): Promise<DomainDnsRecordCollectionResponse | undefined>;
    /**
     * Add new entity to domainDnsRecords
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DomainDnsRecord
     */
    post(body: DomainDnsRecord, requestConfiguration?: DomainDnsRecordsRequestBuilderPostRequestConfiguration | undefined): Promise<DomainDnsRecord | undefined>;
    /**
     * Get entities from domainDnsRecords
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DomainDnsRecordsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to domainDnsRecords
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DomainDnsRecord, requestConfiguration?: DomainDnsRecordsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a domainDnsRecordsRequestBuilder
     */
    withUrl(rawUrl: string): DomainDnsRecordsRequestBuilder;
}
