import { type InternalDomainFederation } from '../../../../models/internalDomainFederation';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface InternalDomainFederationItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface InternalDomainFederationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface InternalDomainFederationItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: InternalDomainFederationItemRequestBuilderGetQueryParameters;
}
export interface InternalDomainFederationItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the federationConfiguration property of the microsoft.graph.domain entity.
 */
export declare class InternalDomainFederationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new InternalDomainFederationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/internaldomainfederation-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: InternalDomainFederationItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternalDomainFederation
     * @see {@link https://learn.microsoft.com/graph/api/internaldomainfederation-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: InternalDomainFederationItemRequestBuilderGetRequestConfiguration | undefined): Promise<InternalDomainFederation | undefined>;
    /**
     * Update the properties of an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternalDomainFederation
     * @see {@link https://learn.microsoft.com/graph/api/internaldomainfederation-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: InternalDomainFederation, requestConfiguration?: InternalDomainFederationItemRequestBuilderPatchRequestConfiguration | undefined): Promise<InternalDomainFederation | undefined>;
    /**
     * Delete an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: InternalDomainFederationItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: InternalDomainFederationItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an internalDomainFederation object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: InternalDomainFederation, requestConfiguration?: InternalDomainFederationItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a InternalDomainFederationItemRequestBuilder
     */
    withUrl(rawUrl: string): InternalDomainFederationItemRequestBuilder;
}
