import { type Drive } from '../../models/drive';
import { BundlesRequestBuilder } from './bundles/bundlesRequestBuilder';
import { CreatedByUserRequestBuilder } from './createdByUser/createdByUserRequestBuilder';
import { FollowingRequestBuilder } from './following/followingRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { LastModifiedByUserRequestBuilder } from './lastModifiedByUser/lastModifiedByUserRequestBuilder';
import { ListRequestBuilder } from './list/listRequestBuilder';
import { RecentRequestBuilder } from './recent/recentRequestBuilder';
import { RootRequestBuilder } from './root/rootRequestBuilder';
import { SearchWithQRequestBuilder } from './searchWithQ/searchWithQRequestBuilder';
import { SharedWithMeRequestBuilder } from './sharedWithMe/sharedWithMeRequestBuilder';
import { SpecialRequestBuilder } from './special/specialRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DriveItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface DriveItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DriveItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DriveItemRequestBuilderGetQueryParameters;
}
export interface DriveItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of drive entities.
 */
export declare class DriveItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the bundles property of the microsoft.graph.drive entity.
     */
    get bundles(): BundlesRequestBuilder;
    /**
     * Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
     */
    get createdByUser(): CreatedByUserRequestBuilder;
    /**
     * Provides operations to manage the following property of the microsoft.graph.drive entity.
     */
    get following(): FollowingRequestBuilder;
    /**
     * Provides operations to manage the items property of the microsoft.graph.drive entity.
     */
    get items(): ItemsRequestBuilder;
    /**
     * Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
     */
    get lastModifiedByUser(): LastModifiedByUserRequestBuilder;
    /**
     * Provides operations to manage the list property of the microsoft.graph.drive entity.
     */
    get list(): ListRequestBuilder;
    /**
     * Provides operations to call the recent method.
     */
    get recent(): RecentRequestBuilder;
    /**
     * Provides operations to manage the root property of the microsoft.graph.drive entity.
     */
    get root(): RootRequestBuilder;
    /**
     * Provides operations to call the sharedWithMe method.
     */
    get sharedWithMe(): SharedWithMeRequestBuilder;
    /**
     * Provides operations to manage the special property of the microsoft.graph.drive entity.
     */
    get special(): SpecialRequestBuilder;
    /**
     * Instantiates a new DriveItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: DriveItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get entity from drives by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Drive
     */
    get(requestConfiguration?: DriveItemRequestBuilderGetRequestConfiguration | undefined): Promise<Drive | undefined>;
    /**
     * Update entity in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Drive
     */
    patch(body: Drive, requestConfiguration?: DriveItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Drive | undefined>;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q: string | undefined): SearchWithQRequestBuilder;
    /**
     * Delete entity from drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: DriveItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entity from drives by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DriveItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Drive, requestConfiguration?: DriveItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DriveItemRequestBuilder
     */
    withUrl(rawUrl: string): DriveItemRequestBuilder;
}
