import { type CheckinPostRequestBody } from './checkinPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface CheckinRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the checkin method.
 */
export declare class CheckinRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new CheckinRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Check in a checked out driveItem resource, which makes the version of the document available to others. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-checkin?view=graph-rest-1.0|Find more info here}
     */
    post(body: CheckinPostRequestBody, requestConfiguration?: CheckinRequestBuilderPostRequestConfiguration | undefined): Promise<void>;
    /**
     * Check in a checked out driveItem resource, which makes the version of the document available to others. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CheckinPostRequestBody, requestConfiguration?: CheckinRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a checkinRequestBuilder
     */
    withUrl(rawUrl: string): CheckinRequestBuilder;
}
