import { type WorkbookApplication } from '../../../../../../models/workbookApplication';
import { CalculateRequestBuilder } from './calculate/calculateRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ApplicationRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ApplicationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ApplicationRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ApplicationRequestBuilderGetQueryParameters;
}
export interface ApplicationRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the application property of the microsoft.graph.workbook entity.
 */
export declare class ApplicationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the calculate method.
     */
    get calculate(): CalculateRequestBuilder;
    /**
     * Instantiates a new ApplicationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property application for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ApplicationRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a workbookApplication object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookApplication
     * @see {@link https://learn.microsoft.com/graph/api/workbookapplication-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ApplicationRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookApplication | undefined>;
    /**
     * Update the navigation property application in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookApplication
     */
    patch(body: WorkbookApplication, requestConfiguration?: ApplicationRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookApplication | undefined>;
    /**
     * Delete navigation property application for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ApplicationRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a workbookApplication object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ApplicationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property application in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookApplication, requestConfiguration?: ApplicationRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a applicationRequestBuilder
     */
    withUrl(rawUrl: string): ApplicationRequestBuilder;
}
