import { type WorkbookComment } from '../../../../../../../models/workbookComment';
import { RepliesRequestBuilder } from './replies/repliesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorkbookCommentItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WorkbookCommentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WorkbookCommentItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorkbookCommentItemRequestBuilderGetQueryParameters;
}
export interface WorkbookCommentItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the comments property of the microsoft.graph.workbook entity.
 */
export declare class WorkbookCommentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the replies property of the microsoft.graph.workbookComment entity.
     */
    get replies(): RepliesRequestBuilder;
    /**
     * Instantiates a new WorkbookCommentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property comments for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: WorkbookCommentItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents a collection of comments in a workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookComment
     */
    get(requestConfiguration?: WorkbookCommentItemRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookComment | undefined>;
    /**
     * Update the navigation property comments in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookComment
     */
    patch(body: WorkbookComment, requestConfiguration?: WorkbookCommentItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookComment | undefined>;
    /**
     * Delete navigation property comments for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WorkbookCommentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents a collection of comments in a workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorkbookCommentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property comments in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookComment, requestConfiguration?: WorkbookCommentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookCommentItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookCommentItemRequestBuilder;
}
