import { type WorkbookFunctionResult } from '../../../../../../../models/workbookFunctionResult';
import { type CodePostRequestBody } from './codePostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface CodeRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the code method.
 */
export declare class CodeRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new CodeRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Invoke action code
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFunctionResult
     */
    post(body: CodePostRequestBody, requestConfiguration?: CodeRequestBuilderPostRequestConfiguration | undefined): Promise<WorkbookFunctionResult | undefined>;
    /**
     * Invoke action code
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CodePostRequestBody, requestConfiguration?: CodeRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a codeRequestBuilder
     */
    withUrl(rawUrl: string): CodeRequestBuilder;
}
