import { type WorkbookFunctionResult } from '../../../../../../../models/workbookFunctionResult';
import { type PowerPostRequestBody } from './powerPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PowerRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the power method.
 */
export declare class PowerRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PowerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Invoke action power
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFunctionResult
     */
    post(body: PowerPostRequestBody, requestConfiguration?: PowerRequestBuilderPostRequestConfiguration | undefined): Promise<WorkbookFunctionResult | undefined>;
    /**
     * Invoke action power
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PowerPostRequestBody, requestConfiguration?: PowerRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a powerRequestBuilder
     */
    withUrl(rawUrl: string): PowerRequestBuilder;
}
