"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../../../../models/oDataErrors/oDataError");
const workbookFilter_1 = require("../../../../../../../../../../models/workbookFilter");
const applyRequestBuilder_1 = require("./apply/applyRequestBuilder");
const applyBottomItemsFilterRequestBuilder_1 = require("./applyBottomItemsFilter/applyBottomItemsFilterRequestBuilder");
const applyBottomPercentFilterRequestBuilder_1 = require("./applyBottomPercentFilter/applyBottomPercentFilterRequestBuilder");
const applyCellColorFilterRequestBuilder_1 = require("./applyCellColorFilter/applyCellColorFilterRequestBuilder");
const applyCustomFilterRequestBuilder_1 = require("./applyCustomFilter/applyCustomFilterRequestBuilder");
const applyDynamicFilterRequestBuilder_1 = require("./applyDynamicFilter/applyDynamicFilterRequestBuilder");
const applyFontColorFilterRequestBuilder_1 = require("./applyFontColorFilter/applyFontColorFilterRequestBuilder");
const applyIconFilterRequestBuilder_1 = require("./applyIconFilter/applyIconFilterRequestBuilder");
const applyTopItemsFilterRequestBuilder_1 = require("./applyTopItemsFilter/applyTopItemsFilterRequestBuilder");
const applyTopPercentFilterRequestBuilder_1 = require("./applyTopPercentFilter/applyTopPercentFilterRequestBuilder");
const applyValuesFilterRequestBuilder_1 = require("./applyValuesFilter/applyValuesFilterRequestBuilder");
const clearRequestBuilder_1 = require("./clear/clearRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the filter property of the microsoft.graph.workbookTableColumn entity.
 */
class FilterRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the apply method.
     */
    get apply() {
        return new applyRequestBuilder_1.ApplyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyBottomItemsFilter method.
     */
    get applyBottomItemsFilter() {
        return new applyBottomItemsFilterRequestBuilder_1.ApplyBottomItemsFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyBottomPercentFilter method.
     */
    get applyBottomPercentFilter() {
        return new applyBottomPercentFilterRequestBuilder_1.ApplyBottomPercentFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyCellColorFilter method.
     */
    get applyCellColorFilter() {
        return new applyCellColorFilterRequestBuilder_1.ApplyCellColorFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyCustomFilter method.
     */
    get applyCustomFilter() {
        return new applyCustomFilterRequestBuilder_1.ApplyCustomFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyDynamicFilter method.
     */
    get applyDynamicFilter() {
        return new applyDynamicFilterRequestBuilder_1.ApplyDynamicFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyFontColorFilter method.
     */
    get applyFontColorFilter() {
        return new applyFontColorFilterRequestBuilder_1.ApplyFontColorFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyIconFilter method.
     */
    get applyIconFilter() {
        return new applyIconFilterRequestBuilder_1.ApplyIconFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyTopItemsFilter method.
     */
    get applyTopItemsFilter() {
        return new applyTopItemsFilterRequestBuilder_1.ApplyTopItemsFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyTopPercentFilter method.
     */
    get applyTopPercentFilter() {
        return new applyTopPercentFilterRequestBuilder_1.ApplyTopPercentFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyValuesFilter method.
     */
    get applyValuesFilter() {
        return new applyValuesFilterRequestBuilder_1.ApplyValuesFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the clear method.
     */
    get clear() {
        return new clearRequestBuilder_1.ClearRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new FilterRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/tables/{workbookTable%2Did}/columns/{workbookTableColumn%2Did}/filter{?%24select,%24expand}");
    }
    ;
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookFilter_1.createWorkbookFilterFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookFilter_1.createWorkbookFilterFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        requestInfo.tryAddRequestHeaders("Accept", "application/json, application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbookFilter_1.serializeWorkbookFilter);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filterRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new FilterRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.FilterRequestBuilder = FilterRequestBuilder;
// tslint:enable
// eslint-enable
