"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkbookRequestBuilder = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const workbook_1 = require("../../../../../models/workbook");
const applicationRequestBuilder_1 = require("./application/applicationRequestBuilder");
const closeSessionRequestBuilder_1 = require("./closeSession/closeSessionRequestBuilder");
const commentsRequestBuilder_1 = require("./comments/commentsRequestBuilder");
const createSessionRequestBuilder_1 = require("./createSession/createSessionRequestBuilder");
const functionsRequestBuilder_1 = require("./functions/functionsRequestBuilder");
const namesRequestBuilder_1 = require("./names/namesRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const refreshSessionRequestBuilder_1 = require("./refreshSession/refreshSessionRequestBuilder");
const sessionInfoResourceWithKeyRequestBuilder_1 = require("./sessionInfoResourceWithKey/sessionInfoResourceWithKeyRequestBuilder");
const tableRowOperationResultWithKeyRequestBuilder_1 = require("./tableRowOperationResultWithKey/tableRowOperationResultWithKeyRequestBuilder");
const tablesRequestBuilder_1 = require("./tables/tablesRequestBuilder");
const worksheetsRequestBuilder_1 = require("./worksheets/worksheetsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the workbook property of the microsoft.graph.driveItem entity.
 */
class WorkbookRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the application property of the microsoft.graph.workbook entity.
     */
    get application() {
        return new applicationRequestBuilder_1.ApplicationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the closeSession method.
     */
    get closeSession() {
        return new closeSessionRequestBuilder_1.CloseSessionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the comments property of the microsoft.graph.workbook entity.
     */
    get comments() {
        return new commentsRequestBuilder_1.CommentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the createSession method.
     */
    get createSession() {
        return new createSessionRequestBuilder_1.CreateSessionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the functions property of the microsoft.graph.workbook entity.
     */
    get functions() {
        return new functionsRequestBuilder_1.FunctionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the names property of the microsoft.graph.workbook entity.
     */
    get names() {
        return new namesRequestBuilder_1.NamesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the operations property of the microsoft.graph.workbook entity.
     */
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the refreshSession method.
     */
    get refreshSession() {
        return new refreshSessionRequestBuilder_1.RefreshSessionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the tables property of the microsoft.graph.workbook entity.
     */
    get tables() {
        return new tablesRequestBuilder_1.TablesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
     */
    get worksheets() {
        return new worksheetsRequestBuilder_1.WorksheetsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new WorkbookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook{?%24select,%24expand}");
    }
    ;
    /**
     * Delete navigation property workbook for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Workbook
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbook_1.createWorkbookFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property workbook in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Workbook
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbook_1.createWorkbookFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the sessionInfoResource method.
     * @param key Usage: key='{key}'
     * @returns a sessionInfoResourceWithKeyRequestBuilder
     */
    sessionInfoResourceWithKey(key) {
        if (!key)
            throw new Error("key cannot be undefined");
        return new sessionInfoResourceWithKeyRequestBuilder_1.SessionInfoResourceWithKeyRequestBuilder(this.pathParameters, this.requestAdapter, key);
    }
    ;
    /**
     * Provides operations to call the tableRowOperationResult method.
     * @param key Usage: key='{key}'
     * @returns a tableRowOperationResultWithKeyRequestBuilder
     */
    tableRowOperationResultWithKey(key) {
        if (!key)
            throw new Error("key cannot be undefined");
        return new tableRowOperationResultWithKeyRequestBuilder_1.TableRowOperationResultWithKeyRequestBuilder(this.pathParameters, this.requestAdapter, key);
    }
    ;
    /**
     * Delete navigation property workbook for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        requestInfo.tryAddRequestHeaders("Accept", "application/json, application/json");
        return requestInfo;
    }
    ;
    /**
     * For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property workbook in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbook_1.serializeWorkbook);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a workbookRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WorkbookRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WorkbookRequestBuilder = WorkbookRequestBuilder;
// tslint:enable
// eslint-enable
