import { type WorkbookChartAxes } from '../../../../../../../../../../models/workbookChartAxes';
import { CategoryAxisRequestBuilder } from './categoryAxis/categoryAxisRequestBuilder';
import { SeriesAxisRequestBuilder } from './seriesAxis/seriesAxisRequestBuilder';
import { ValueAxisRequestBuilder } from './valueAxis/valueAxisRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AxesRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AxesRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AxesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AxesRequestBuilderGetQueryParameters;
}
export interface AxesRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the axes property of the microsoft.graph.workbookChart entity.
 */
export declare class AxesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the categoryAxis property of the microsoft.graph.workbookChartAxes entity.
     */
    get categoryAxis(): CategoryAxisRequestBuilder;
    /**
     * Provides operations to manage the seriesAxis property of the microsoft.graph.workbookChartAxes entity.
     */
    get seriesAxis(): SeriesAxisRequestBuilder;
    /**
     * Provides operations to manage the valueAxis property of the microsoft.graph.workbookChartAxes entity.
     */
    get valueAxis(): ValueAxisRequestBuilder;
    /**
     * Instantiates a new AxesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property axes for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AxesRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents chart axes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxes
     */
    get(requestConfiguration?: AxesRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChartAxes | undefined>;
    /**
     * Update the navigation property axes in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxes
     */
    patch(body: WorkbookChartAxes, requestConfiguration?: AxesRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChartAxes | undefined>;
    /**
     * Delete navigation property axes for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AxesRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents chart axes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AxesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property axes in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAxes, requestConfiguration?: AxesRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a axesRequestBuilder
     */
    withUrl(rawUrl: string): AxesRequestBuilder;
}
