import { type WorkbookChartLineFormat } from '../../../../../../../../../../../../../models/workbookChartLineFormat';
import { ClearRequestBuilder } from './clear/clearRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LineRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface LineRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface LineRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LineRequestBuilderGetQueryParameters;
}
export interface LineRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the line property of the microsoft.graph.workbookChartAxisFormat entity.
 */
export declare class LineRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clear method.
     */
    get clear(): ClearRequestBuilder;
    /**
     * Instantiates a new LineRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property line for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: LineRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chartlineformat object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartLineFormat
     * @see {@link https://learn.microsoft.com/graph/api/chartlineformat-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: LineRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChartLineFormat | undefined>;
    /**
     * Update the properties of chartlineformat object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartLineFormat
     * @see {@link https://learn.microsoft.com/graph/api/chartlineformat-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChartLineFormat, requestConfiguration?: LineRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChartLineFormat | undefined>;
    /**
     * Delete navigation property line for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: LineRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chartlineformat object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LineRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of chartlineformat object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartLineFormat, requestConfiguration?: LineRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a lineRequestBuilder
     */
    withUrl(rawUrl: string): LineRequestBuilder;
}
