import { type WorkbookChartAxisTitleFormat } from '../../../../../../../../../../../../../models/workbookChartAxisTitleFormat';
import { FontRequestBuilder } from './font/fontRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface FormatRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface FormatRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface FormatRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: FormatRequestBuilderGetQueryParameters;
}
export interface FormatRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the format property of the microsoft.graph.workbookChartAxisTitle entity.
 */
export declare class FormatRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the font property of the microsoft.graph.workbookChartAxisTitleFormat entity.
     */
    get font(): FontRequestBuilder;
    /**
     * Instantiates a new FormatRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property format for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: FormatRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents the formatting of chart axis title. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxisTitleFormat
     */
    get(requestConfiguration?: FormatRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChartAxisTitleFormat | undefined>;
    /**
     * Update the navigation property format in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxisTitleFormat
     */
    patch(body: WorkbookChartAxisTitleFormat, requestConfiguration?: FormatRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChartAxisTitleFormat | undefined>;
    /**
     * Delete navigation property format for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: FormatRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the formatting of chart axis title. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: FormatRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property format in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAxisTitleFormat, requestConfiguration?: FormatRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a formatRequestBuilder
     */
    withUrl(rawUrl: string): FormatRequestBuilder;
}
