import { type WorkbookChartAxis } from '../../../../../../../../../../../models/workbookChartAxis';
import { FormatRequestBuilder } from './format/formatRequestBuilder';
import { MajorGridlinesRequestBuilder } from './majorGridlines/majorGridlinesRequestBuilder';
import { MinorGridlinesRequestBuilder } from './minorGridlines/minorGridlinesRequestBuilder';
import { TitleRequestBuilder } from './title/titleRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SeriesAxisRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SeriesAxisRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SeriesAxisRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SeriesAxisRequestBuilderGetQueryParameters;
}
export interface SeriesAxisRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the seriesAxis property of the microsoft.graph.workbookChartAxes entity.
 */
export declare class SeriesAxisRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChartAxis entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Provides operations to manage the majorGridlines property of the microsoft.graph.workbookChartAxis entity.
     */
    get majorGridlines(): MajorGridlinesRequestBuilder;
    /**
     * Provides operations to manage the minorGridlines property of the microsoft.graph.workbookChartAxis entity.
     */
    get minorGridlines(): MinorGridlinesRequestBuilder;
    /**
     * Provides operations to manage the title property of the microsoft.graph.workbookChartAxis entity.
     */
    get title(): TitleRequestBuilder;
    /**
     * Instantiates a new SeriesAxisRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property seriesAxis for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SeriesAxisRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents the series axis of a 3-dimensional chart. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxis
     */
    get(requestConfiguration?: SeriesAxisRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChartAxis | undefined>;
    /**
     * Update the navigation property seriesAxis in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxis
     */
    patch(body: WorkbookChartAxis, requestConfiguration?: SeriesAxisRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChartAxis | undefined>;
    /**
     * Delete navigation property seriesAxis for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SeriesAxisRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the series axis of a 3-dimensional chart. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SeriesAxisRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property seriesAxis in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAxis, requestConfiguration?: SeriesAxisRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a seriesAxisRequestBuilder
     */
    withUrl(rawUrl: string): SeriesAxisRequestBuilder;
}
