import { type WorkbookChartFill } from '../../../../../../../../../../../../models/workbookChartFill';
import { ClearRequestBuilder } from './clear/clearRequestBuilder';
import { SetSolidColorRequestBuilder } from './setSolidColor/setSolidColorRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface FillRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface FillRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface FillRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: FillRequestBuilderGetQueryParameters;
}
export interface FillRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the fill property of the microsoft.graph.workbookChartDataLabelFormat entity.
 */
export declare class FillRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clear method.
     */
    get clear(): ClearRequestBuilder;
    /**
     * Provides operations to call the setSolidColor method.
     */
    get setSolidColor(): SetSolidColorRequestBuilder;
    /**
     * Instantiates a new FillRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property fill for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: FillRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents the fill format of the current chart data label. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartFill
     */
    get(requestConfiguration?: FillRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChartFill | undefined>;
    /**
     * Update the navigation property fill in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartFill
     */
    patch(body: WorkbookChartFill, requestConfiguration?: FillRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChartFill | undefined>;
    /**
     * Delete navigation property fill for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: FillRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the fill format of the current chart data label. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: FillRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property fill in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartFill, requestConfiguration?: FillRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a fillRequestBuilder
     */
    withUrl(rawUrl: string): FillRequestBuilder;
}
