import { type WorkbookChart } from '../../../../../../../../../models/workbookChart';
import { AxesRequestBuilder } from './axes/axesRequestBuilder';
import { DataLabelsRequestBuilder } from './dataLabels/dataLabelsRequestBuilder';
import { FormatRequestBuilder } from './format/formatRequestBuilder';
import { ImageRequestBuilder } from './image/imageRequestBuilder';
import { ImageWithWidthRequestBuilder } from './imageWithWidth/imageWithWidthRequestBuilder';
import { ImageWithWidthWithHeightRequestBuilder } from './imageWithWidthWithHeight/imageWithWidthWithHeightRequestBuilder';
import { ImageWithWidthWithHeightWithFittingModeRequestBuilder } from './imageWithWidthWithHeightWithFittingMode/imageWithWidthWithHeightWithFittingModeRequestBuilder';
import { LegendRequestBuilder } from './legend/legendRequestBuilder';
import { SeriesRequestBuilder } from './series/seriesRequestBuilder';
import { SetDataRequestBuilder } from './setData/setDataRequestBuilder';
import { SetPositionRequestBuilder } from './setPosition/setPositionRequestBuilder';
import { TitleRequestBuilder } from './title/titleRequestBuilder';
import { WorksheetRequestBuilder } from './worksheet/worksheetRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorkbookChartItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WorkbookChartItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WorkbookChartItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorkbookChartItemRequestBuilderGetQueryParameters;
}
export interface WorkbookChartItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class WorkbookChartItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the axes property of the microsoft.graph.workbookChart entity.
     */
    get axes(): AxesRequestBuilder;
    /**
     * Provides operations to manage the dataLabels property of the microsoft.graph.workbookChart entity.
     */
    get dataLabels(): DataLabelsRequestBuilder;
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChart entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Provides operations to call the image method.
     */
    get image(): ImageRequestBuilder;
    /**
     * Provides operations to manage the legend property of the microsoft.graph.workbookChart entity.
     */
    get legend(): LegendRequestBuilder;
    /**
     * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
     */
    get series(): SeriesRequestBuilder;
    /**
     * Provides operations to call the setData method.
     */
    get setData(): SetDataRequestBuilder;
    /**
     * Provides operations to call the setPosition method.
     */
    get setPosition(): SetPositionRequestBuilder;
    /**
     * Provides operations to manage the title property of the microsoft.graph.workbookChart entity.
     */
    get title(): TitleRequestBuilder;
    /**
     * Provides operations to manage the worksheet property of the microsoft.graph.workbookChart entity.
     */
    get worksheet(): WorksheetRequestBuilder;
    /**
     * Instantiates a new WorkbookChartItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes the chart object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chart-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: WorkbookChartItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chart object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: WorkbookChartItemRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookChart | undefined>;
    /**
     * Provides operations to call the image method.
     * @param width Usage: width={width}
     * @returns a imageWithWidthRequestBuilder
     */
    imageWithWidth(width: number | undefined): ImageWithWidthRequestBuilder;
    /**
     * Provides operations to call the image method.
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightRequestBuilder
     */
    imageWithWidthWithHeight(height: number | undefined, width: number | undefined): ImageWithWidthWithHeightRequestBuilder;
    /**
     * Provides operations to call the image method.
     * @param fittingMode Usage: fittingMode='{fittingMode}'
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightWithFittingModeRequestBuilder
     */
    imageWithWidthWithHeightWithFittingMode(fittingMode: string | undefined, height: number | undefined, width: number | undefined): ImageWithWidthWithHeightWithFittingModeRequestBuilder;
    /**
     * Update the properties of chart object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChart, requestConfiguration?: WorkbookChartItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookChart | undefined>;
    /**
     * Deletes the chart object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WorkbookChartItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chart object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorkbookChartItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of chart object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChart, requestConfiguration?: WorkbookChartItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookChartItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookChartItemRequestBuilder;
}
