import { type WorkbookPivotTable } from '../../../../../../../../../models/workbookPivotTable';
import { RefreshRequestBuilder } from './refresh/refreshRequestBuilder';
import { WorksheetRequestBuilder } from './worksheet/worksheetRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorkbookPivotTableItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WorkbookPivotTableItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WorkbookPivotTableItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorkbookPivotTableItemRequestBuilderGetQueryParameters;
}
export interface WorkbookPivotTableItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the pivotTables property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class WorkbookPivotTableItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the refresh method.
     */
    get refresh(): RefreshRequestBuilder;
    /**
     * Provides operations to manage the worksheet property of the microsoft.graph.workbookPivotTable entity.
     */
    get worksheet(): WorksheetRequestBuilder;
    /**
     * Instantiates a new WorkbookPivotTableItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property pivotTables for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: WorkbookPivotTableItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of workbookPivotTable object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookPivotTable
     * @see {@link https://learn.microsoft.com/graph/api/workbookpivottable-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: WorkbookPivotTableItemRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookPivotTable | undefined>;
    /**
     * Update the navigation property pivotTables in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookPivotTable
     */
    patch(body: WorkbookPivotTable, requestConfiguration?: WorkbookPivotTableItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookPivotTable | undefined>;
    /**
     * Delete navigation property pivotTables for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WorkbookPivotTableItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of workbookPivotTable object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorkbookPivotTableItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property pivotTables in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookPivotTable, requestConfiguration?: WorkbookPivotTableItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookPivotTableItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookPivotTableItemRequestBuilder;
}
