import { type WorkbookWorksheetProtection } from '../../../../../../../../models/workbookWorksheetProtection';
import { ProtectRequestBuilder } from './protect/protectRequestBuilder';
import { UnprotectRequestBuilder } from './unprotect/unprotectRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ProtectionRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ProtectionRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ProtectionRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ProtectionRequestBuilderGetQueryParameters;
}
export interface ProtectionRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the protection property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class ProtectionRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the protect method.
     */
    get protect(): ProtectRequestBuilder;
    /**
     * Provides operations to call the unprotect method.
     */
    get unprotect(): UnprotectRequestBuilder;
    /**
     * Instantiates a new ProtectionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property protection for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ProtectionRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of worksheetprotection object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheetProtection
     * @see {@link https://learn.microsoft.com/graph/api/worksheetprotection-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ProtectionRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookWorksheetProtection | undefined>;
    /**
     * Update the navigation property protection in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheetProtection
     */
    patch(body: WorkbookWorksheetProtection, requestConfiguration?: ProtectionRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookWorksheetProtection | undefined>;
    /**
     * Delete navigation property protection for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ProtectionRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of worksheetprotection object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ProtectionRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property protection in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookWorksheetProtection, requestConfiguration?: ProtectionRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a protectionRequestBuilder
     */
    withUrl(rawUrl: string): ProtectionRequestBuilder;
}
