import { type ApplyPostRequestBody } from './applyPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ApplyRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the apply method.
 */
export declare class ApplyRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ApplyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Apply the given filter criteria on the given column. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/filter-apply?view=graph-rest-1.0|Find more info here}
     */
    post(body: ApplyPostRequestBody, requestConfiguration?: ApplyRequestBuilderPostRequestConfiguration | undefined): Promise<void>;
    /**
     * Apply the given filter criteria on the given column. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ApplyPostRequestBody, requestConfiguration?: ApplyRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a applyRequestBuilder
     */
    withUrl(rawUrl: string): ApplyRequestBuilder;
}
