import { type WorkbookTableColumn } from '../../../../../../../../../../../models/workbookTableColumn';
import { DataBodyRangeRequestBuilder } from './dataBodyRange/dataBodyRangeRequestBuilder';
import { FilterRequestBuilder } from './filter/filterRequestBuilder';
import { HeaderRowRangeRequestBuilder } from './headerRowRange/headerRowRangeRequestBuilder';
import { RangeRequestBuilder } from './range/rangeRequestBuilder';
import { TotalRowRangeRequestBuilder } from './totalRowRange/totalRowRangeRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorkbookTableColumnItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WorkbookTableColumnItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WorkbookTableColumnItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorkbookTableColumnItemRequestBuilderGetQueryParameters;
}
export interface WorkbookTableColumnItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the columns property of the microsoft.graph.workbookTable entity.
 */
export declare class WorkbookTableColumnItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the dataBodyRange method.
     */
    get dataBodyRange(): DataBodyRangeRequestBuilder;
    /**
     * Provides operations to manage the filter property of the microsoft.graph.workbookTableColumn entity.
     */
    get filter(): FilterRequestBuilder;
    /**
     * Provides operations to call the headerRowRange method.
     */
    get headerRowRange(): HeaderRowRangeRequestBuilder;
    /**
     * Provides operations to call the range method.
     */
    get range(): RangeRequestBuilder;
    /**
     * Provides operations to call the totalRowRange method.
     */
    get totalRowRange(): TotalRowRangeRequestBuilder;
    /**
     * Instantiates a new WorkbookTableColumnItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes the column from the table. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/tablecolumn-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: WorkbookTableColumnItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of tablecolumn object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableColumn
     * @see {@link https://learn.microsoft.com/graph/api/tablecolumn-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: WorkbookTableColumnItemRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookTableColumn | undefined>;
    /**
     * Update the properties of tablecolumn object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableColumn
     * @see {@link https://learn.microsoft.com/graph/api/tablecolumn-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookTableColumn, requestConfiguration?: WorkbookTableColumnItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookTableColumn | undefined>;
    /**
     * Deletes the column from the table. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WorkbookTableColumnItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of tablecolumn object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorkbookTableColumnItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of tablecolumn object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookTableColumn, requestConfiguration?: WorkbookTableColumnItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookTableColumnItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookTableColumnItemRequestBuilder;
}
