import { type WorkbookTable } from '../../../../../../../../../models/workbookTable';
import { ClearFiltersRequestBuilder } from './clearFilters/clearFiltersRequestBuilder';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ConvertToRangeRequestBuilder } from './convertToRange/convertToRangeRequestBuilder';
import { DataBodyRangeRequestBuilder } from './dataBodyRange/dataBodyRangeRequestBuilder';
import { HeaderRowRangeRequestBuilder } from './headerRowRange/headerRowRangeRequestBuilder';
import { RangeRequestBuilder } from './range/rangeRequestBuilder';
import { ReapplyFiltersRequestBuilder } from './reapplyFilters/reapplyFiltersRequestBuilder';
import { RowsRequestBuilder } from './rows/rowsRequestBuilder';
import { SortRequestBuilder } from './sort/sortRequestBuilder';
import { TotalRowRangeRequestBuilder } from './totalRowRange/totalRowRangeRequestBuilder';
import { WorksheetRequestBuilder } from './worksheet/worksheetRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorkbookTableItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WorkbookTableItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WorkbookTableItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorkbookTableItemRequestBuilderGetQueryParameters;
}
export interface WorkbookTableItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the tables property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class WorkbookTableItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clearFilters method.
     */
    get clearFilters(): ClearFiltersRequestBuilder;
    /**
     * Provides operations to manage the columns property of the microsoft.graph.workbookTable entity.
     */
    get columns(): ColumnsRequestBuilder;
    /**
     * Provides operations to call the convertToRange method.
     */
    get convertToRange(): ConvertToRangeRequestBuilder;
    /**
     * Provides operations to call the dataBodyRange method.
     */
    get dataBodyRange(): DataBodyRangeRequestBuilder;
    /**
     * Provides operations to call the headerRowRange method.
     */
    get headerRowRange(): HeaderRowRangeRequestBuilder;
    /**
     * Provides operations to call the range method.
     */
    get range(): RangeRequestBuilder;
    /**
     * Provides operations to call the reapplyFilters method.
     */
    get reapplyFilters(): ReapplyFiltersRequestBuilder;
    /**
     * Provides operations to manage the rows property of the microsoft.graph.workbookTable entity.
     */
    get rows(): RowsRequestBuilder;
    /**
     * Provides operations to manage the sort property of the microsoft.graph.workbookTable entity.
     */
    get sort(): SortRequestBuilder;
    /**
     * Provides operations to call the totalRowRange method.
     */
    get totalRowRange(): TotalRowRangeRequestBuilder;
    /**
     * Provides operations to manage the worksheet property of the microsoft.graph.workbookTable entity.
     */
    get worksheet(): WorksheetRequestBuilder;
    /**
     * Instantiates a new WorkbookTableItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property tables for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: WorkbookTableItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Collection of tables that are part of the worksheet. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTable
     */
    get(requestConfiguration?: WorkbookTableItemRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookTable | undefined>;
    /**
     * Update the navigation property tables in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTable
     */
    patch(body: WorkbookTable, requestConfiguration?: WorkbookTableItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WorkbookTable | undefined>;
    /**
     * Delete navigation property tables for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WorkbookTableItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Collection of tables that are part of the worksheet. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorkbookTableItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property tables in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookTable, requestConfiguration?: WorkbookTableItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookTableItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookTableItemRequestBuilder;
}
