import { type WorkbookWorksheetCollectionResponse } from '../../../../../../models/';
import { type WorkbookWorksheet } from '../../../../../../models/workbookWorksheet';
import { AddRequestBuilder } from './add/addRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { WorkbookWorksheetItemRequestBuilder } from './item/workbookWorksheetItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WorksheetsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface WorksheetsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WorksheetsRequestBuilderGetQueryParameters;
}
export interface WorksheetsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
 */
export declare class WorksheetsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add(): AddRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
     * @param workbookWorksheetId The unique identifier of workbookWorksheet
     * @returns a WorkbookWorksheetItemRequestBuilder
     */
    byWorkbookWorksheetId(workbookWorksheetId: string): WorkbookWorksheetItemRequestBuilder;
    /**
     * Instantiates a new WorksheetsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of worksheet objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheetCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/workbook-list-worksheets?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: WorksheetsRequestBuilderGetRequestConfiguration | undefined): Promise<WorkbookWorksheetCollectionResponse | undefined>;
    /**
     * Create new navigation property to worksheets for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheet
     */
    post(body: WorkbookWorksheet, requestConfiguration?: WorksheetsRequestBuilderPostRequestConfiguration | undefined): Promise<WorkbookWorksheet | undefined>;
    /**
     * Retrieve a list of worksheet objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WorksheetsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to worksheets for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookWorksheet, requestConfiguration?: WorksheetsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a worksheetsRequestBuilder
     */
    withUrl(rawUrl: string): WorksheetsRequestBuilder;
}
