import { type DocumentSetVersionCollectionResponse } from '../../../../../../models/';
import { type DocumentSetVersion } from '../../../../../../models/documentSetVersion';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DocumentSetVersionItemRequestBuilder } from './item/documentSetVersionItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DocumentSetVersionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DocumentSetVersionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DocumentSetVersionsRequestBuilderGetQueryParameters;
}
export interface DocumentSetVersionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the documentSetVersions property of the microsoft.graph.listItem entity.
 */
export declare class DocumentSetVersionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the documentSetVersions property of the microsoft.graph.listItem entity.
     * @param documentSetVersionId The unique identifier of documentSetVersion
     * @returns a DocumentSetVersionItemRequestBuilder
     */
    byDocumentSetVersionId(documentSetVersionId: string): DocumentSetVersionItemRequestBuilder;
    /**
     * Instantiates a new DocumentSetVersionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the versions of a document set item in a list. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DocumentSetVersionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/listitem-list-documentsetversions?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: DocumentSetVersionsRequestBuilderGetRequestConfiguration | undefined): Promise<DocumentSetVersionCollectionResponse | undefined>;
    /**
     * Create a new version of a document set item in a list. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DocumentSetVersion
     * @see {@link https://learn.microsoft.com/graph/api/listitem-post-documentsetversions?view=graph-rest-1.0|Find more info here}
     */
    post(body: DocumentSetVersion, requestConfiguration?: DocumentSetVersionsRequestBuilderPostRequestConfiguration | undefined): Promise<DocumentSetVersion | undefined>;
    /**
     * Get a list of the versions of a document set item in a list. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DocumentSetVersionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new version of a document set item in a list. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DocumentSetVersion, requestConfiguration?: DocumentSetVersionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a documentSetVersionsRequestBuilder
     */
    withUrl(rawUrl: string): DocumentSetVersionsRequestBuilder;
}
