import { type EducationAssignmentSettings } from '../../../../models/educationAssignmentSettings';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AssignmentSettingsRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AssignmentSettingsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AssignmentSettingsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AssignmentSettingsRequestBuilderGetQueryParameters;
}
export interface AssignmentSettingsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the assignmentSettings property of the microsoft.graph.educationClass entity.
 */
export declare class AssignmentSettingsRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AssignmentSettingsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignmentSettings for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AssignmentSettingsRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Specifies class-level assignments settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignmentSettings
     */
    get(requestConfiguration?: AssignmentSettingsRequestBuilderGetRequestConfiguration | undefined): Promise<EducationAssignmentSettings | undefined>;
    /**
     * Update the properties of an educationAssignmentSettings object. Only teachers can update these settings. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignmentSettings
     * @see {@link https://learn.microsoft.com/graph/api/educationassignmentsettings-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EducationAssignmentSettings, requestConfiguration?: AssignmentSettingsRequestBuilderPatchRequestConfiguration | undefined): Promise<EducationAssignmentSettings | undefined>;
    /**
     * Delete navigation property assignmentSettings for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AssignmentSettingsRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Specifies class-level assignments settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AssignmentSettingsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an educationAssignmentSettings object. Only teachers can update these settings. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationAssignmentSettings, requestConfiguration?: AssignmentSettingsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a assignmentSettingsRequestBuilder
     */
    withUrl(rawUrl: string): AssignmentSettingsRequestBuilder;
}
