import { type EducationAssignment } from '../../../../../models/educationAssignment';
import { CategoriesRequestBuilder } from './categories/categoriesRequestBuilder';
import { PublishRequestBuilder } from './publish/publishRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { RubricRequestBuilder } from './rubric/rubricRequestBuilder';
import { SetUpFeedbackResourcesFolderRequestBuilder } from './setUpFeedbackResourcesFolder/setUpFeedbackResourcesFolderRequestBuilder';
import { SetUpResourcesFolderRequestBuilder } from './setUpResourcesFolder/setUpResourcesFolderRequestBuilder';
import { SubmissionsRequestBuilder } from './submissions/submissionsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EducationAssignmentItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface EducationAssignmentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface EducationAssignmentItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EducationAssignmentItemRequestBuilderGetQueryParameters;
}
export interface EducationAssignmentItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the assignments property of the microsoft.graph.educationClass entity.
 */
export declare class EducationAssignmentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the categories property of the microsoft.graph.educationAssignment entity.
     */
    get categories(): CategoriesRequestBuilder;
    /**
     * Provides operations to call the publish method.
     */
    get publish(): PublishRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.educationAssignment entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to manage the rubric property of the microsoft.graph.educationAssignment entity.
     */
    get rubric(): RubricRequestBuilder;
    /**
     * Provides operations to call the setUpFeedbackResourcesFolder method.
     */
    get setUpFeedbackResourcesFolder(): SetUpFeedbackResourcesFolderRequestBuilder;
    /**
     * Provides operations to call the setUpResourcesFolder method.
     */
    get setUpResourcesFolder(): SetUpResourcesFolderRequestBuilder;
    /**
     * Provides operations to manage the submissions property of the microsoft.graph.educationAssignment entity.
     */
    get submissions(): SubmissionsRequestBuilder;
    /**
     * Instantiates a new EducationAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an existing assignment. Only teachers within a class can delete assignments. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/educationassignment-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: EducationAssignmentItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of an assignment. Only teachers, students, and applications with application permissions can perform this operation. Students can only see assignments assigned to them; teachers and applications with application permissions can see all assignments in a class. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignment
     * @see {@link https://learn.microsoft.com/graph/api/educationassignment-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: EducationAssignmentItemRequestBuilderGetRequestConfiguration | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Update an educationAssignment object.  Only teachers can perform this action.  Alternatively, request to change the status of an assignment with publish action. Don't use a PATCH operation for this purpose. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignment
     * @see {@link https://learn.microsoft.com/graph/api/educationassignment-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EducationAssignment, requestConfiguration?: EducationAssignmentItemRequestBuilderPatchRequestConfiguration | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Delete an existing assignment. Only teachers within a class can delete assignments. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: EducationAssignmentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of an assignment. Only teachers, students, and applications with application permissions can perform this operation. Students can only see assignments assigned to them; teachers and applications with application permissions can see all assignments in a class. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EducationAssignmentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update an educationAssignment object.  Only teachers can perform this action.  Alternatively, request to change the status of an assignment with publish action. Don't use a PATCH operation for this purpose. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationAssignment, requestConfiguration?: EducationAssignmentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationAssignmentItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationAssignmentItemRequestBuilder;
}
