import { type EducationClass } from '../../../models/educationClass';
import { AssignmentCategoriesRequestBuilder } from './assignmentCategories/assignmentCategoriesRequestBuilder';
import { AssignmentDefaultsRequestBuilder } from './assignmentDefaults/assignmentDefaultsRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { AssignmentSettingsRequestBuilder } from './assignmentSettings/assignmentSettingsRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { SchoolsRequestBuilder } from './schools/schoolsRequestBuilder';
import { TeachersRequestBuilder } from './teachers/teachersRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EducationClassItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface EducationClassItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface EducationClassItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EducationClassItemRequestBuilderGetQueryParameters;
}
export interface EducationClassItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the classes property of the microsoft.graph.educationRoot entity.
 */
export declare class EducationClassItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignmentCategories property of the microsoft.graph.educationClass entity.
     */
    get assignmentCategories(): AssignmentCategoriesRequestBuilder;
    /**
     * Provides operations to manage the assignmentDefaults property of the microsoft.graph.educationClass entity.
     */
    get assignmentDefaults(): AssignmentDefaultsRequestBuilder;
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.educationClass entity.
     */
    get assignments(): AssignmentsRequestBuilder;
    /**
     * Provides operations to manage the assignmentSettings property of the microsoft.graph.educationClass entity.
     */
    get assignmentSettings(): AssignmentSettingsRequestBuilder;
    /**
     * Provides operations to manage the group property of the microsoft.graph.educationClass entity.
     */
    get group(): GroupRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.educationClass entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the schools property of the microsoft.graph.educationClass entity.
     */
    get schools(): SchoolsRequestBuilder;
    /**
     * Provides operations to manage the teachers property of the microsoft.graph.educationClass entity.
     */
    get teachers(): TeachersRequestBuilder;
    /**
     * Instantiates a new EducationClassItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an educationClass. Because a class is also a universal group, deleting a class deletes the group. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/educationclass-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: EducationClassItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve a class from the system. A class is a universal group with a special property that indicates to the system that the group is a class. Group members represent the students; group admins represent the teachers in the class. If you're using the delegated token, the user will only see classes in which they are members. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationClass
     * @see {@link https://learn.microsoft.com/graph/api/educationclass-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: EducationClassItemRequestBuilderGetRequestConfiguration | undefined): Promise<EducationClass | undefined>;
    /**
     * Update the properties of an educationClass object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationClass
     * @see {@link https://learn.microsoft.com/graph/api/educationclass-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EducationClass, requestConfiguration?: EducationClassItemRequestBuilderPatchRequestConfiguration | undefined): Promise<EducationClass | undefined>;
    /**
     * Delete an educationClass. Because a class is also a universal group, deleting a class deletes the group. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: EducationClassItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a class from the system. A class is a universal group with a special property that indicates to the system that the group is a class. Group members represent the students; group admins represent the teachers in the class. If you're using the delegated token, the user will only see classes in which they are members. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EducationClassItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an educationClass object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationClass, requestConfiguration?: EducationClassItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationClassItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationClassItemRequestBuilder;
}
