import { type EducationSubmission } from '../../../../../../models/educationSubmission';
import { OutcomesRequestBuilder } from './outcomes/outcomesRequestBuilder';
import { ReassignRequestBuilder } from './reassign/reassignRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { ReturnRequestBuilder } from './returnEscaped/returnRequestBuilder';
import { SetUpResourcesFolderRequestBuilder } from './setUpResourcesFolder/setUpResourcesFolderRequestBuilder';
import { SubmitRequestBuilder } from './submit/submitRequestBuilder';
import { SubmittedResourcesRequestBuilder } from './submittedResources/submittedResourcesRequestBuilder';
import { UnsubmitRequestBuilder } from './unsubmit/unsubmitRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EducationSubmissionItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface EducationSubmissionItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface EducationSubmissionItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EducationSubmissionItemRequestBuilderGetQueryParameters;
}
export interface EducationSubmissionItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the submissions property of the microsoft.graph.educationAssignment entity.
 */
export declare class EducationSubmissionItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the outcomes property of the microsoft.graph.educationSubmission entity.
     */
    get outcomes(): OutcomesRequestBuilder;
    /**
     * Provides operations to call the reassign method.
     */
    get reassign(): ReassignRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.educationSubmission entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to call the return method.
     */
    get returnEscaped(): ReturnRequestBuilder;
    /**
     * Provides operations to call the setUpResourcesFolder method.
     */
    get setUpResourcesFolder(): SetUpResourcesFolderRequestBuilder;
    /**
     * Provides operations to call the submit method.
     */
    get submit(): SubmitRequestBuilder;
    /**
     * Provides operations to manage the submittedResources property of the microsoft.graph.educationSubmission entity.
     */
    get submittedResources(): SubmittedResourcesRequestBuilder;
    /**
     * Provides operations to call the unsubmit method.
     */
    get unsubmit(): UnsubmitRequestBuilder;
    /**
     * Instantiates a new EducationSubmissionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property submissions for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: EducationSubmissionItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve a particular submission. Only teachers, students, and applications with application permissions can perform this operation. A submission object represents a student's work for an assignment. Resources associated with the submission represent this work. Only the assignedTo student can see and modify the submission. A teacher or application with application permissions has full access to all submissions. The grade and feedback from a teacher are part of the educationOutcome associated with this object. Only teachers or applications with application permissions can add or change grades and feedback. Students will not see the grade or feedback until the assignment has been released. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSubmission
     * @see {@link https://learn.microsoft.com/graph/api/educationsubmission-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: EducationSubmissionItemRequestBuilderGetRequestConfiguration | undefined): Promise<EducationSubmission | undefined>;
    /**
     * Update the navigation property submissions in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSubmission
     */
    patch(body: EducationSubmission, requestConfiguration?: EducationSubmissionItemRequestBuilderPatchRequestConfiguration | undefined): Promise<EducationSubmission | undefined>;
    /**
     * Delete navigation property submissions for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: EducationSubmissionItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a particular submission. Only teachers, students, and applications with application permissions can perform this operation. A submission object represents a student's work for an assignment. Resources associated with the submission represent this work. Only the assignedTo student can see and modify the submission. A teacher or application with application permissions has full access to all submissions. The grade and feedback from a teacher are part of the educationOutcome associated with this object. Only teachers or applications with application permissions can add or change grades and feedback. Students will not see the grade or feedback until the assignment has been released. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EducationSubmissionItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property submissions in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationSubmission, requestConfiguration?: EducationSubmissionItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationSubmissionItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationSubmissionItemRequestBuilder;
}
