import { type AdministrativeUnit } from '../../../../models/administrativeUnit';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AdministrativeUnitRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AdministrativeUnitRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AdministrativeUnitRequestBuilderGetQueryParameters;
}
export interface AdministrativeUnitRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the administrativeUnit property of the microsoft.graph.educationSchool entity.
 */
export declare class AdministrativeUnitRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AdministrativeUnitRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of administrativeUnits associated with an educationSchool object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AdministrativeUnit
     * @see {@link https://learn.microsoft.com/graph/api/educationschool-list-administrativeunit?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AdministrativeUnitRequestBuilderGetRequestConfiguration | undefined): Promise<AdministrativeUnit | undefined>;
    /**
     * Update the navigation property administrativeUnit in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AdministrativeUnit
     */
    patch(body: AdministrativeUnit, requestConfiguration?: AdministrativeUnitRequestBuilderPatchRequestConfiguration | undefined): Promise<AdministrativeUnit | undefined>;
    /**
     * Get a list of administrativeUnits associated with an educationSchool object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AdministrativeUnitRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property administrativeUnit in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AdministrativeUnit, requestConfiguration?: AdministrativeUnitRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a administrativeUnitRequestBuilder
     */
    withUrl(rawUrl: string): AdministrativeUnitRequestBuilder;
}
