import { type LearningProvider } from '../../../models/learningProvider';
import { LearningContentsRequestBuilder } from './learningContents/learningContentsRequestBuilder';
import { LearningCourseActivitiesRequestBuilder } from './learningCourseActivities/learningCourseActivitiesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LearningProviderItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface LearningProviderItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface LearningProviderItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LearningProviderItemRequestBuilderGetQueryParameters;
}
export interface LearningProviderItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the learningProviders property of the microsoft.graph.employeeExperience entity.
 */
export declare class LearningProviderItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the learningContents property of the microsoft.graph.learningProvider entity.
     */
    get learningContents(): LearningContentsRequestBuilder;
    /**
     * Provides operations to manage the learningCourseActivities property of the microsoft.graph.learningProvider entity.
     */
    get learningCourseActivities(): LearningCourseActivitiesRequestBuilder;
    /**
     * Instantiates a new LearningProviderItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a learningProvider resource and remove its registration in Viva Learning for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/employeeexperience-delete-learningproviders?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: LearningProviderItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a learningProvider object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LearningProvider
     * @see {@link https://learn.microsoft.com/graph/api/learningprovider-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: LearningProviderItemRequestBuilderGetRequestConfiguration | undefined): Promise<LearningProvider | undefined>;
    /**
     * Update the properties of a learningProvider object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LearningProvider
     * @see {@link https://learn.microsoft.com/graph/api/learningprovider-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: LearningProvider, requestConfiguration?: LearningProviderItemRequestBuilderPatchRequestConfiguration | undefined): Promise<LearningProvider | undefined>;
    /**
     * Delete a learningProvider resource and remove its registration in Viva Learning for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: LearningProviderItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a learningProvider object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LearningProviderItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a learningProvider object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: LearningProvider, requestConfiguration?: LearningProviderItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a LearningProviderItemRequestBuilder
     */
    withUrl(rawUrl: string): LearningProviderItemRequestBuilder;
}
