import { type GroupLifecyclePolicy } from '../../../../models/groupLifecyclePolicy';
import { AddGroupRequestBuilder } from './addGroup/addGroupRequestBuilder';
import { RemoveGroupRequestBuilder } from './removeGroup/removeGroupRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface GroupLifecyclePolicyItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface GroupLifecyclePolicyItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface GroupLifecyclePolicyItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: GroupLifecyclePolicyItemRequestBuilderGetQueryParameters;
}
export interface GroupLifecyclePolicyItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the groupLifecyclePolicies property of the microsoft.graph.group entity.
 */
export declare class GroupLifecyclePolicyItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the addGroup method.
     */
    get addGroup(): AddGroupRequestBuilder;
    /**
     * Provides operations to call the removeGroup method.
     */
    get removeGroup(): RemoveGroupRequestBuilder;
    /**
     * Instantiates a new GroupLifecyclePolicyItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property groupLifecyclePolicies for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The collection of lifecycle policies for this group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GroupLifecyclePolicy
     */
    get(requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderGetRequestConfiguration | undefined): Promise<GroupLifecyclePolicy | undefined>;
    /**
     * Update the navigation property groupLifecyclePolicies in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GroupLifecyclePolicy
     */
    patch(body: GroupLifecyclePolicy, requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderPatchRequestConfiguration | undefined): Promise<GroupLifecyclePolicy | undefined>;
    /**
     * Delete navigation property groupLifecyclePolicies for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The collection of lifecycle policies for this group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property groupLifecyclePolicies in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: GroupLifecyclePolicy, requestConfiguration?: GroupLifecyclePolicyItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a GroupLifecyclePolicyItemRequestBuilder
     */
    withUrl(rawUrl: string): GroupLifecyclePolicyItemRequestBuilder;
}
