"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SectionsRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const onenoteSection_1 = require("../../../../../../models/onenoteSection");
const onenoteSectionCollectionResponse_1 = require("../../../../../../models/onenoteSectionCollectionResponse");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const onenoteSectionItemRequestBuilder_1 = require("./item/onenoteSectionItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the sections property of the microsoft.graph.notebook entity.
 */
class SectionsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the sections property of the microsoft.graph.notebook entity.
     * @param onenoteSectionId The unique identifier of onenoteSection
     * @returns a OnenoteSectionItemRequestBuilder
     */
    byOnenoteSectionId(onenoteSectionId) {
        if (!onenoteSectionId)
            throw new Error("onenoteSectionId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteSection%2Did"] = onenoteSectionId;
        return new onenoteSectionItemRequestBuilder_1.OnenoteSectionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new SectionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groups/{group%2Did}/onenote/notebooks/{notebook%2Did}/sections{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Retrieve a list of onenoteSection objects from the specified notebook. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenoteSectionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/notebook-list-sections?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, onenoteSectionCollectionResponse_1.createOnenoteSectionCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create a new onenoteSection in the specified notebook. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenoteSection
     * @see {@link https://learn.microsoft.com/graph/api/notebook-post-sections?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, onenoteSection_1.createOnenoteSectionFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve a list of onenoteSection objects from the specified notebook. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create a new onenoteSection in the specified notebook. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, onenoteSection_1.serializeOnenoteSection);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sectionsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SectionsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SectionsRequestBuilder = SectionsRequestBuilder;
// tslint:enable
// eslint-enable
