import { type PlannerTask } from '../../../../../../../../../models/plannerTask';
import { AssignedToTaskBoardFormatRequestBuilder } from './assignedToTaskBoardFormat/assignedToTaskBoardFormatRequestBuilder';
import { BucketTaskBoardFormatRequestBuilder } from './bucketTaskBoardFormat/bucketTaskBoardFormatRequestBuilder';
import { DetailsRequestBuilder } from './details/detailsRequestBuilder';
import { ProgressTaskBoardFormatRequestBuilder } from './progressTaskBoardFormat/progressTaskBoardFormatRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PlannerTaskItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PlannerTaskItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PlannerTaskItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PlannerTaskItemRequestBuilderGetQueryParameters;
}
export interface PlannerTaskItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the tasks property of the microsoft.graph.plannerBucket entity.
 */
export declare class PlannerTaskItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignedToTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get assignedToTaskBoardFormat(): AssignedToTaskBoardFormatRequestBuilder;
    /**
     * Provides operations to manage the bucketTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get bucketTaskBoardFormat(): BucketTaskBoardFormatRequestBuilder;
    /**
     * Provides operations to manage the details property of the microsoft.graph.plannerTask entity.
     */
    get details(): DetailsRequestBuilder;
    /**
     * Provides operations to manage the progressTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get progressTaskBoardFormat(): ProgressTaskBoardFormatRequestBuilder;
    /**
     * Instantiates a new PlannerTaskItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property tasks for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PlannerTaskItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read-only. Nullable. The collection of tasks in the bucket.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTask
     */
    get(requestConfiguration?: PlannerTaskItemRequestBuilderGetRequestConfiguration | undefined): Promise<PlannerTask | undefined>;
    /**
     * Update the navigation property tasks in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTask
     */
    patch(body: PlannerTask, requestConfiguration?: PlannerTaskItemRequestBuilderPatchRequestConfiguration | undefined): Promise<PlannerTask | undefined>;
    /**
     * Delete navigation property tasks for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PlannerTaskItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read-only. Nullable. The collection of tasks in the bucket.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PlannerTaskItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property tasks in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PlannerTask, requestConfiguration?: PlannerTaskItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PlannerTaskItemRequestBuilder
     */
    withUrl(rawUrl: string): PlannerTaskItemRequestBuilder;
}
