import { type ContentTypeCollectionResponse } from '../../../../../models/';
import { type ContentType } from '../../../../../models/contentType';
import { AddCopyRequestBuilder } from './addCopy/addCopyRequestBuilder';
import { AddCopyFromContentTypeHubRequestBuilder } from './addCopyFromContentTypeHub/addCopyFromContentTypeHubRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { GetCompatibleHubContentTypesRequestBuilder } from './getCompatibleHubContentTypes/getCompatibleHubContentTypesRequestBuilder';
import { ContentTypeItemRequestBuilder } from './item/contentTypeItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ContentTypesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ContentTypesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ContentTypesRequestBuilderGetQueryParameters;
}
export interface ContentTypesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the contentTypes property of the microsoft.graph.site entity.
 */
export declare class ContentTypesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the addCopy method.
     */
    get addCopy(): AddCopyRequestBuilder;
    /**
     * Provides operations to call the addCopyFromContentTypeHub method.
     */
    get addCopyFromContentTypeHub(): AddCopyFromContentTypeHubRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the getCompatibleHubContentTypes method.
     */
    get getCompatibleHubContentTypes(): GetCompatibleHubContentTypesRequestBuilder;
    /**
     * Provides operations to manage the contentTypes property of the microsoft.graph.site entity.
     * @param contentTypeId The unique identifier of contentType
     * @returns a ContentTypeItemRequestBuilder
     */
    byContentTypeId(contentTypeId: string): ContentTypeItemRequestBuilder;
    /**
     * Instantiates a new ContentTypesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the collection of contentType][contentType] resources in a [site][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentTypeCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/site-list-contenttypes?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ContentTypesRequestBuilderGetRequestConfiguration | undefined): Promise<ContentTypeCollectionResponse | undefined>;
    /**
     * Create a new contentType][] in a [site][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     * @see {@link https://learn.microsoft.com/graph/api/site-post-contenttypes?view=graph-rest-1.0|Find more info here}
     */
    post(body: ContentType, requestConfiguration?: ContentTypesRequestBuilderPostRequestConfiguration | undefined): Promise<ContentType | undefined>;
    /**
     * Get the collection of contentType][contentType] resources in a [site][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ContentTypesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new contentType][] in a [site][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ContentType, requestConfiguration?: ContentTypesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a contentTypesRequestBuilder
     */
    withUrl(rawUrl: string): ContentTypesRequestBuilder;
}
