import { type ContentType } from '../../../../../../models/contentType';
import { AssociateWithHubSitesRequestBuilder } from './associateWithHubSites/associateWithHubSitesRequestBuilder';
import { BaseRequestBuilderEscaped } from './base/baseRequestBuilderEscaped';
import { BaseTypesRequestBuilder } from './baseTypes/baseTypesRequestBuilder';
import { ColumnLinksRequestBuilder } from './columnLinks/columnLinksRequestBuilder';
import { ColumnPositionsRequestBuilder } from './columnPositions/columnPositionsRequestBuilder';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { CopyToDefaultContentLocationRequestBuilder } from './copyToDefaultContentLocation/copyToDefaultContentLocationRequestBuilder';
import { IsPublishedRequestBuilder } from './isPublished/isPublishedRequestBuilder';
import { PublishRequestBuilder } from './publish/publishRequestBuilder';
import { UnpublishRequestBuilder } from './unpublish/unpublishRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ContentTypeItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ContentTypeItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ContentTypeItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ContentTypeItemRequestBuilderGetQueryParameters;
}
export interface ContentTypeItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the contentTypes property of the microsoft.graph.site entity.
 */
export declare class ContentTypeItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the associateWithHubSites method.
     */
    get associateWithHubSites(): AssociateWithHubSitesRequestBuilder;
    /**
     * Provides operations to manage the base property of the microsoft.graph.contentType entity.
     */
    get base(): BaseRequestBuilderEscaped;
    /**
     * Provides operations to manage the baseTypes property of the microsoft.graph.contentType entity.
     */
    get baseTypes(): BaseTypesRequestBuilder;
    /**
     * Provides operations to manage the columnLinks property of the microsoft.graph.contentType entity.
     */
    get columnLinks(): ColumnLinksRequestBuilder;
    /**
     * Provides operations to manage the columnPositions property of the microsoft.graph.contentType entity.
     */
    get columnPositions(): ColumnPositionsRequestBuilder;
    /**
     * Provides operations to manage the columns property of the microsoft.graph.contentType entity.
     */
    get columns(): ColumnsRequestBuilder;
    /**
     * Provides operations to call the copyToDefaultContentLocation method.
     */
    get copyToDefaultContentLocation(): CopyToDefaultContentLocationRequestBuilder;
    /**
     * Provides operations to call the isPublished method.
     */
    get isPublished(): IsPublishedRequestBuilder;
    /**
     * Provides operations to call the publish method.
     */
    get publish(): PublishRequestBuilder;
    /**
     * Provides operations to call the unpublish method.
     */
    get unpublish(): UnpublishRequestBuilder;
    /**
     * Instantiates a new ContentTypeItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Remove a content type][contentType] from a [list][] or a [site][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/contenttype-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: ContentTypeItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the metadata for a content type][contentType] in a [site][] or a [list][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     * @see {@link https://learn.microsoft.com/graph/api/contenttype-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ContentTypeItemRequestBuilderGetRequestConfiguration | undefined): Promise<ContentType | undefined>;
    /**
     * Update a content type][contentType]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     * @see {@link https://learn.microsoft.com/graph/api/contenttype-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ContentType, requestConfiguration?: ContentTypeItemRequestBuilderPatchRequestConfiguration | undefined): Promise<ContentType | undefined>;
    /**
     * Remove a content type][contentType] from a [list][] or a [site][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ContentTypeItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the metadata for a content type][contentType] in a [site][] or a [list][]. This API is available in the following [national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ContentTypeItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update a content type][contentType]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ContentType, requestConfiguration?: ContentTypeItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ContentTypeItemRequestBuilder
     */
    withUrl(rawUrl: string): ContentTypeItemRequestBuilder;
}
