import { type FieldValueSet } from '../../../../../../../../../models/fieldValueSet';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface FieldsRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface FieldsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface FieldsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: FieldsRequestBuilderGetQueryParameters;
}
export interface FieldsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the fields property of the microsoft.graph.listItem entity.
 */
export declare class FieldsRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new FieldsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property fields for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: FieldsRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The values of the columns set on this list item.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FieldValueSet
     */
    get(requestConfiguration?: FieldsRequestBuilderGetRequestConfiguration | undefined): Promise<FieldValueSet | undefined>;
    /**
     * Update the properties on a listItem][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FieldValueSet
     * @see {@link https://learn.microsoft.com/graph/api/listitem-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: FieldValueSet, requestConfiguration?: FieldsRequestBuilderPatchRequestConfiguration | undefined): Promise<FieldValueSet | undefined>;
    /**
     * Delete navigation property fields for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: FieldsRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The values of the columns set on this list item.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: FieldsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties on a listItem][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: FieldValueSet, requestConfiguration?: FieldsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a fieldsRequestBuilder
     */
    withUrl(rawUrl: string): FieldsRequestBuilder;
}
