import { type List } from '../../../../../../models/list';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ContentTypesRequestBuilder } from './contentTypes/contentTypesRequestBuilder';
import { CreatedByUserRequestBuilder } from './createdByUser/createdByUserRequestBuilder';
import { DriveRequestBuilder } from './drive/driveRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { LastModifiedByUserRequestBuilder } from './lastModifiedByUser/lastModifiedByUserRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ListItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ListItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ListItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ListItemRequestBuilderGetQueryParameters;
}
export interface ListItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the lists property of the microsoft.graph.site entity.
 */
export declare class ListItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the columns property of the microsoft.graph.list entity.
     */
    get columns(): ColumnsRequestBuilder;
    /**
     * Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
     */
    get contentTypes(): ContentTypesRequestBuilder;
    /**
     * Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
     */
    get createdByUser(): CreatedByUserRequestBuilder;
    /**
     * Provides operations to manage the drive property of the microsoft.graph.list entity.
     */
    get drive(): DriveRequestBuilder;
    /**
     * Provides operations to manage the items property of the microsoft.graph.list entity.
     */
    get items(): ItemsRequestBuilder;
    /**
     * Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
     */
    get lastModifiedByUser(): LastModifiedByUserRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.list entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the subscriptions property of the microsoft.graph.list entity.
     */
    get subscriptions(): SubscriptionsRequestBuilder;
    /**
     * Instantiates a new ListItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property lists for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ListItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get a list of rich long-running operations associated with a list. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of List
     * @see {@link https://learn.microsoft.com/graph/api/list-list-operations?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ListItemRequestBuilderGetRequestConfiguration | undefined): Promise<List | undefined>;
    /**
     * Update the navigation property lists in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of List
     */
    patch(body: List, requestConfiguration?: ListItemRequestBuilderPatchRequestConfiguration | undefined): Promise<List | undefined>;
    /**
     * Delete navigation property lists for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ListItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get a list of rich long-running operations associated with a list. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ListItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property lists in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: List, requestConfiguration?: ListItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ListItemRequestBuilder
     */
    withUrl(rawUrl: string): ListItemRequestBuilder;
}
