import { type IdentityApiConnector } from '../../../../../models/identityApiConnector';
import { RefRequestBuilder } from './ref/refRequestBuilder';
import { UploadClientCertificateRequestBuilder } from './uploadClientCertificate/uploadClientCertificateRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PostAttributeCollectionRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PostAttributeCollectionRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PostAttributeCollectionRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PostAttributeCollectionRequestBuilderGetQueryParameters;
}
export interface PostAttributeCollectionRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the postAttributeCollection property of the microsoft.graph.userFlowApiConnectorConfiguration entity.
 */
export declare class PostAttributeCollectionRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the collection of identityContainer entities.
     */
    get ref(): RefRequestBuilder;
    /**
     * Provides operations to call the uploadClientCertificate method.
     */
    get uploadClientCertificate(): UploadClientCertificateRequestBuilder;
    /**
     * Instantiates a new PostAttributeCollectionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property postAttributeCollection for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PostAttributeCollectionRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get postAttributeCollection from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     */
    get(requestConfiguration?: PostAttributeCollectionRequestBuilderGetRequestConfiguration | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Update the navigation property postAttributeCollection in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     */
    patch(body: IdentityApiConnector, requestConfiguration?: PostAttributeCollectionRequestBuilderPatchRequestConfiguration | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Delete navigation property postAttributeCollection for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PostAttributeCollectionRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get postAttributeCollection from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PostAttributeCollectionRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property postAttributeCollection in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityApiConnector, requestConfiguration?: PostAttributeCollectionRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a postAttributeCollectionRequestBuilder
     */
    withUrl(rawUrl: string): PostAttributeCollectionRequestBuilder;
}
