import { type IdentityApiConnector } from '../../../../../models/identityApiConnector';
import { RefRequestBuilder } from './ref/refRequestBuilder';
import { UploadClientCertificateRequestBuilder } from './uploadClientCertificate/uploadClientCertificateRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PostFederationSignupRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PostFederationSignupRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PostFederationSignupRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PostFederationSignupRequestBuilderGetQueryParameters;
}
export interface PostFederationSignupRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the postFederationSignup property of the microsoft.graph.userFlowApiConnectorConfiguration entity.
 */
export declare class PostFederationSignupRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the collection of identityContainer entities.
     */
    get ref(): RefRequestBuilder;
    /**
     * Provides operations to call the uploadClientCertificate method.
     */
    get uploadClientCertificate(): UploadClientCertificateRequestBuilder;
    /**
     * Instantiates a new PostFederationSignupRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property postFederationSignup for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PostFederationSignupRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get postFederationSignup from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     */
    get(requestConfiguration?: PostFederationSignupRequestBuilderGetRequestConfiguration | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Update the navigation property postFederationSignup in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     */
    patch(body: IdentityApiConnector, requestConfiguration?: PostFederationSignupRequestBuilderPatchRequestConfiguration | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Delete navigation property postFederationSignup for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PostFederationSignupRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get postFederationSignup from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PostFederationSignupRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property postFederationSignup in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityApiConnector, requestConfiguration?: PostFederationSignupRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a postFederationSignupRequestBuilder
     */
    withUrl(rawUrl: string): PostFederationSignupRequestBuilder;
}
