import { type UserFlowLanguageConfigurationCollectionResponse } from '../../../../models/';
import { type UserFlowLanguageConfiguration } from '../../../../models/userFlowLanguageConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { UserFlowLanguageConfigurationItemRequestBuilder } from './item/userFlowLanguageConfigurationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LanguagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface LanguagesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LanguagesRequestBuilderGetQueryParameters;
}
export interface LanguagesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the languages property of the microsoft.graph.b2xIdentityUserFlow entity.
 */
export declare class LanguagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the languages property of the microsoft.graph.b2xIdentityUserFlow entity.
     * @param userFlowLanguageConfigurationId The unique identifier of userFlowLanguageConfiguration
     * @returns a UserFlowLanguageConfigurationItemRequestBuilder
     */
    byUserFlowLanguageConfigurationId(userFlowLanguageConfigurationId: string): UserFlowLanguageConfigurationItemRequestBuilder;
    /**
     * Instantiates a new LanguagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of languages supported for customization in a B2X user flow. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserFlowLanguageConfigurationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/b2xidentityuserflow-list-languages?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: LanguagesRequestBuilderGetRequestConfiguration | undefined): Promise<UserFlowLanguageConfigurationCollectionResponse | undefined>;
    /**
     * Create new navigation property to languages for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserFlowLanguageConfiguration
     */
    post(body: UserFlowLanguageConfiguration, requestConfiguration?: LanguagesRequestBuilderPostRequestConfiguration | undefined): Promise<UserFlowLanguageConfiguration | undefined>;
    /**
     * Retrieve a list of languages supported for customization in a B2X user flow. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LanguagesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to languages for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserFlowLanguageConfiguration, requestConfiguration?: LanguagesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a languagesRequestBuilder
     */
    withUrl(rawUrl: string): LanguagesRequestBuilder;
}
