import { type AuthenticationStrengthRoot } from '../../../models/authenticationStrengthRoot';
import { AuthenticationMethodModesRequestBuilder } from './authenticationMethodModes/authenticationMethodModesRequestBuilder';
import { PoliciesRequestBuilder } from './policies/policiesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AuthenticationStrengthRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AuthenticationStrengthRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AuthenticationStrengthRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AuthenticationStrengthRequestBuilderGetQueryParameters;
}
export interface AuthenticationStrengthRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the authenticationStrength property of the microsoft.graph.conditionalAccessRoot entity.
 */
export declare class AuthenticationStrengthRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the authenticationMethodModes property of the microsoft.graph.authenticationStrengthRoot entity.
     */
    get authenticationMethodModes(): AuthenticationMethodModesRequestBuilder;
    /**
     * Provides operations to manage the policies property of the microsoft.graph.authenticationStrengthRoot entity.
     */
    get policies(): PoliciesRequestBuilder;
    /**
     * Instantiates a new AuthenticationStrengthRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authenticationStrength for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AuthenticationStrengthRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get authenticationStrength from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationStrengthRoot
     */
    get(requestConfiguration?: AuthenticationStrengthRequestBuilderGetRequestConfiguration | undefined): Promise<AuthenticationStrengthRoot | undefined>;
    /**
     * Update the navigation property authenticationStrength in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationStrengthRoot
     */
    patch(body: AuthenticationStrengthRoot, requestConfiguration?: AuthenticationStrengthRequestBuilderPatchRequestConfiguration | undefined): Promise<AuthenticationStrengthRoot | undefined>;
    /**
     * Delete navigation property authenticationStrength for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AuthenticationStrengthRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get authenticationStrength from identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AuthenticationStrengthRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property authenticationStrength in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AuthenticationStrengthRoot, requestConfiguration?: AuthenticationStrengthRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a authenticationStrengthRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationStrengthRequestBuilder;
}
