import { type ConditionalAccessRoot } from '../../models/conditionalAccessRoot';
import { AuthenticationContextClassReferencesRequestBuilder } from './authenticationContextClassReferences/authenticationContextClassReferencesRequestBuilder';
import { AuthenticationStrengthRequestBuilder } from './authenticationStrength/authenticationStrengthRequestBuilder';
import { NamedLocationsRequestBuilder } from './namedLocations/namedLocationsRequestBuilder';
import { PoliciesRequestBuilder } from './policies/policiesRequestBuilder';
import { TemplatesRequestBuilder } from './templates/templatesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ConditionalAccessRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ConditionalAccessRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ConditionalAccessRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ConditionalAccessRequestBuilderGetQueryParameters;
}
export interface ConditionalAccessRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the conditionalAccess property of the microsoft.graph.identityContainer entity.
 */
export declare class ConditionalAccessRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the authenticationContextClassReferences property of the microsoft.graph.conditionalAccessRoot entity.
     */
    get authenticationContextClassReferences(): AuthenticationContextClassReferencesRequestBuilder;
    /**
     * Provides operations to manage the authenticationStrength property of the microsoft.graph.conditionalAccessRoot entity.
     */
    get authenticationStrength(): AuthenticationStrengthRequestBuilder;
    /**
     * Provides operations to manage the namedLocations property of the microsoft.graph.conditionalAccessRoot entity.
     */
    get namedLocations(): NamedLocationsRequestBuilder;
    /**
     * Provides operations to manage the policies property of the microsoft.graph.conditionalAccessRoot entity.
     */
    get policies(): PoliciesRequestBuilder;
    /**
     * Provides operations to manage the templates property of the microsoft.graph.conditionalAccessRoot entity.
     */
    get templates(): TemplatesRequestBuilder;
    /**
     * Instantiates a new ConditionalAccessRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property conditionalAccess for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ConditionalAccessRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * the entry point for the Conditional Access (CA) object model.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConditionalAccessRoot
     */
    get(requestConfiguration?: ConditionalAccessRequestBuilderGetRequestConfiguration | undefined): Promise<ConditionalAccessRoot | undefined>;
    /**
     * Update the navigation property conditionalAccess in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConditionalAccessRoot
     */
    patch(body: ConditionalAccessRoot, requestConfiguration?: ConditionalAccessRequestBuilderPatchRequestConfiguration | undefined): Promise<ConditionalAccessRoot | undefined>;
    /**
     * Delete navigation property conditionalAccess for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ConditionalAccessRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * the entry point for the Conditional Access (CA) object model.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ConditionalAccessRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property conditionalAccess in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ConditionalAccessRoot, requestConfiguration?: ConditionalAccessRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a conditionalAccessRequestBuilder
     */
    withUrl(rawUrl: string): ConditionalAccessRequestBuilder;
}
