import { type ConditionalAccessTemplateCollectionResponse } from '../../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ConditionalAccessTemplateItemRequestBuilder } from './item/conditionalAccessTemplateItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TemplatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TemplatesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TemplatesRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the templates property of the microsoft.graph.conditionalAccessRoot entity.
 */
export declare class TemplatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the templates property of the microsoft.graph.conditionalAccessRoot entity.
     * @param conditionalAccessTemplateId The unique identifier of conditionalAccessTemplate
     * @returns a ConditionalAccessTemplateItemRequestBuilder
     */
    byConditionalAccessTemplateId(conditionalAccessTemplateId: string): ConditionalAccessTemplateItemRequestBuilder;
    /**
     * Instantiates a new TemplatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the conditionalAccessTemplate objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConditionalAccessTemplateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/conditionalaccessroot-list-templates?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TemplatesRequestBuilderGetRequestConfiguration | undefined): Promise<ConditionalAccessTemplateCollectionResponse | undefined>;
    /**
     * Get a list of the conditionalAccessTemplate objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TemplatesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a templatesRequestBuilder
     */
    withUrl(rawUrl: string): TemplatesRequestBuilder;
}
