import { type IdentityUserFlowAttributeCollectionResponse } from '../../models/';
import { type IdentityUserFlowAttribute } from '../../models/identityUserFlowAttribute';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { IdentityUserFlowAttributeItemRequestBuilder } from './item/identityUserFlowAttributeItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface UserFlowAttributesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface UserFlowAttributesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: UserFlowAttributesRequestBuilderGetQueryParameters;
}
export interface UserFlowAttributesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the userFlowAttributes property of the microsoft.graph.identityContainer entity.
 */
export declare class UserFlowAttributesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userFlowAttributes property of the microsoft.graph.identityContainer entity.
     * @param identityUserFlowAttributeId The unique identifier of identityUserFlowAttribute
     * @returns a IdentityUserFlowAttributeItemRequestBuilder
     */
    byIdentityUserFlowAttributeId(identityUserFlowAttributeId: string): IdentityUserFlowAttributeItemRequestBuilder;
    /**
     * Instantiates a new UserFlowAttributesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of identityUserFlowAttribute objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityUserFlowAttributeCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/identityuserflowattribute-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: UserFlowAttributesRequestBuilderGetRequestConfiguration | undefined): Promise<IdentityUserFlowAttributeCollectionResponse | undefined>;
    /**
     * Create a new custom identityUserFlowAttribute object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityUserFlowAttribute
     * @see {@link https://learn.microsoft.com/graph/api/identityuserflowattribute-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: IdentityUserFlowAttribute, requestConfiguration?: UserFlowAttributesRequestBuilderPostRequestConfiguration | undefined): Promise<IdentityUserFlowAttribute | undefined>;
    /**
     * Retrieve a list of identityUserFlowAttribute objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: UserFlowAttributesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new custom identityUserFlowAttribute object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IdentityUserFlowAttribute, requestConfiguration?: UserFlowAttributesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userFlowAttributesRequestBuilder
     */
    withUrl(rawUrl: string): UserFlowAttributesRequestBuilder;
}
