import { type AccessReviewScheduleDefinitionCollectionResponse } from '../../../models/';
import { type AccessReviewScheduleDefinition } from '../../../models/accessReviewScheduleDefinition';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { FilterByCurrentUserWithOnRequestBuilder } from './filterByCurrentUserWithOn/filterByCurrentUserWithOnRequestBuilder';
import { AccessReviewScheduleDefinitionItemRequestBuilder } from './item/accessReviewScheduleDefinitionItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DefinitionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DefinitionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DefinitionsRequestBuilderGetQueryParameters;
}
export interface DefinitionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the definitions property of the microsoft.graph.accessReviewSet entity.
 */
export declare class DefinitionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the definitions property of the microsoft.graph.accessReviewSet entity.
     * @param accessReviewScheduleDefinitionId The unique identifier of accessReviewScheduleDefinition
     * @returns a AccessReviewScheduleDefinitionItemRequestBuilder
     */
    byAccessReviewScheduleDefinitionId(accessReviewScheduleDefinitionId: string): AccessReviewScheduleDefinitionItemRequestBuilder;
    /**
     * Instantiates a new DefinitionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on: string | undefined): FilterByCurrentUserWithOnRequestBuilder;
    /**
     * Get a list of the accessReviewScheduleDefinition objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewScheduleDefinitionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewset-list-definitions?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: DefinitionsRequestBuilderGetRequestConfiguration | undefined): Promise<AccessReviewScheduleDefinitionCollectionResponse | undefined>;
    /**
     * Create a new accessReviewScheduleDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewScheduleDefinition
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewset-post-definitions?view=graph-rest-1.0|Find more info here}
     */
    post(body: AccessReviewScheduleDefinition, requestConfiguration?: DefinitionsRequestBuilderPostRequestConfiguration | undefined): Promise<AccessReviewScheduleDefinition | undefined>;
    /**
     * Get a list of the accessReviewScheduleDefinition objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DefinitionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new accessReviewScheduleDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessReviewScheduleDefinition, requestConfiguration?: DefinitionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a definitionsRequestBuilder
     */
    withUrl(rawUrl: string): DefinitionsRequestBuilder;
}
