import { type AccessReviewHistoryDefinitionCollectionResponse } from '../../../models/';
import { type AccessReviewHistoryDefinition } from '../../../models/accessReviewHistoryDefinition';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AccessReviewHistoryDefinitionItemRequestBuilder } from './item/accessReviewHistoryDefinitionItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface HistoryDefinitionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface HistoryDefinitionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: HistoryDefinitionsRequestBuilderGetQueryParameters;
}
export interface HistoryDefinitionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the historyDefinitions property of the microsoft.graph.accessReviewSet entity.
 */
export declare class HistoryDefinitionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the historyDefinitions property of the microsoft.graph.accessReviewSet entity.
     * @param accessReviewHistoryDefinitionId The unique identifier of accessReviewHistoryDefinition
     * @returns a AccessReviewHistoryDefinitionItemRequestBuilder
     */
    byAccessReviewHistoryDefinitionId(accessReviewHistoryDefinitionId: string): AccessReviewHistoryDefinitionItemRequestBuilder;
    /**
     * Instantiates a new HistoryDefinitionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the accessReviewHistoryDefinition objects created in the last 30 days, including all nested properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewHistoryDefinitionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewset-list-historydefinitions?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: HistoryDefinitionsRequestBuilderGetRequestConfiguration | undefined): Promise<AccessReviewHistoryDefinitionCollectionResponse | undefined>;
    /**
     * Create a new accessReviewHistoryDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewHistoryDefinition
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewset-post-historydefinitions?view=graph-rest-1.0|Find more info here}
     */
    post(body: AccessReviewHistoryDefinition, requestConfiguration?: HistoryDefinitionsRequestBuilderPostRequestConfiguration | undefined): Promise<AccessReviewHistoryDefinition | undefined>;
    /**
     * Retrieve the accessReviewHistoryDefinition objects created in the last 30 days, including all nested properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: HistoryDefinitionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new accessReviewHistoryDefinition object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessReviewHistoryDefinition, requestConfiguration?: HistoryDefinitionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a historyDefinitionsRequestBuilder
     */
    withUrl(rawUrl: string): HistoryDefinitionsRequestBuilder;
}
