import { type AccessPackageCatalogCollectionResponse } from '../../../models/';
import { type AccessPackageCatalog } from '../../../models/accessPackageCatalog';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AccessPackageCatalogItemRequestBuilder } from './item/accessPackageCatalogItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface CatalogsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface CatalogsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: CatalogsRequestBuilderGetQueryParameters;
}
export interface CatalogsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the catalogs property of the microsoft.graph.entitlementManagement entity.
 */
export declare class CatalogsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the catalogs property of the microsoft.graph.entitlementManagement entity.
     * @param accessPackageCatalogId The unique identifier of accessPackageCatalog
     * @returns a AccessPackageCatalogItemRequestBuilder
     */
    byAccessPackageCatalogId(accessPackageCatalogId: string): AccessPackageCatalogItemRequestBuilder;
    /**
     * Instantiates a new CatalogsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of accessPackageCatalog objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageCatalogCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/entitlementmanagement-list-catalogs?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: CatalogsRequestBuilderGetRequestConfiguration | undefined): Promise<AccessPackageCatalogCollectionResponse | undefined>;
    /**
     * Create a new accessPackageCatalog object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageCatalog
     * @see {@link https://learn.microsoft.com/graph/api/entitlementmanagement-post-catalogs?view=graph-rest-1.0|Find more info here}
     */
    post(body: AccessPackageCatalog, requestConfiguration?: CatalogsRequestBuilderPostRequestConfiguration | undefined): Promise<AccessPackageCatalog | undefined>;
    /**
     * Retrieve a list of accessPackageCatalog objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: CatalogsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new accessPackageCatalog object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessPackageCatalog, requestConfiguration?: CatalogsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a catalogsRequestBuilder
     */
    withUrl(rawUrl: string): CatalogsRequestBuilder;
}
