import { type AccessPackageResource } from '../../../../../../models/accessPackageResource';
import { EnvironmentRequestBuilder } from './environment/environmentRequestBuilder';
import { RolesRequestBuilder } from './roles/rolesRequestBuilder';
import { ScopesRequestBuilder } from './scopes/scopesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AccessPackageResourceItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AccessPackageResourceItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AccessPackageResourceItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AccessPackageResourceItemRequestBuilderGetQueryParameters;
}
export interface AccessPackageResourceItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the resources property of the microsoft.graph.accessPackageCatalog entity.
 */
export declare class AccessPackageResourceItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the environment property of the microsoft.graph.accessPackageResource entity.
     */
    get environment(): EnvironmentRequestBuilder;
    /**
     * Provides operations to manage the roles property of the microsoft.graph.accessPackageResource entity.
     */
    get roles(): RolesRequestBuilder;
    /**
     * Provides operations to manage the scopes property of the microsoft.graph.accessPackageResource entity.
     */
    get scopes(): ScopesRequestBuilder;
    /**
     * Instantiates a new AccessPackageResourceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property resources for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AccessPackageResourceItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Access package resources in this catalog.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResource
     */
    get(requestConfiguration?: AccessPackageResourceItemRequestBuilderGetRequestConfiguration | undefined): Promise<AccessPackageResource | undefined>;
    /**
     * Update the navigation property resources in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResource
     */
    patch(body: AccessPackageResource, requestConfiguration?: AccessPackageResourceItemRequestBuilderPatchRequestConfiguration | undefined): Promise<AccessPackageResource | undefined>;
    /**
     * Delete navigation property resources for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AccessPackageResourceItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Access package resources in this catalog.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AccessPackageResourceItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property resources in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AccessPackageResource, requestConfiguration?: AccessPackageResourceItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AccessPackageResourceItemRequestBuilder
     */
    withUrl(rawUrl: string): AccessPackageResourceItemRequestBuilder;
}
