import { type EntitlementManagement } from '../../models/entitlementManagement';
import { AccessPackageAssignmentApprovalsRequestBuilder } from './accessPackageAssignmentApprovals/accessPackageAssignmentApprovalsRequestBuilder';
import { AccessPackagesRequestBuilder } from './accessPackages/accessPackagesRequestBuilder';
import { AssignmentPoliciesRequestBuilder } from './assignmentPolicies/assignmentPoliciesRequestBuilder';
import { AssignmentRequestsRequestBuilder } from './assignmentRequests/assignmentRequestsRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { CatalogsRequestBuilder } from './catalogs/catalogsRequestBuilder';
import { ConnectedOrganizationsRequestBuilder } from './connectedOrganizations/connectedOrganizationsRequestBuilder';
import { ResourceEnvironmentsRequestBuilder } from './resourceEnvironments/resourceEnvironmentsRequestBuilder';
import { ResourceRequestsRequestBuilder } from './resourceRequests/resourceRequestsRequestBuilder';
import { ResourceRoleScopesRequestBuilder } from './resourceRoleScopes/resourceRoleScopesRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { SettingsRequestBuilder } from './settings/settingsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EntitlementManagementRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface EntitlementManagementRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface EntitlementManagementRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EntitlementManagementRequestBuilderGetQueryParameters;
}
export interface EntitlementManagementRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the entitlementManagement property of the microsoft.graph.identityGovernance entity.
 */
export declare class EntitlementManagementRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the accessPackageAssignmentApprovals property of the microsoft.graph.entitlementManagement entity.
     */
    get accessPackageAssignmentApprovals(): AccessPackageAssignmentApprovalsRequestBuilder;
    /**
     * Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.
     */
    get accessPackages(): AccessPackagesRequestBuilder;
    /**
     * Provides operations to manage the assignmentPolicies property of the microsoft.graph.entitlementManagement entity.
     */
    get assignmentPolicies(): AssignmentPoliciesRequestBuilder;
    /**
     * Provides operations to manage the assignmentRequests property of the microsoft.graph.entitlementManagement entity.
     */
    get assignmentRequests(): AssignmentRequestsRequestBuilder;
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.entitlementManagement entity.
     */
    get assignments(): AssignmentsRequestBuilder;
    /**
     * Provides operations to manage the catalogs property of the microsoft.graph.entitlementManagement entity.
     */
    get catalogs(): CatalogsRequestBuilder;
    /**
     * Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
     */
    get connectedOrganizations(): ConnectedOrganizationsRequestBuilder;
    /**
     * Provides operations to manage the resourceEnvironments property of the microsoft.graph.entitlementManagement entity.
     */
    get resourceEnvironments(): ResourceEnvironmentsRequestBuilder;
    /**
     * Provides operations to manage the resourceRequests property of the microsoft.graph.entitlementManagement entity.
     */
    get resourceRequests(): ResourceRequestsRequestBuilder;
    /**
     * Provides operations to manage the resourceRoleScopes property of the microsoft.graph.entitlementManagement entity.
     */
    get resourceRoleScopes(): ResourceRoleScopesRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.entitlementManagement entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to manage the settings property of the microsoft.graph.entitlementManagement entity.
     */
    get settings(): SettingsRequestBuilder;
    /**
     * Instantiates a new EntitlementManagementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property entitlementManagement for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: EntitlementManagementRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get entitlementManagement from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EntitlementManagement
     */
    get(requestConfiguration?: EntitlementManagementRequestBuilderGetRequestConfiguration | undefined): Promise<EntitlementManagement | undefined>;
    /**
     * Update the navigation property entitlementManagement in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EntitlementManagement
     */
    patch(body: EntitlementManagement, requestConfiguration?: EntitlementManagementRequestBuilderPatchRequestConfiguration | undefined): Promise<EntitlementManagement | undefined>;
    /**
     * Delete navigation property entitlementManagement for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: EntitlementManagementRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entitlementManagement from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EntitlementManagementRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property entitlementManagement in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EntitlementManagement, requestConfiguration?: EntitlementManagementRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a entitlementManagementRequestBuilder
     */
    withUrl(rawUrl: string): EntitlementManagementRequestBuilder;
}
