import { type AccessPackageResourceRequest } from '../../../../models/accessPackageResourceRequest';
import { CatalogRequestBuilder } from './catalog/catalogRequestBuilder';
import { ResourceRequestBuilder } from './resource/resourceRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AccessPackageResourceRequestItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AccessPackageResourceRequestItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AccessPackageResourceRequestItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AccessPackageResourceRequestItemRequestBuilderGetQueryParameters;
}
export interface AccessPackageResourceRequestItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the resourceRequests property of the microsoft.graph.entitlementManagement entity.
 */
export declare class AccessPackageResourceRequestItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the catalog property of the microsoft.graph.accessPackageResourceRequest entity.
     */
    get catalog(): CatalogRequestBuilder;
    /**
     * Provides operations to manage the resource property of the microsoft.graph.accessPackageResourceRequest entity.
     */
    get resource(): ResourceRequestBuilder;
    /**
     * Instantiates a new AccessPackageResourceRequestItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property resourceRequests for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents a request to add or remove a resource to or from a catalog respectively.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResourceRequest
     */
    get(requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderGetRequestConfiguration | undefined): Promise<AccessPackageResourceRequest | undefined>;
    /**
     * Update the navigation property resourceRequests in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResourceRequest
     */
    patch(body: AccessPackageResourceRequest, requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderPatchRequestConfiguration | undefined): Promise<AccessPackageResourceRequest | undefined>;
    /**
     * Delete navigation property resourceRequests for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents a request to add or remove a resource to or from a catalog respectively.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property resourceRequests in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AccessPackageResourceRequest, requestConfiguration?: AccessPackageResourceRequestItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AccessPackageResourceRequestItemRequestBuilder
     */
    withUrl(rawUrl: string): AccessPackageResourceRequestItemRequestBuilder;
}
