import { type IdentityGovernance } from '../models/identityGovernance';
import { AccessReviewsRequestBuilder } from './accessReviews/accessReviewsRequestBuilder';
import { AppConsentRequestBuilder } from './appConsent/appConsentRequestBuilder';
import { EntitlementManagementRequestBuilder } from './entitlementManagement/entitlementManagementRequestBuilder';
import { LifecycleWorkflowsRequestBuilder } from './lifecycleWorkflows/lifecycleWorkflowsRequestBuilder';
import { PrivilegedAccessRequestBuilder } from './privilegedAccess/privilegedAccessRequestBuilder';
import { TermsOfUseRequestBuilder } from './termsOfUse/termsOfUseRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface IdentityGovernanceRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface IdentityGovernanceRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: IdentityGovernanceRequestBuilderGetQueryParameters;
}
export interface IdentityGovernanceRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the identityGovernance singleton.
 */
export declare class IdentityGovernanceRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the accessReviews property of the microsoft.graph.identityGovernance entity.
     */
    get accessReviews(): AccessReviewsRequestBuilder;
    /**
     * Provides operations to manage the appConsent property of the microsoft.graph.identityGovernance entity.
     */
    get appConsent(): AppConsentRequestBuilder;
    /**
     * Provides operations to manage the entitlementManagement property of the microsoft.graph.identityGovernance entity.
     */
    get entitlementManagement(): EntitlementManagementRequestBuilder;
    /**
     * Provides operations to manage the lifecycleWorkflows property of the microsoft.graph.identityGovernance entity.
     */
    get lifecycleWorkflows(): LifecycleWorkflowsRequestBuilder;
    /**
     * Provides operations to manage the privilegedAccess property of the microsoft.graph.identityGovernance entity.
     */
    get privilegedAccess(): PrivilegedAccessRequestBuilder;
    /**
     * Provides operations to manage the termsOfUse property of the microsoft.graph.identityGovernance entity.
     */
    get termsOfUse(): TermsOfUseRequestBuilder;
    /**
     * Instantiates a new IdentityGovernanceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityGovernance
     */
    get(requestConfiguration?: IdentityGovernanceRequestBuilderGetRequestConfiguration | undefined): Promise<IdentityGovernance | undefined>;
    /**
     * Update identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityGovernance
     */
    patch(body: IdentityGovernance, requestConfiguration?: IdentityGovernanceRequestBuilderPatchRequestConfiguration | undefined): Promise<IdentityGovernance | undefined>;
    /**
     * Get identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: IdentityGovernanceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityGovernance, requestConfiguration?: IdentityGovernanceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a identityGovernanceRequestBuilder
     */
    withUrl(rawUrl: string): IdentityGovernanceRequestBuilder;
}
