"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkflowItemRequestBuilder = void 0;
const workflow_1 = require("../../../../../models/identityGovernance/workflow");
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const createdByRequestBuilder_1 = require("./createdBy/createdByRequestBuilder");
const executionScopeRequestBuilder_1 = require("./executionScope/executionScopeRequestBuilder");
const lastModifiedByRequestBuilder_1 = require("./lastModifiedBy/lastModifiedByRequestBuilder");
const microsoftGraphIdentityGovernanceActivateRequestBuilder_1 = require("./microsoftGraphIdentityGovernanceActivate/microsoftGraphIdentityGovernanceActivateRequestBuilder");
const microsoftGraphIdentityGovernanceCreateNewVersionRequestBuilder_1 = require("./microsoftGraphIdentityGovernanceCreateNewVersion/microsoftGraphIdentityGovernanceCreateNewVersionRequestBuilder");
const microsoftGraphIdentityGovernanceRestoreRequestBuilder_1 = require("./microsoftGraphIdentityGovernanceRestore/microsoftGraphIdentityGovernanceRestoreRequestBuilder");
const runsRequestBuilder_1 = require("./runs/runsRequestBuilder");
const taskReportsRequestBuilder_1 = require("./taskReports/taskReportsRequestBuilder");
const tasksRequestBuilder_1 = require("./tasks/tasksRequestBuilder");
const userProcessingResultsRequestBuilder_1 = require("./userProcessingResults/userProcessingResultsRequestBuilder");
const versionsRequestBuilder_1 = require("./versions/versionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the workflows property of the microsoft.graph.deletedItemContainer entity.
 */
class WorkflowItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the createdBy property of the microsoft.graph.identityGovernance.workflowBase entity.
     */
    get createdBy() {
        return new createdByRequestBuilder_1.CreatedByRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
     */
    get executionScope() {
        return new executionScopeRequestBuilder_1.ExecutionScopeRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the lastModifiedBy property of the microsoft.graph.identityGovernance.workflowBase entity.
     */
    get lastModifiedBy() {
        return new lastModifiedByRequestBuilder_1.LastModifiedByRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the activate method.
     */
    get microsoftGraphIdentityGovernanceActivate() {
        return new microsoftGraphIdentityGovernanceActivateRequestBuilder_1.MicrosoftGraphIdentityGovernanceActivateRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the createNewVersion method.
     */
    get microsoftGraphIdentityGovernanceCreateNewVersion() {
        return new microsoftGraphIdentityGovernanceCreateNewVersionRequestBuilder_1.MicrosoftGraphIdentityGovernanceCreateNewVersionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the restore method.
     */
    get microsoftGraphIdentityGovernanceRestore() {
        return new microsoftGraphIdentityGovernanceRestoreRequestBuilder_1.MicrosoftGraphIdentityGovernanceRestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the runs property of the microsoft.graph.identityGovernance.workflow entity.
     */
    get runs() {
        return new runsRequestBuilder_1.RunsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the taskReports property of the microsoft.graph.identityGovernance.workflow entity.
     */
    get taskReports() {
        return new taskReportsRequestBuilder_1.TaskReportsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the tasks property of the microsoft.graph.identityGovernance.workflowBase entity.
     */
    get tasks() {
        return new tasksRequestBuilder_1.TasksRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the userProcessingResults property of the microsoft.graph.identityGovernance.workflow entity.
     */
    get userProcessingResults() {
        return new userProcessingResultsRequestBuilder_1.UserProcessingResultsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the versions property of the microsoft.graph.identityGovernance.workflow entity.
     */
    get versions() {
        return new versionsRequestBuilder_1.VersionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new WorkflowItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/deletedItems/workflows/{workflow%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Delete a workflow object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/identitygovernance-deletedItemcontainer-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve a deleted workflow object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Workflow
     * @see {@link https://learn.microsoft.com/graph/api/identitygovernance-deleteditemcontainer-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workflow_1.createWorkflowFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete a workflow object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        requestInfo.tryAddRequestHeaders("Accept", "application/json, application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve a deleted workflow object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkflowItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WorkflowItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WorkflowItemRequestBuilder = WorkflowItemRequestBuilder;
// tslint:enable
// eslint-enable
