import { type TaskProcessingResultCollectionResponse } from '../../../../../../../models/identityGovernance/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TaskProcessingResultItemRequestBuilder } from './item/taskProcessingResultItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TaskProcessingResultsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TaskProcessingResultsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TaskProcessingResultsRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the taskProcessingResults property of the microsoft.graph.identityGovernance.taskReport entity.
 */
export declare class TaskProcessingResultsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the taskProcessingResults property of the microsoft.graph.identityGovernance.taskReport entity.
     * @param taskProcessingResultId The unique identifier of taskProcessingResult
     * @returns a TaskProcessingResultItemRequestBuilder
     */
    byTaskProcessingResultId(taskProcessingResultId: string): TaskProcessingResultItemRequestBuilder;
    /**
     * Instantiates a new TaskProcessingResultsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the task processing result resources from the taskReport. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TaskProcessingResultCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/identitygovernance-taskreport-list-taskprocessingresults?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TaskProcessingResultsRequestBuilderGetRequestConfiguration | undefined): Promise<TaskProcessingResultCollectionResponse | undefined>;
    /**
     * Get the task processing result resources from the taskReport. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TaskProcessingResultsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a taskProcessingResultsRequestBuilder
     */
    withUrl(rawUrl: string): TaskProcessingResultsRequestBuilder;
}
