import { type PrivilegedAccessGroupAssignmentSchedule } from '../../../../../models/privilegedAccessGroupAssignmentSchedule';
import { ActivatedUsingRequestBuilder } from './activatedUsing/activatedUsingRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { PrincipalRequestBuilder } from './principal/principalRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderGetQueryParameters;
}
export interface PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the assignmentSchedules property of the microsoft.graph.privilegedAccessGroup entity.
 */
export declare class PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the activatedUsing property of the microsoft.graph.privilegedAccessGroupAssignmentSchedule entity.
     */
    get activatedUsing(): ActivatedUsingRequestBuilder;
    /**
     * Provides operations to manage the group property of the microsoft.graph.privilegedAccessGroupAssignmentSchedule entity.
     */
    get group(): GroupRequestBuilder;
    /**
     * Provides operations to manage the principal property of the microsoft.graph.privilegedAccessGroupAssignmentSchedule entity.
     */
    get principal(): PrincipalRequestBuilder;
    /**
     * Instantiates a new PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignmentSchedules for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a privilegedAccessGroupAssignmentSchedule object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupAssignmentSchedule
     * @see {@link https://learn.microsoft.com/graph/api/privilegedaccessgroupassignmentschedule-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderGetRequestConfiguration | undefined): Promise<PrivilegedAccessGroupAssignmentSchedule | undefined>;
    /**
     * Update the navigation property assignmentSchedules in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupAssignmentSchedule
     */
    patch(body: PrivilegedAccessGroupAssignmentSchedule, requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderPatchRequestConfiguration | undefined): Promise<PrivilegedAccessGroupAssignmentSchedule | undefined>;
    /**
     * Delete navigation property assignmentSchedules for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a privilegedAccessGroupAssignmentSchedule object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property assignmentSchedules in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrivilegedAccessGroupAssignmentSchedule, requestConfiguration?: PrivilegedAccessGroupAssignmentScheduleItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder
     */
    withUrl(rawUrl: string): PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder;
}
