import { type PrivilegedAccessGroupEligibilitySchedule } from '../../../../../models/privilegedAccessGroupEligibilitySchedule';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { PrincipalRequestBuilder } from './principal/principalRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderGetQueryParameters;
}
export interface PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the eligibilitySchedules property of the microsoft.graph.privilegedAccessGroup entity.
 */
export declare class PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the group property of the microsoft.graph.privilegedAccessGroupEligibilitySchedule entity.
     */
    get group(): GroupRequestBuilder;
    /**
     * Provides operations to manage the principal property of the microsoft.graph.privilegedAccessGroupEligibilitySchedule entity.
     */
    get principal(): PrincipalRequestBuilder;
    /**
     * Instantiates a new PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property eligibilitySchedules for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a privilegedAccessGroupEligibilitySchedule object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilitySchedule
     * @see {@link https://learn.microsoft.com/graph/api/privilegedaccessgroupeligibilityschedule-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderGetRequestConfiguration | undefined): Promise<PrivilegedAccessGroupEligibilitySchedule | undefined>;
    /**
     * Update the navigation property eligibilitySchedules in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilitySchedule
     */
    patch(body: PrivilegedAccessGroupEligibilitySchedule, requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderPatchRequestConfiguration | undefined): Promise<PrivilegedAccessGroupEligibilitySchedule | undefined>;
    /**
     * Delete navigation property eligibilitySchedules for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a privilegedAccessGroupEligibilitySchedule object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property eligibilitySchedules in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrivilegedAccessGroupEligibilitySchedule, requestConfiguration?: PrivilegedAccessGroupEligibilityScheduleItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder
     */
    withUrl(rawUrl: string): PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder;
}
