import { type PrivilegedAccessRoot } from '../../models/privilegedAccessRoot';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrivilegedAccessRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrivilegedAccessRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrivilegedAccessRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrivilegedAccessRequestBuilderGetQueryParameters;
}
export interface PrivilegedAccessRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the privilegedAccess property of the microsoft.graph.identityGovernance entity.
 */
export declare class PrivilegedAccessRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the group property of the microsoft.graph.privilegedAccessRoot entity.
     */
    get group(): GroupRequestBuilder;
    /**
     * Instantiates a new PrivilegedAccessRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property privilegedAccess for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrivilegedAccessRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get privilegedAccess from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessRoot
     */
    get(requestConfiguration?: PrivilegedAccessRequestBuilderGetRequestConfiguration | undefined): Promise<PrivilegedAccessRoot | undefined>;
    /**
     * Update the navigation property privilegedAccess in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessRoot
     */
    patch(body: PrivilegedAccessRoot, requestConfiguration?: PrivilegedAccessRequestBuilderPatchRequestConfiguration | undefined): Promise<PrivilegedAccessRoot | undefined>;
    /**
     * Delete navigation property privilegedAccess for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrivilegedAccessRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get privilegedAccess from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrivilegedAccessRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property privilegedAccess in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrivilegedAccessRoot, requestConfiguration?: PrivilegedAccessRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a privilegedAccessRequestBuilder
     */
    withUrl(rawUrl: string): PrivilegedAccessRequestBuilder;
}
