import { type Agreement } from '../../../../models/agreement';
import { AcceptancesRequestBuilder } from './acceptances/acceptancesRequestBuilder';
import { FileRequestBuilder } from './file/fileRequestBuilder';
import { FilesRequestBuilder } from './files/filesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AgreementItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AgreementItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AgreementItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AgreementItemRequestBuilderGetQueryParameters;
}
export interface AgreementItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the agreements property of the microsoft.graph.termsOfUseContainer entity.
 */
export declare class AgreementItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the acceptances property of the microsoft.graph.agreement entity.
     */
    get acceptances(): AcceptancesRequestBuilder;
    /**
     * Provides operations to manage the file property of the microsoft.graph.agreement entity.
     */
    get file(): FileRequestBuilder;
    /**
     * Provides operations to manage the files property of the microsoft.graph.agreement entity.
     */
    get files(): FilesRequestBuilder;
    /**
     * Instantiates a new AgreementItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an agreement object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/agreement-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: AgreementItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve all files related to an agreement. This includes the default file and all localized files. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Agreement
     * @see {@link https://learn.microsoft.com/graph/api/agreement-list-files?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AgreementItemRequestBuilderGetRequestConfiguration | undefined): Promise<Agreement | undefined>;
    /**
     * Update the properties of an agreement object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Agreement
     * @see {@link https://learn.microsoft.com/graph/api/agreement-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Agreement, requestConfiguration?: AgreementItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Agreement | undefined>;
    /**
     * Delete an agreement object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AgreementItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve all files related to an agreement. This includes the default file and all localized files. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AgreementItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an agreement object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Agreement, requestConfiguration?: AgreementItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AgreementItemRequestBuilder
     */
    withUrl(rawUrl: string): AgreementItemRequestBuilder;
}
