import { type AgreementFileLocalizationCollectionResponse } from '../../../../../../models/';
import { type AgreementFileLocalization } from '../../../../../../models/agreementFileLocalization';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AgreementFileLocalizationItemRequestBuilder } from './item/agreementFileLocalizationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LocalizationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface LocalizationsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LocalizationsRequestBuilderGetQueryParameters;
}
export interface LocalizationsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the localizations property of the microsoft.graph.agreementFile entity.
 */
export declare class LocalizationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the localizations property of the microsoft.graph.agreementFile entity.
     * @param agreementFileLocalizationId The unique identifier of agreementFileLocalization
     * @returns a AgreementFileLocalizationItemRequestBuilder
     */
    byAgreementFileLocalizationId(agreementFileLocalizationId: string): AgreementFileLocalizationItemRequestBuilder;
    /**
     * Instantiates a new LocalizationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the default and localized agreement files. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementFileLocalizationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/agreementfile-list-localizations?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: LocalizationsRequestBuilderGetRequestConfiguration | undefined): Promise<AgreementFileLocalizationCollectionResponse | undefined>;
    /**
     * Create new navigation property to localizations for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementFileLocalization
     */
    post(body: AgreementFileLocalization, requestConfiguration?: LocalizationsRequestBuilderPostRequestConfiguration | undefined): Promise<AgreementFileLocalization | undefined>;
    /**
     * Get a list of the default and localized agreement files. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LocalizationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to localizations for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AgreementFileLocalization, requestConfiguration?: LocalizationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a localizationsRequestBuilder
     */
    withUrl(rawUrl: string): LocalizationsRequestBuilder;
}
