import { type Invitation } from '../../models/invitation';
import { InvitedUserRequestBuilder } from './invitedUser/invitedUserRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface InvitationItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface InvitationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface InvitationItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: InvitationItemRequestBuilderGetQueryParameters;
}
export interface InvitationItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of invitation entities.
 */
export declare class InvitationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the invitedUser property of the microsoft.graph.invitation entity.
     */
    get invitedUser(): InvitedUserRequestBuilder;
    /**
     * Instantiates a new InvitationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from invitations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: InvitationItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get entity from invitations by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Invitation
     */
    get(requestConfiguration?: InvitationItemRequestBuilderGetRequestConfiguration | undefined): Promise<Invitation | undefined>;
    /**
     * Update entity in invitations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Invitation
     */
    patch(body: Invitation, requestConfiguration?: InvitationItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Invitation | undefined>;
    /**
     * Delete entity from invitations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: InvitationItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entity from invitations by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: InvitationItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in invitations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Invitation, requestConfiguration?: InvitationItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a InvitationItemRequestBuilder
     */
    withUrl(rawUrl: string): InvitationItemRequestBuilder;
}
