"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvitedUserRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const user_1 = require("../../../models/user");
const mailboxSettingsRequestBuilder_1 = require("./mailboxSettings/mailboxSettingsRequestBuilder");
const serviceProvisioningErrorsRequestBuilder_1 = require("./serviceProvisioningErrors/serviceProvisioningErrorsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the invitedUser property of the microsoft.graph.invitation entity.
 */
class InvitedUserRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * The mailboxSettings property
     */
    get mailboxSettings() {
        return new mailboxSettingsRequestBuilder_1.MailboxSettingsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * The serviceProvisioningErrors property
     */
    get serviceProvisioningErrors() {
        return new serviceProvisioningErrorsRequestBuilder_1.ServiceProvisioningErrorsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new InvitedUserRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/invitations/{invitation%2Did}/invitedUser{?%24select,%24expand}");
    }
    ;
    /**
     * The user created as part of the invitation creation. Read-Only
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of User
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, user_1.createUserFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * The user created as part of the invitation creation. Read-Only
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a invitedUserRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new InvitedUserRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.InvitedUserRequestBuilder = InvitedUserRequestBuilder;
// tslint:enable
// eslint-enable
