import { type AgreementAcceptanceCollectionResponse } from '../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AgreementAcceptanceItemRequestBuilder } from './item/agreementAcceptanceItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AgreementAcceptancesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface AgreementAcceptancesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AgreementAcceptancesRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the agreementAcceptances property of the microsoft.graph.user entity.
 */
export declare class AgreementAcceptancesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the agreementAcceptances property of the microsoft.graph.user entity.
     * @param agreementAcceptanceId The unique identifier of agreementAcceptance
     * @returns a AgreementAcceptanceItemRequestBuilder
     */
    byAgreementAcceptanceId(agreementAcceptanceId: string): AgreementAcceptanceItemRequestBuilder;
    /**
     * Instantiates a new AgreementAcceptancesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the signed-in user's agreementAcceptance objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementAcceptanceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/user-list-agreementacceptances?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AgreementAcceptancesRequestBuilderGetRequestConfiguration | undefined): Promise<AgreementAcceptanceCollectionResponse | undefined>;
    /**
     * Retrieve the signed-in user's agreementAcceptance objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AgreementAcceptancesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a agreementAcceptancesRequestBuilder
     */
    withUrl(rawUrl: string): AgreementAcceptancesRequestBuilder;
}
