"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventItemRequestBuilder = void 0;
const event_1 = require("../../../../../models/event");
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const acceptRequestBuilder_1 = require("./accept/acceptRequestBuilder");
const attachmentsRequestBuilder_1 = require("./attachments/attachmentsRequestBuilder");
const calendarRequestBuilder_1 = require("./calendar/calendarRequestBuilder");
const cancelRequestBuilder_1 = require("./cancel/cancelRequestBuilder");
const declineRequestBuilder_1 = require("./decline/declineRequestBuilder");
const dismissReminderRequestBuilder_1 = require("./dismissReminder/dismissReminderRequestBuilder");
const extensionsRequestBuilder_1 = require("./extensions/extensionsRequestBuilder");
const forwardRequestBuilder_1 = require("./forward/forwardRequestBuilder");
const snoozeReminderRequestBuilder_1 = require("./snoozeReminder/snoozeReminderRequestBuilder");
const tentativelyAcceptRequestBuilder_1 = require("./tentativelyAccept/tentativelyAcceptRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the instances property of the microsoft.graph.event entity.
 */
class EventItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the accept method.
     */
    get accept() {
        return new acceptRequestBuilder_1.AcceptRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the attachments property of the microsoft.graph.event entity.
     */
    get attachments() {
        return new attachmentsRequestBuilder_1.AttachmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the calendar property of the microsoft.graph.event entity.
     */
    get calendar() {
        return new calendarRequestBuilder_1.CalendarRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the cancel method.
     */
    get cancel() {
        return new cancelRequestBuilder_1.CancelRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the decline method.
     */
    get decline() {
        return new declineRequestBuilder_1.DeclineRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the dismissReminder method.
     */
    get dismissReminder() {
        return new dismissReminderRequestBuilder_1.DismissReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the extensions property of the microsoft.graph.event entity.
     */
    get extensions() {
        return new extensionsRequestBuilder_1.ExtensionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the forward method.
     */
    get forward() {
        return new forwardRequestBuilder_1.ForwardRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the snoozeReminder method.
     */
    get snoozeReminder() {
        return new snoozeReminderRequestBuilder_1.SnoozeReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the tentativelyAccept method.
     */
    get tentativelyAccept() {
        return new tentativelyAcceptRequestBuilder_1.TentativelyAcceptRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new EventItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/me/calendarView/{event%2Did}/instances/{event%2Did1}{?startDateTime*,endDateTime*,%24select}");
    }
    ;
    /**
     * The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Event
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, event_1.createEventFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EventItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new EventItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.EventItemRequestBuilder = EventItemRequestBuilder;
// tslint:enable
// eslint-enable
