import { type Chat } from '../../../models/chat';
import { HideForUserRequestBuilder } from './hideForUser/hideForUserRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { LastMessagePreviewRequestBuilder } from './lastMessagePreview/lastMessagePreviewRequestBuilder';
import { MarkChatReadForUserRequestBuilder } from './markChatReadForUser/markChatReadForUserRequestBuilder';
import { MarkChatUnreadForUserRequestBuilder } from './markChatUnreadForUser/markChatUnreadForUserRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { PermissionGrantsRequestBuilder } from './permissionGrants/permissionGrantsRequestBuilder';
import { PinnedMessagesRequestBuilder } from './pinnedMessages/pinnedMessagesRequestBuilder';
import { SendActivityNotificationRequestBuilder } from './sendActivityNotification/sendActivityNotificationRequestBuilder';
import { TabsRequestBuilder } from './tabs/tabsRequestBuilder';
import { UnhideForUserRequestBuilder } from './unhideForUser/unhideForUserRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ChatItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ChatItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ChatItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ChatItemRequestBuilderGetQueryParameters;
}
export interface ChatItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the chats property of the microsoft.graph.user entity.
 */
export declare class ChatItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the hideForUser method.
     */
    get hideForUser(): HideForUserRequestBuilder;
    /**
     * Provides operations to manage the installedApps property of the microsoft.graph.chat entity.
     */
    get installedApps(): InstalledAppsRequestBuilder;
    /**
     * Provides operations to manage the lastMessagePreview property of the microsoft.graph.chat entity.
     */
    get lastMessagePreview(): LastMessagePreviewRequestBuilder;
    /**
     * Provides operations to call the markChatReadForUser method.
     */
    get markChatReadForUser(): MarkChatReadForUserRequestBuilder;
    /**
     * Provides operations to call the markChatUnreadForUser method.
     */
    get markChatUnreadForUser(): MarkChatUnreadForUserRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.chat entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the messages property of the microsoft.graph.chat entity.
     */
    get messages(): MessagesRequestBuilder;
    /**
     * Provides operations to manage the permissionGrants property of the microsoft.graph.chat entity.
     */
    get permissionGrants(): PermissionGrantsRequestBuilder;
    /**
     * Provides operations to manage the pinnedMessages property of the microsoft.graph.chat entity.
     */
    get pinnedMessages(): PinnedMessagesRequestBuilder;
    /**
     * Provides operations to call the sendActivityNotification method.
     */
    get sendActivityNotification(): SendActivityNotificationRequestBuilder;
    /**
     * Provides operations to manage the tabs property of the microsoft.graph.chat entity.
     */
    get tabs(): TabsRequestBuilder;
    /**
     * Provides operations to call the unhideForUser method.
     */
    get unhideForUser(): UnhideForUserRequestBuilder;
    /**
     * Instantiates a new ChatItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property chats for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ChatItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve a single chat (without its messages). This method supports federation. To access a chat, at least one chat member must belong to the tenant the request initiated from. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Chat
     * @see {@link https://learn.microsoft.com/graph/api/chat-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ChatItemRequestBuilderGetRequestConfiguration | undefined): Promise<Chat | undefined>;
    /**
     * Update the navigation property chats in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Chat
     */
    patch(body: Chat, requestConfiguration?: ChatItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Chat | undefined>;
    /**
     * Delete navigation property chats for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ChatItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a single chat (without its messages). This method supports federation. To access a chat, at least one chat member must belong to the tenant the request initiated from. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ChatItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property chats in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Chat, requestConfiguration?: ChatItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ChatItemRequestBuilder
     */
    withUrl(rawUrl: string): ChatItemRequestBuilder;
}
