import { type OfficeGraphInsights } from '../../models/officeGraphInsights';
import { SharedRequestBuilder } from './shared/sharedRequestBuilder';
import { TrendingRequestBuilder } from './trending/trendingRequestBuilder';
import { UsedRequestBuilder } from './used/usedRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface InsightsRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface InsightsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface InsightsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: InsightsRequestBuilderGetQueryParameters;
}
export interface InsightsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the insights property of the microsoft.graph.user entity.
 */
export declare class InsightsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
     */
    get shared(): SharedRequestBuilder;
    /**
     * Provides operations to manage the trending property of the microsoft.graph.officeGraphInsights entity.
     */
    get trending(): TrendingRequestBuilder;
    /**
     * Provides operations to manage the used property of the microsoft.graph.officeGraphInsights entity.
     */
    get used(): UsedRequestBuilder;
    /**
     * Instantiates a new InsightsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property insights for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: InsightsRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get insights from me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OfficeGraphInsights
     */
    get(requestConfiguration?: InsightsRequestBuilderGetRequestConfiguration | undefined): Promise<OfficeGraphInsights | undefined>;
    /**
     * Update the navigation property insights in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OfficeGraphInsights
     */
    patch(body: OfficeGraphInsights, requestConfiguration?: InsightsRequestBuilderPatchRequestConfiguration | undefined): Promise<OfficeGraphInsights | undefined>;
    /**
     * Delete navigation property insights for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: InsightsRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get insights from me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: InsightsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property insights in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OfficeGraphInsights, requestConfiguration?: InsightsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a insightsRequestBuilder
     */
    withUrl(rawUrl: string): InsightsRequestBuilder;
}
