import { type SharedInsight } from '../../../../models/sharedInsight';
import { LastSharedMethodRequestBuilder } from './lastSharedMethod/lastSharedMethodRequestBuilder';
import { ResourceRequestBuilder } from './resource/resourceRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SharedInsightItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SharedInsightItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SharedInsightItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SharedInsightItemRequestBuilderGetQueryParameters;
}
export interface SharedInsightItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
 */
export declare class SharedInsightItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the lastSharedMethod property of the microsoft.graph.sharedInsight entity.
     */
    get lastSharedMethod(): LastSharedMethodRequestBuilder;
    /**
     * Provides operations to manage the resource property of the microsoft.graph.sharedInsight entity.
     */
    get resource(): ResourceRequestBuilder;
    /**
     * Instantiates a new SharedInsightItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property shared for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SharedInsightItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Calculated relationship identifying documents shared with or by the user. This includes URLs, file attachments, and reference attachments to OneDrive for Business and SharePoint files found in Outlook messages and meetings. This also includes URLs and reference attachments to Teams conversations. Ordered by recency of share.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedInsight
     */
    get(requestConfiguration?: SharedInsightItemRequestBuilderGetRequestConfiguration | undefined): Promise<SharedInsight | undefined>;
    /**
     * Update the navigation property shared in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedInsight
     */
    patch(body: SharedInsight, requestConfiguration?: SharedInsightItemRequestBuilderPatchRequestConfiguration | undefined): Promise<SharedInsight | undefined>;
    /**
     * Delete navigation property shared for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SharedInsightItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Calculated relationship identifying documents shared with or by the user. This includes URLs, file attachments, and reference attachments to OneDrive for Business and SharePoint files found in Outlook messages and meetings. This also includes URLs and reference attachments to Teams conversations. Ordered by recency of share.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SharedInsightItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property shared in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SharedInsight, requestConfiguration?: SharedInsightItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SharedInsightItemRequestBuilder
     */
    withUrl(rawUrl: string): SharedInsightItemRequestBuilder;
}
