import { type Presence } from '../../models/presence';
import { ClearPresenceRequestBuilder } from './clearPresence/clearPresenceRequestBuilder';
import { ClearUserPreferredPresenceRequestBuilder } from './clearUserPreferredPresence/clearUserPreferredPresenceRequestBuilder';
import { SetPresenceRequestBuilder } from './setPresence/setPresenceRequestBuilder';
import { SetStatusMessageRequestBuilder } from './setStatusMessage/setStatusMessageRequestBuilder';
import { SetUserPreferredPresenceRequestBuilder } from './setUserPreferredPresence/setUserPreferredPresenceRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PresenceRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PresenceRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PresenceRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PresenceRequestBuilderGetQueryParameters;
}
export interface PresenceRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the presence property of the microsoft.graph.user entity.
 */
export declare class PresenceRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clearPresence method.
     */
    get clearPresence(): ClearPresenceRequestBuilder;
    /**
     * Provides operations to call the clearUserPreferredPresence method.
     */
    get clearUserPreferredPresence(): ClearUserPreferredPresenceRequestBuilder;
    /**
     * Provides operations to call the setPresence method.
     */
    get setPresence(): SetPresenceRequestBuilder;
    /**
     * Provides operations to call the setStatusMessage method.
     */
    get setStatusMessage(): SetStatusMessageRequestBuilder;
    /**
     * Provides operations to call the setUserPreferredPresence method.
     */
    get setUserPreferredPresence(): SetUserPreferredPresenceRequestBuilder;
    /**
     * Instantiates a new PresenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property presence for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PresenceRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Set a presence status message for a user. An optional expiration date and time can be supplied. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Presence
     * @see {@link https://learn.microsoft.com/graph/api/presence-setstatusmessage?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PresenceRequestBuilderGetRequestConfiguration | undefined): Promise<Presence | undefined>;
    /**
     * Update the navigation property presence in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Presence
     */
    patch(body: Presence, requestConfiguration?: PresenceRequestBuilderPatchRequestConfiguration | undefined): Promise<Presence | undefined>;
    /**
     * Delete navigation property presence for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PresenceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Set a presence status message for a user. An optional expiration date and time can be supplied. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PresenceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property presence in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Presence, requestConfiguration?: PresenceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a presenceRequestBuilder
     */
    withUrl(rawUrl: string): PresenceRequestBuilder;
}
