import { type ChecklistItemCollectionResponse } from '../../../../../../../models/';
import { type ChecklistItem } from '../../../../../../../models/checklistItem';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ChecklistItemItemRequestBuilder } from './item/checklistItemItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ChecklistItemsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ChecklistItemsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ChecklistItemsRequestBuilderGetQueryParameters;
}
export interface ChecklistItemsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the checklistItems property of the microsoft.graph.todoTask entity.
 */
export declare class ChecklistItemsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the checklistItems property of the microsoft.graph.todoTask entity.
     * @param checklistItemId The unique identifier of checklistItem
     * @returns a ChecklistItemItemRequestBuilder
     */
    byChecklistItemId(checklistItemId: string): ChecklistItemItemRequestBuilder;
    /**
     * Instantiates a new ChecklistItemsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the checklistItem resources associated to a todoTask from the checklistItems navigation property. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChecklistItemCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/todotask-list-checklistitems?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ChecklistItemsRequestBuilderGetRequestConfiguration | undefined): Promise<ChecklistItemCollectionResponse | undefined>;
    /**
     * Create a new checklistItem object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChecklistItem
     * @see {@link https://learn.microsoft.com/graph/api/todotask-post-checklistitems?view=graph-rest-1.0|Find more info here}
     */
    post(body: ChecklistItem, requestConfiguration?: ChecklistItemsRequestBuilderPostRequestConfiguration | undefined): Promise<ChecklistItem | undefined>;
    /**
     * Get the checklistItem resources associated to a todoTask from the checklistItems navigation property. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ChecklistItemsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new checklistItem object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ChecklistItem, requestConfiguration?: ChecklistItemsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a checklistItemsRequestBuilder
     */
    withUrl(rawUrl: string): ChecklistItemsRequestBuilder;
}
