import { type Todo } from '../../models/todo';
import { ListsRequestBuilder } from './lists/listsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TodoRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface TodoRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface TodoRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TodoRequestBuilderGetQueryParameters;
}
export interface TodoRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the todo property of the microsoft.graph.user entity.
 */
export declare class TodoRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the lists property of the microsoft.graph.todo entity.
     */
    get lists(): ListsRequestBuilder;
    /**
     * Instantiates a new TodoRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property todo for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: TodoRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Represents the To Do services available to a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Todo
     */
    get(requestConfiguration?: TodoRequestBuilderGetRequestConfiguration | undefined): Promise<Todo | undefined>;
    /**
     * Update the navigation property todo in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Todo
     */
    patch(body: Todo, requestConfiguration?: TodoRequestBuilderPatchRequestConfiguration | undefined): Promise<Todo | undefined>;
    /**
     * Delete navigation property todo for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: TodoRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the To Do services available to a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TodoRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property todo in me
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Todo, requestConfiguration?: TodoRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a todoRequestBuilder
     */
    withUrl(rawUrl: string): TodoRequestBuilder;
}
