import { type AudioConferencing } from './audioConferencing';
import { type BroadcastMeetingSettings } from './broadcastMeetingSettings';
import { type CallTranscript } from './callTranscript';
import { type ChatInfo } from './chatInfo';
import { type Entity } from './entity';
import { type ItemBody } from './itemBody';
import { type JoinMeetingIdSettings } from './joinMeetingIdSettings';
import { type LobbyBypassSettings } from './lobbyBypassSettings';
import { type MeetingAttendanceReport } from './meetingAttendanceReport';
import { MeetingChatHistoryDefaultMode } from './meetingChatHistoryDefaultMode';
import { MeetingChatMode } from './meetingChatMode';
import { type MeetingParticipants } from './meetingParticipants';
import { OnlineMeetingPresenters } from './onlineMeetingPresenters';
import { type WatermarkProtectionValues } from './watermarkProtectionValues';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createOnlineMeetingFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoOnlineMeeting;
export declare function deserializeIntoOnlineMeeting(onlineMeeting?: OnlineMeeting | undefined): Record<string, (node: ParseNode) => void>;
export interface OnlineMeeting extends Entity, Parsable {
    /**
     * Indicates whether attendees can turn on their camera.
     */
    allowAttendeeToEnableCamera?: boolean;
    /**
     * Indicates whether attendees can turn on their microphone.
     */
    allowAttendeeToEnableMic?: boolean;
    /**
     * Specifies who can be a presenter in a meeting. Possible values are listed in the following table.
     */
    allowedPresenters?: OnlineMeetingPresenters;
    /**
     * Specifies the mode of meeting chat.
     */
    allowMeetingChat?: MeetingChatMode;
    /**
     * Specifies if participants are allowed to rename themselves in an instance of the meeting.
     */
    allowParticipantsToChangeName?: boolean;
    /**
     * Indicates whether Teams reactions are enabled for the meeting.
     */
    allowTeamworkReactions?: boolean;
    /**
     * The attendance reports of an online meeting. Read-only.
     */
    attendanceReports?: MeetingAttendanceReport[];
    /**
     * The attendeeReport property
     */
    attendeeReport?: string;
    /**
     * The phone access (dial-in) information for an online meeting. Read-only.
     */
    audioConferencing?: AudioConferencing;
    /**
     * The broadcastSettings property
     */
    broadcastSettings?: BroadcastMeetingSettings;
    /**
     * The chat information associated with this online meeting.
     */
    chatInfo?: ChatInfo;
    /**
     * The meeting creation time in UTC. Read-only.
     */
    creationDateTime?: Date;
    /**
     * The meeting end time in UTC.
     */
    endDateTime?: Date;
    /**
     * The externalId property
     */
    externalId?: string;
    /**
     * The isBroadcast property
     */
    isBroadcast?: boolean;
    /**
     * Indicates whether to announce when callers join or leave.
     */
    isEntryExitAnnounced?: boolean;
    /**
     * The join information in the language and locale variant specified in the Accept-Language request HTTP header. Read-only.
     */
    joinInformation?: ItemBody;
    /**
     * Specifies the joinMeetingId, the meeting passcode, and the requirement for the passcode. Once an onlineMeeting is created, the joinMeetingIdSettings cannot be modified. To make any changes to this property, the meeting needs to be canceled and a new one needs to be created.
     */
    joinMeetingIdSettings?: JoinMeetingIdSettings;
    /**
     * The join URL of the online meeting. Read-only.
     */
    joinWebUrl?: string;
    /**
     * Specifies which participants can bypass the meeting   lobby.
     */
    lobbyBypassSettings?: LobbyBypassSettings;
    /**
     * The participants associated with the online meeting.  This includes the organizer and the attendees.
     */
    participants?: MeetingParticipants;
    /**
     * Indicates whether to record the meeting automatically.
     */
    recordAutomatically?: boolean;
    /**
     * Specifies whether meeting chat history is shared with participants. Possible values are: all, none, unknownFutureValue.
     */
    shareMeetingChatHistoryDefault?: MeetingChatHistoryDefaultMode;
    /**
     * The meeting start time in UTC.
     */
    startDateTime?: Date;
    /**
     * The subject of the online meeting.
     */
    subject?: string;
    /**
     * The transcripts of an online meeting. Read-only.
     */
    transcripts?: CallTranscript[];
    /**
     * The video teleconferencing ID. Read-only.
     */
    videoTeleconferenceId?: string;
    /**
     * Specifies whether a watermark should be applied to a content type by the client application.
     */
    watermarkProtection?: WatermarkProtectionValues;
}
export declare function serializeOnlineMeeting(writer: SerializationWriter, onlineMeeting?: OnlineMeeting | undefined): void;
