import { type OrganizationalBranding } from '../../../models/organizationalBranding';
import { BackgroundImageRequestBuilder } from './backgroundImage/backgroundImageRequestBuilder';
import { BannerLogoRequestBuilder } from './bannerLogo/bannerLogoRequestBuilder';
import { CustomCSSRequestBuilder } from './customCSS/customCSSRequestBuilder';
import { FaviconRequestBuilder } from './favicon/faviconRequestBuilder';
import { HeaderLogoRequestBuilder } from './headerLogo/headerLogoRequestBuilder';
import { LocalizationsRequestBuilder } from './localizations/localizationsRequestBuilder';
import { SquareLogoRequestBuilder } from './squareLogo/squareLogoRequestBuilder';
import { SquareLogoDarkRequestBuilder } from './squareLogoDark/squareLogoDarkRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface BrandingRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface BrandingRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface BrandingRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: BrandingRequestBuilderGetQueryParameters;
}
export interface BrandingRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the branding property of the microsoft.graph.organization entity.
 */
export declare class BrandingRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get backgroundImage(): BackgroundImageRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get bannerLogo(): BannerLogoRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get customCSS(): CustomCSSRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get favicon(): FaviconRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get headerLogo(): HeaderLogoRequestBuilder;
    /**
     * Provides operations to manage the localizations property of the microsoft.graph.organizationalBranding entity.
     */
    get localizations(): LocalizationsRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get squareLogo(): SquareLogoRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get squareLogoDark(): SquareLogoDarkRequestBuilder;
    /**
     * Instantiates a new BrandingRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the default organizational branding object. To delete the organizationalBranding object, all images (Stream types) must first be removed from the object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbranding-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: BrandingRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the default organizational branding object, if the Accept-Language header is set to 0 or default. If no default organizational branding object exists, this method returns a 404 Not Found error. If the Accept-Language header is set to an existing locale identified by the value of its id, this method retrieves the branding for the specified locale. This method retrieves only non-Stream properties, for example, usernameHintText and signInPageText. To retrieve Stream types of the default branding, for example, bannerLogo and backgroundImage, use the GET organizationalBrandingLocalization method. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrganizationalBranding
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbranding-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: BrandingRequestBuilderGetRequestConfiguration | undefined): Promise<OrganizationalBranding | undefined>;
    /**
     * Update the properties of the default branding object specified by the organizationalBranding resource. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrganizationalBranding
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbranding-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OrganizationalBranding, requestConfiguration?: BrandingRequestBuilderPatchRequestConfiguration | undefined): Promise<OrganizationalBranding | undefined>;
    /**
     * Delete the default organizational branding object. To delete the organizationalBranding object, all images (Stream types) must first be removed from the object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: BrandingRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the default organizational branding object, if the Accept-Language header is set to 0 or default. If no default organizational branding object exists, this method returns a 404 Not Found error. If the Accept-Language header is set to an existing locale identified by the value of its id, this method retrieves the branding for the specified locale. This method retrieves only non-Stream properties, for example, usernameHintText and signInPageText. To retrieve Stream types of the default branding, for example, bannerLogo and backgroundImage, use the GET organizationalBrandingLocalization method. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: BrandingRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of the default branding object specified by the organizationalBranding resource. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OrganizationalBranding, requestConfiguration?: BrandingRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a brandingRequestBuilder
     */
    withUrl(rawUrl: string): BrandingRequestBuilder;
}
