import { type Planner } from '../models/planner';
import { BucketsRequestBuilder } from './buckets/bucketsRequestBuilder';
import { PlansRequestBuilder } from './plans/plansRequestBuilder';
import { TasksRequestBuilder } from './tasks/tasksRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PlannerRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PlannerRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PlannerRequestBuilderGetQueryParameters;
}
export interface PlannerRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the planner singleton.
 */
export declare class PlannerRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the buckets property of the microsoft.graph.planner entity.
     */
    get buckets(): BucketsRequestBuilder;
    /**
     * Provides operations to manage the plans property of the microsoft.graph.planner entity.
     */
    get plans(): PlansRequestBuilder;
    /**
     * Provides operations to manage the tasks property of the microsoft.graph.planner entity.
     */
    get tasks(): TasksRequestBuilder;
    /**
     * Instantiates a new PlannerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get planner
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Planner
     */
    get(requestConfiguration?: PlannerRequestBuilderGetRequestConfiguration | undefined): Promise<Planner | undefined>;
    /**
     * Update planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Planner
     */
    patch(body: Planner, requestConfiguration?: PlannerRequestBuilderPatchRequestConfiguration | undefined): Promise<Planner | undefined>;
    /**
     * Get planner
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PlannerRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Planner, requestConfiguration?: PlannerRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a plannerRequestBuilder
     */
    withUrl(rawUrl: string): PlannerRequestBuilder;
}
