import { type PlannerPlanCollectionResponse } from '../../models/';
import { type PlannerPlan } from '../../models/plannerPlan';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { PlannerPlanItemRequestBuilder } from './item/plannerPlanItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PlansRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface PlansRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PlansRequestBuilderGetQueryParameters;
}
export interface PlansRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the plans property of the microsoft.graph.planner entity.
 */
export declare class PlansRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the plans property of the microsoft.graph.planner entity.
     * @param plannerPlanId The unique identifier of plannerPlan
     * @returns a PlannerPlanItemRequestBuilder
     */
    byPlannerPlanId(plannerPlanId: string): PlannerPlanItemRequestBuilder;
    /**
     * Instantiates a new PlansRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of plannerPlan objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerPlanCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/planner-list-plans?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PlansRequestBuilderGetRequestConfiguration | undefined): Promise<PlannerPlanCollectionResponse | undefined>;
    /**
     * Use this API to create a new plannerPlan. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerPlan
     * @see {@link https://learn.microsoft.com/graph/api/planner-post-plans?view=graph-rest-1.0|Find more info here}
     */
    post(body: PlannerPlan, requestConfiguration?: PlansRequestBuilderPostRequestConfiguration | undefined): Promise<PlannerPlan | undefined>;
    /**
     * Get a list of plannerPlan objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PlansRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Use this API to create a new plannerPlan. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PlannerPlan, requestConfiguration?: PlansRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a plansRequestBuilder
     */
    withUrl(rawUrl: string): PlansRequestBuilder;
}
