import { type CrossTenantIdentitySyncPolicyPartner } from '../../../../../models/crossTenantIdentitySyncPolicyPartner';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface IdentitySynchronizationRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface IdentitySynchronizationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface IdentitySynchronizationRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: IdentitySynchronizationRequestBuilderGetQueryParameters;
}
export interface IdentitySynchronizationRequestBuilderPutRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the identitySynchronization property of the microsoft.graph.crossTenantAccessPolicyConfigurationPartner entity.
 */
export declare class IdentitySynchronizationRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new IdentitySynchronizationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the user synchronization policy for a partner-specific configuration. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/crosstenantidentitysyncpolicypartner-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: IdentitySynchronizationRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the user synchronization policy of a partner-specific configuration. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CrossTenantIdentitySyncPolicyPartner
     * @see {@link https://learn.microsoft.com/graph/api/crosstenantidentitysyncpolicypartner-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: IdentitySynchronizationRequestBuilderGetRequestConfiguration | undefined): Promise<CrossTenantIdentitySyncPolicyPartner | undefined>;
    /**
     * Update the navigation property identitySynchronization in policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CrossTenantIdentitySyncPolicyPartner
     */
    put(body: CrossTenantIdentitySyncPolicyPartner, requestConfiguration?: IdentitySynchronizationRequestBuilderPutRequestConfiguration | undefined): Promise<CrossTenantIdentitySyncPolicyPartner | undefined>;
    /**
     * Delete the user synchronization policy for a partner-specific configuration. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: IdentitySynchronizationRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the user synchronization policy of a partner-specific configuration. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: IdentitySynchronizationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property identitySynchronization in policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPutRequestInformation(body: CrossTenantIdentitySyncPolicyPartner, requestConfiguration?: IdentitySynchronizationRequestBuilderPutRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a identitySynchronizationRequestBuilder
     */
    withUrl(rawUrl: string): IdentitySynchronizationRequestBuilder;
}
