import { type TenantAppManagementPolicy } from '../../models/tenantAppManagementPolicy';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DefaultAppManagementPolicyRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface DefaultAppManagementPolicyRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DefaultAppManagementPolicyRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DefaultAppManagementPolicyRequestBuilderGetQueryParameters;
}
export interface DefaultAppManagementPolicyRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the defaultAppManagementPolicy property of the microsoft.graph.policyRoot entity.
 */
export declare class DefaultAppManagementPolicyRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new DefaultAppManagementPolicyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property defaultAppManagementPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: DefaultAppManagementPolicyRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties of a tenantAppManagementPolicy object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantAppManagementPolicy
     * @see {@link https://learn.microsoft.com/graph/api/tenantappmanagementpolicy-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: DefaultAppManagementPolicyRequestBuilderGetRequestConfiguration | undefined): Promise<TenantAppManagementPolicy | undefined>;
    /**
     * Update the properties of a tenantAppManagementPolicy object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantAppManagementPolicy
     * @see {@link https://learn.microsoft.com/graph/api/tenantappmanagementpolicy-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: TenantAppManagementPolicy, requestConfiguration?: DefaultAppManagementPolicyRequestBuilderPatchRequestConfiguration | undefined): Promise<TenantAppManagementPolicy | undefined>;
    /**
     * Delete navigation property defaultAppManagementPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: DefaultAppManagementPolicyRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties of a tenantAppManagementPolicy object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DefaultAppManagementPolicyRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a tenantAppManagementPolicy object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: TenantAppManagementPolicy, requestConfiguration?: DefaultAppManagementPolicyRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a defaultAppManagementPolicyRequestBuilder
     */
    withUrl(rawUrl: string): DefaultAppManagementPolicyRequestBuilder;
}
