import { type TokenIssuancePolicyCollectionResponse } from '../../models/';
import { type TokenIssuancePolicy } from '../../models/tokenIssuancePolicy';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TokenIssuancePolicyItemRequestBuilder } from './item/tokenIssuancePolicyItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TokenIssuancePoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TokenIssuancePoliciesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TokenIssuancePoliciesRequestBuilderGetQueryParameters;
}
export interface TokenIssuancePoliciesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.policyRoot entity.
 */
export declare class TokenIssuancePoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.policyRoot entity.
     * @param tokenIssuancePolicyId The unique identifier of tokenIssuancePolicy
     * @returns a TokenIssuancePolicyItemRequestBuilder
     */
    byTokenIssuancePolicyId(tokenIssuancePolicyId: string): TokenIssuancePolicyItemRequestBuilder;
    /**
     * Instantiates a new TokenIssuancePoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of tokenIssuancePolicy objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TokenIssuancePolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/tokenissuancepolicy-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TokenIssuancePoliciesRequestBuilderGetRequestConfiguration | undefined): Promise<TokenIssuancePolicyCollectionResponse | undefined>;
    /**
     * Create a new tokenIssuancePolicy object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TokenIssuancePolicy
     * @see {@link https://learn.microsoft.com/graph/api/tokenissuancepolicy-post-tokenissuancepolicy?view=graph-rest-1.0|Find more info here}
     */
    post(body: TokenIssuancePolicy, requestConfiguration?: TokenIssuancePoliciesRequestBuilderPostRequestConfiguration | undefined): Promise<TokenIssuancePolicy | undefined>;
    /**
     * Get a list of tokenIssuancePolicy objects. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TokenIssuancePoliciesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new tokenIssuancePolicy object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TokenIssuancePolicy, requestConfiguration?: TokenIssuancePoliciesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tokenIssuancePoliciesRequestBuilder
     */
    withUrl(rawUrl: string): TokenIssuancePoliciesRequestBuilder;
}
