import { type PrintServiceEndpoint } from '../../../../../models/printServiceEndpoint';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrintServiceEndpointItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrintServiceEndpointItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrintServiceEndpointItemRequestBuilderGetQueryParameters;
}
export interface PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the endpoints property of the microsoft.graph.printService entity.
 */
export declare class PrintServiceEndpointItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PrintServiceEndpointItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property endpoints for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a print service endpoint. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintServiceEndpoint
     * @see {@link https://learn.microsoft.com/graph/api/printserviceendpoint-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PrintServiceEndpointItemRequestBuilderGetRequestConfiguration | undefined): Promise<PrintServiceEndpoint | undefined>;
    /**
     * Update the navigation property endpoints in print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintServiceEndpoint
     */
    patch(body: PrintServiceEndpoint, requestConfiguration?: PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration | undefined): Promise<PrintServiceEndpoint | undefined>;
    /**
     * Delete navigation property endpoints for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a print service endpoint. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrintServiceEndpointItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property endpoints in print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrintServiceEndpoint, requestConfiguration?: PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrintServiceEndpointItemRequestBuilder
     */
    withUrl(rawUrl: string): PrintServiceEndpointItemRequestBuilder;
}
