import { type PrintUsageByUser } from '../../../models/printUsageByUser';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrintUsageByUserItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrintUsageByUserItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrintUsageByUserItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrintUsageByUserItemRequestBuilderGetQueryParameters;
}
export interface PrintUsageByUserItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the dailyPrintUsageByUser property of the microsoft.graph.reportRoot entity.
 */
export declare class PrintUsageByUserItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PrintUsageByUserItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property dailyPrintUsageByUser for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrintUsageByUserItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve a user's usage summary for a particular time period. For descriptions of each endpoint, see printUsageByUser. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintUsageByUser
     * @see {@link https://learn.microsoft.com/graph/api/printusagebyuser-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PrintUsageByUserItemRequestBuilderGetRequestConfiguration | undefined): Promise<PrintUsageByUser | undefined>;
    /**
     * Update the navigation property dailyPrintUsageByUser in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintUsageByUser
     */
    patch(body: PrintUsageByUser, requestConfiguration?: PrintUsageByUserItemRequestBuilderPatchRequestConfiguration | undefined): Promise<PrintUsageByUser | undefined>;
    /**
     * Delete navigation property dailyPrintUsageByUser for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrintUsageByUserItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a user's usage summary for a particular time period. For descriptions of each endpoint, see printUsageByUser. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrintUsageByUserItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property dailyPrintUsageByUser in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrintUsageByUser, requestConfiguration?: PrintUsageByUserItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrintUsageByUserItemRequestBuilder
     */
    withUrl(rawUrl: string): PrintUsageByUserItemRequestBuilder;
}
