import { type PrintUsageByPrinterCollectionResponse } from '../../models/';
import { type PrintUsageByPrinter } from '../../models/printUsageByPrinter';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { PrintUsageByPrinterItemRequestBuilder } from './item/printUsageByPrinterItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface MonthlyPrintUsageByPrinterRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface MonthlyPrintUsageByPrinterRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: MonthlyPrintUsageByPrinterRequestBuilderGetQueryParameters;
}
export interface MonthlyPrintUsageByPrinterRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the monthlyPrintUsageByPrinter property of the microsoft.graph.reportRoot entity.
 */
export declare class MonthlyPrintUsageByPrinterRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the monthlyPrintUsageByPrinter property of the microsoft.graph.reportRoot entity.
     * @param printUsageByPrinterId The unique identifier of printUsageByPrinter
     * @returns a PrintUsageByPrinterItemRequestBuilder
     */
    byPrintUsageByPrinterId(printUsageByPrinterId: string): PrintUsageByPrinterItemRequestBuilder;
    /**
     * Instantiates a new MonthlyPrintUsageByPrinterRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of monthly print usage summaries, grouped by printer. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintUsageByPrinterCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/reportroot-list-monthlyprintusagebyprinter?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: MonthlyPrintUsageByPrinterRequestBuilderGetRequestConfiguration | undefined): Promise<PrintUsageByPrinterCollectionResponse | undefined>;
    /**
     * Create new navigation property to monthlyPrintUsageByPrinter for reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintUsageByPrinter
     */
    post(body: PrintUsageByPrinter, requestConfiguration?: MonthlyPrintUsageByPrinterRequestBuilderPostRequestConfiguration | undefined): Promise<PrintUsageByPrinter | undefined>;
    /**
     * Retrieve a list of monthly print usage summaries, grouped by printer. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: MonthlyPrintUsageByPrinterRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to monthlyPrintUsageByPrinter for reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PrintUsageByPrinter, requestConfiguration?: MonthlyPrintUsageByPrinterRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a monthlyPrintUsageByPrinterRequestBuilder
     */
    withUrl(rawUrl: string): MonthlyPrintUsageByPrinterRequestBuilder;
}
