import { type UnifiedRbacResourceActionCollectionResponse } from '../../../../../models/';
import { type UnifiedRbacResourceAction } from '../../../../../models/unifiedRbacResourceAction';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { UnifiedRbacResourceActionItemRequestBuilder } from './item/unifiedRbacResourceActionItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ResourceActionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ResourceActionsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ResourceActionsRequestBuilderGetQueryParameters;
}
export interface ResourceActionsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the resourceActions property of the microsoft.graph.unifiedRbacResourceNamespace entity.
 */
export declare class ResourceActionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the resourceActions property of the microsoft.graph.unifiedRbacResourceNamespace entity.
     * @param unifiedRbacResourceActionId The unique identifier of unifiedRbacResourceAction
     * @returns a UnifiedRbacResourceActionItemRequestBuilder
     */
    byUnifiedRbacResourceActionId(unifiedRbacResourceActionId: string): UnifiedRbacResourceActionItemRequestBuilder;
    /**
     * Instantiates a new ResourceActionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get resourceActions from roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRbacResourceActionCollectionResponse
     */
    get(requestConfiguration?: ResourceActionsRequestBuilderGetRequestConfiguration | undefined): Promise<UnifiedRbacResourceActionCollectionResponse | undefined>;
    /**
     * Create new navigation property to resourceActions for roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRbacResourceAction
     */
    post(body: UnifiedRbacResourceAction, requestConfiguration?: ResourceActionsRequestBuilderPostRequestConfiguration | undefined): Promise<UnifiedRbacResourceAction | undefined>;
    /**
     * Get resourceActions from roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ResourceActionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to resourceActions for roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UnifiedRbacResourceAction, requestConfiguration?: ResourceActionsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a resourceActionsRequestBuilder
     */
    withUrl(rawUrl: string): ResourceActionsRequestBuilder;
}
