"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleEligibilityScheduleInstancesRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const unifiedRoleEligibilityScheduleInstance_1 = require("../../../models/unifiedRoleEligibilityScheduleInstance");
const unifiedRoleEligibilityScheduleInstanceCollectionResponse_1 = require("../../../models/unifiedRoleEligibilityScheduleInstanceCollectionResponse");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const filterByCurrentUserWithOnRequestBuilder_1 = require("./filterByCurrentUserWithOn/filterByCurrentUserWithOnRequestBuilder");
const unifiedRoleEligibilityScheduleInstanceItemRequestBuilder_1 = require("./item/unifiedRoleEligibilityScheduleInstanceItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the roleEligibilityScheduleInstances property of the microsoft.graph.rbacApplication entity.
 */
class RoleEligibilityScheduleInstancesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the roleEligibilityScheduleInstances property of the microsoft.graph.rbacApplication entity.
     * @param unifiedRoleEligibilityScheduleInstanceId The unique identifier of unifiedRoleEligibilityScheduleInstance
     * @returns a UnifiedRoleEligibilityScheduleInstanceItemRequestBuilder
     */
    byUnifiedRoleEligibilityScheduleInstanceId(unifiedRoleEligibilityScheduleInstanceId) {
        if (!unifiedRoleEligibilityScheduleInstanceId)
            throw new Error("unifiedRoleEligibilityScheduleInstanceId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["unifiedRoleEligibilityScheduleInstance%2Did"] = unifiedRoleEligibilityScheduleInstanceId;
        return new unifiedRoleEligibilityScheduleInstanceItemRequestBuilder_1.UnifiedRoleEligibilityScheduleInstanceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new RoleEligibilityScheduleInstancesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/roleManagement/entitlementManagement/roleEligibilityScheduleInstances{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on) {
        if (!on)
            throw new Error("on cannot be undefined");
        return new filterByCurrentUserWithOnRequestBuilder_1.FilterByCurrentUserWithOnRequestBuilder(this.pathParameters, this.requestAdapter, on);
    }
    ;
    /**
     * Get the instances of role eligibilities. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleEligibilityScheduleInstanceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/rbacapplication-list-roleeligibilityscheduleinstances?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, unifiedRoleEligibilityScheduleInstanceCollectionResponse_1.createUnifiedRoleEligibilityScheduleInstanceCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to roleEligibilityScheduleInstances for roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleEligibilityScheduleInstance
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, unifiedRoleEligibilityScheduleInstance_1.createUnifiedRoleEligibilityScheduleInstanceFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get the instances of role eligibilities. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to roleEligibilityScheduleInstances for roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, unifiedRoleEligibilityScheduleInstance_1.serializeUnifiedRoleEligibilityScheduleInstance);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a roleEligibilityScheduleInstancesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RoleEligibilityScheduleInstancesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RoleEligibilityScheduleInstancesRequestBuilder = RoleEligibilityScheduleInstancesRequestBuilder;
// tslint:enable
// eslint-enable
