import { type EndUserNotificationCollectionResponse } from '../../../models/';
import { type EndUserNotification } from '../../../models/endUserNotification';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { EndUserNotificationItemRequestBuilder } from './item/endUserNotificationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EndUserNotificationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface EndUserNotificationsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EndUserNotificationsRequestBuilderGetQueryParameters;
}
export interface EndUserNotificationsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the endUserNotifications property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class EndUserNotificationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the endUserNotifications property of the microsoft.graph.attackSimulationRoot entity.
     * @param endUserNotificationId The unique identifier of endUserNotification
     * @returns a EndUserNotificationItemRequestBuilder
     */
    byEndUserNotificationId(endUserNotificationId: string): EndUserNotificationItemRequestBuilder;
    /**
     * Instantiates a new EndUserNotificationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get endUserNotifications from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotificationCollectionResponse
     */
    get(requestConfiguration?: EndUserNotificationsRequestBuilderGetRequestConfiguration | undefined): Promise<EndUserNotificationCollectionResponse | undefined>;
    /**
     * Create new navigation property to endUserNotifications for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotification
     */
    post(body: EndUserNotification, requestConfiguration?: EndUserNotificationsRequestBuilderPostRequestConfiguration | undefined): Promise<EndUserNotification | undefined>;
    /**
     * Get endUserNotifications from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EndUserNotificationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to endUserNotifications for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EndUserNotification, requestConfiguration?: EndUserNotificationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a endUserNotificationsRequestBuilder
     */
    withUrl(rawUrl: string): EndUserNotificationsRequestBuilder;
}
