import { type LandingPageDetailCollectionResponse } from '../../../../../models/';
import { type LandingPageDetail } from '../../../../../models/landingPageDetail';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { LandingPageDetailItemRequestBuilder } from './item/landingPageDetailItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface DetailsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DetailsRequestBuilderGetQueryParameters;
}
export interface DetailsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the details property of the microsoft.graph.landingPage entity.
 */
export declare class DetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the details property of the microsoft.graph.landingPage entity.
     * @param landingPageDetailId The unique identifier of landingPageDetail
     * @returns a LandingPageDetailItemRequestBuilder
     */
    byLandingPageDetailId(landingPageDetailId: string): LandingPageDetailItemRequestBuilder;
    /**
     * Instantiates a new DetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get details from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LandingPageDetailCollectionResponse
     */
    get(requestConfiguration?: DetailsRequestBuilderGetRequestConfiguration | undefined): Promise<LandingPageDetailCollectionResponse | undefined>;
    /**
     * Create new navigation property to details for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LandingPageDetail
     */
    post(body: LandingPageDetail, requestConfiguration?: DetailsRequestBuilderPostRequestConfiguration | undefined): Promise<LandingPageDetail | undefined>;
    /**
     * Get details from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DetailsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to details for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LandingPageDetail, requestConfiguration?: DetailsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a detailsRequestBuilder
     */
    withUrl(rawUrl: string): DetailsRequestBuilder;
}
