import { type LoginPageCollectionResponse } from '../../../models/';
import { type LoginPage } from '../../../models/loginPage';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { LoginPageItemRequestBuilder } from './item/loginPageItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LoginPagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface LoginPagesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LoginPagesRequestBuilderGetQueryParameters;
}
export interface LoginPagesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the loginPages property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class LoginPagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the loginPages property of the microsoft.graph.attackSimulationRoot entity.
     * @param loginPageId The unique identifier of loginPage
     * @returns a LoginPageItemRequestBuilder
     */
    byLoginPageId(loginPageId: string): LoginPageItemRequestBuilder;
    /**
     * Instantiates a new LoginPagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get loginPages from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LoginPageCollectionResponse
     */
    get(requestConfiguration?: LoginPagesRequestBuilderGetRequestConfiguration | undefined): Promise<LoginPageCollectionResponse | undefined>;
    /**
     * Create new navigation property to loginPages for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LoginPage
     */
    post(body: LoginPage, requestConfiguration?: LoginPagesRequestBuilderPostRequestConfiguration | undefined): Promise<LoginPage | undefined>;
    /**
     * Get loginPages from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LoginPagesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to loginPages for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LoginPage, requestConfiguration?: LoginPagesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a loginPagesRequestBuilder
     */
    withUrl(rawUrl: string): LoginPagesRequestBuilder;
}
