import { type AttackSimulationOperationCollectionResponse } from '../../../models/';
import { type AttackSimulationOperation } from '../../../models/attackSimulationOperation';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AttackSimulationOperationItemRequestBuilder } from './item/attackSimulationOperationItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OperationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface OperationsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OperationsRequestBuilderGetQueryParameters;
}
export interface OperationsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the operations property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class OperationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.attackSimulationRoot entity.
     * @param attackSimulationOperationId The unique identifier of attackSimulationOperation
     * @returns a AttackSimulationOperationItemRequestBuilder
     */
    byAttackSimulationOperationId(attackSimulationOperationId: string): AttackSimulationOperationItemRequestBuilder;
    /**
     * Instantiates a new OperationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get operations from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttackSimulationOperationCollectionResponse
     */
    get(requestConfiguration?: OperationsRequestBuilderGetRequestConfiguration | undefined): Promise<AttackSimulationOperationCollectionResponse | undefined>;
    /**
     * Create new navigation property to operations for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttackSimulationOperation
     */
    post(body: AttackSimulationOperation, requestConfiguration?: OperationsRequestBuilderPostRequestConfiguration | undefined): Promise<AttackSimulationOperation | undefined>;
    /**
     * Get operations from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OperationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to operations for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AttackSimulationOperation, requestConfiguration?: OperationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a operationsRequestBuilder
     */
    withUrl(rawUrl: string): OperationsRequestBuilder;
}
