import { type SimulationAutomationRunCollectionResponse } from '../../../../../models/';
import { type SimulationAutomationRun } from '../../../../../models/simulationAutomationRun';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { SimulationAutomationRunItemRequestBuilder } from './item/simulationAutomationRunItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface RunsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface RunsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: RunsRequestBuilderGetQueryParameters;
}
export interface RunsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the runs property of the microsoft.graph.simulationAutomation entity.
 */
export declare class RunsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the runs property of the microsoft.graph.simulationAutomation entity.
     * @param simulationAutomationRunId The unique identifier of simulationAutomationRun
     * @returns a SimulationAutomationRunItemRequestBuilder
     */
    bySimulationAutomationRunId(simulationAutomationRunId: string): SimulationAutomationRunItemRequestBuilder;
    /**
     * Instantiates a new RunsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the attack simulation automation runs for a tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SimulationAutomationRunCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/simulationautomation-list-runs?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RunsRequestBuilderGetRequestConfiguration | undefined): Promise<SimulationAutomationRunCollectionResponse | undefined>;
    /**
     * Create new navigation property to runs for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SimulationAutomationRun
     */
    post(body: SimulationAutomationRun, requestConfiguration?: RunsRequestBuilderPostRequestConfiguration | undefined): Promise<SimulationAutomationRun | undefined>;
    /**
     * Get a list of the attack simulation automation runs for a tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RunsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to runs for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SimulationAutomationRun, requestConfiguration?: RunsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a runsRequestBuilder
     */
    withUrl(rawUrl: string): RunsRequestBuilder;
}
