import { type Simulation } from '../../../../models/simulation';
import { LandingPageRequestBuilder } from './landingPage/landingPageRequestBuilder';
import { LoginPageRequestBuilder } from './loginPage/loginPageRequestBuilder';
import { PayloadRequestBuilder } from './payload/payloadRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SimulationItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SimulationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SimulationItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SimulationItemRequestBuilderGetQueryParameters;
}
export interface SimulationItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the simulations property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class SimulationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the landingPage property of the microsoft.graph.simulation entity.
     */
    get landingPage(): LandingPageRequestBuilder;
    /**
     * Provides operations to manage the loginPage property of the microsoft.graph.simulation entity.
     */
    get loginPage(): LoginPageRequestBuilder;
    /**
     * Provides operations to manage the payload property of the microsoft.graph.simulation entity.
     */
    get payload(): PayloadRequestBuilder;
    /**
     * Instantiates a new SimulationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property simulations for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SimulationItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get an attack simulation campaign for a tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Simulation
     * @see {@link https://learn.microsoft.com/graph/api/simulation-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SimulationItemRequestBuilderGetRequestConfiguration | undefined): Promise<Simulation | undefined>;
    /**
     * Update the navigation property simulations in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Simulation
     */
    patch(body: Simulation, requestConfiguration?: SimulationItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Simulation | undefined>;
    /**
     * Delete navigation property simulations for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SimulationItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get an attack simulation campaign for a tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SimulationItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property simulations in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Simulation, requestConfiguration?: SimulationItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SimulationItemRequestBuilder
     */
    withUrl(rawUrl: string): SimulationItemRequestBuilder;
}
