import { type Training } from '../../../../models/training';
import { LanguageDetailsRequestBuilder } from './languageDetails/languageDetailsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TrainingItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface TrainingItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface TrainingItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TrainingItemRequestBuilderGetQueryParameters;
}
export interface TrainingItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the trainings property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class TrainingItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the languageDetails property of the microsoft.graph.training entity.
     */
    get languageDetails(): LanguageDetailsRequestBuilder;
    /**
     * Instantiates a new TrainingItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property trainings for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: TrainingItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get trainings from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Training
     */
    get(requestConfiguration?: TrainingItemRequestBuilderGetRequestConfiguration | undefined): Promise<Training | undefined>;
    /**
     * Update the navigation property trainings in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Training
     */
    patch(body: Training, requestConfiguration?: TrainingItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Training | undefined>;
    /**
     * Delete navigation property trainings for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: TrainingItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get trainings from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TrainingItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property trainings in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Training, requestConfiguration?: TrainingItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a TrainingItemRequestBuilder
     */
    withUrl(rawUrl: string): TrainingItemRequestBuilder;
}
