import { type EdiscoveryCustodian } from '../../../../../../models/security/ediscoveryCustodian';
import { LastIndexOperationRequestBuilder } from './lastIndexOperation/lastIndexOperationRequestBuilder';
import { MicrosoftGraphSecurityActivateRequestBuilder } from './microsoftGraphSecurityActivate/microsoftGraphSecurityActivateRequestBuilder';
import { MicrosoftGraphSecurityApplyHoldRequestBuilder } from './microsoftGraphSecurityApplyHold/microsoftGraphSecurityApplyHoldRequestBuilder';
import { MicrosoftGraphSecurityReleaseRequestBuilder } from './microsoftGraphSecurityRelease/microsoftGraphSecurityReleaseRequestBuilder';
import { MicrosoftGraphSecurityRemoveHoldRequestBuilder } from './microsoftGraphSecurityRemoveHold/microsoftGraphSecurityRemoveHoldRequestBuilder';
import { MicrosoftGraphSecurityUpdateIndexRequestBuilder } from './microsoftGraphSecurityUpdateIndex/microsoftGraphSecurityUpdateIndexRequestBuilder';
import { SiteSourcesRequestBuilder } from './siteSources/siteSourcesRequestBuilder';
import { UnifiedGroupSourcesRequestBuilder } from './unifiedGroupSources/unifiedGroupSourcesRequestBuilder';
import { UserSourcesRequestBuilder } from './userSources/userSourcesRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface EdiscoveryCustodianItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface EdiscoveryCustodianItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface EdiscoveryCustodianItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: EdiscoveryCustodianItemRequestBuilderGetQueryParameters;
}
export interface EdiscoveryCustodianItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the custodians property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class EdiscoveryCustodianItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the lastIndexOperation property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get lastIndexOperation(): LastIndexOperationRequestBuilder;
    /**
     * Provides operations to call the activate method.
     */
    get microsoftGraphSecurityActivate(): MicrosoftGraphSecurityActivateRequestBuilder;
    /**
     * Provides operations to call the applyHold method.
     */
    get microsoftGraphSecurityApplyHold(): MicrosoftGraphSecurityApplyHoldRequestBuilder;
    /**
     * Provides operations to call the release method.
     */
    get microsoftGraphSecurityRelease(): MicrosoftGraphSecurityReleaseRequestBuilder;
    /**
     * Provides operations to call the removeHold method.
     */
    get microsoftGraphSecurityRemoveHold(): MicrosoftGraphSecurityRemoveHoldRequestBuilder;
    /**
     * Provides operations to call the updateIndex method.
     */
    get microsoftGraphSecurityUpdateIndex(): MicrosoftGraphSecurityUpdateIndexRequestBuilder;
    /**
     * Provides operations to manage the siteSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get siteSources(): SiteSourcesRequestBuilder;
    /**
     * Provides operations to manage the unifiedGroupSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get unifiedGroupSources(): UnifiedGroupSourcesRequestBuilder;
    /**
     * Provides operations to manage the userSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get userSources(): UserSourcesRequestBuilder;
    /**
     * Instantiates a new EdiscoveryCustodianItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property custodians for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: EdiscoveryCustodianItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an ediscoveryCustodian object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCustodian
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycustodian-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: EdiscoveryCustodianItemRequestBuilderGetRequestConfiguration | undefined): Promise<EdiscoveryCustodian | undefined>;
    /**
     * Update the navigation property custodians in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCustodian
     */
    patch(body: EdiscoveryCustodian, requestConfiguration?: EdiscoveryCustodianItemRequestBuilderPatchRequestConfiguration | undefined): Promise<EdiscoveryCustodian | undefined>;
    /**
     * Delete navigation property custodians for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: EdiscoveryCustodianItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an ediscoveryCustodian object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: EdiscoveryCustodianItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property custodians in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EdiscoveryCustodian, requestConfiguration?: EdiscoveryCustodianItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EdiscoveryCustodianItemRequestBuilder
     */
    withUrl(rawUrl: string): EdiscoveryCustodianItemRequestBuilder;
}
