import { type SiteSource } from '../../../../../../../../models/security/siteSource';
import { SiteRequestBuilder } from './site/siteRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SiteSourceItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SiteSourceItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SiteSourceItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SiteSourceItemRequestBuilderGetQueryParameters;
}
export interface SiteSourceItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the siteSources property of the microsoft.graph.security.ediscoveryCustodian entity.
 */
export declare class SiteSourceItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the site property of the microsoft.graph.security.siteSource entity.
     */
    get site(): SiteRequestBuilder;
    /**
     * Instantiates a new SiteSourceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property siteSources for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SiteSourceItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Data source entity for SharePoint sites associated with the custodian.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SiteSource
     */
    get(requestConfiguration?: SiteSourceItemRequestBuilderGetRequestConfiguration | undefined): Promise<SiteSource | undefined>;
    /**
     * Update the navigation property siteSources in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SiteSource
     */
    patch(body: SiteSource, requestConfiguration?: SiteSourceItemRequestBuilderPatchRequestConfiguration | undefined): Promise<SiteSource | undefined>;
    /**
     * Delete navigation property siteSources for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SiteSourceItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Data source entity for SharePoint sites associated with the custodian.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SiteSourceItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property siteSources in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SiteSource, requestConfiguration?: SiteSourceItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SiteSourceItemRequestBuilder
     */
    withUrl(rawUrl: string): SiteSourceItemRequestBuilder;
}
