import { type DataSource } from '../../../../../../../models/security/dataSource';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface DataSourceRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface DataSourceRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface DataSourceRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: DataSourceRequestBuilderGetQueryParameters;
}
export interface DataSourceRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the dataSource property of the microsoft.graph.security.ediscoveryNoncustodialDataSource entity.
 */
export declare class DataSourceRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new DataSourceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property dataSource for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: DataSourceRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * User source or SharePoint site data source as noncustodial data source.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataSource
     */
    get(requestConfiguration?: DataSourceRequestBuilderGetRequestConfiguration | undefined): Promise<DataSource | undefined>;
    /**
     * Update the navigation property dataSource in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataSource
     */
    patch(body: DataSource, requestConfiguration?: DataSourceRequestBuilderPatchRequestConfiguration | undefined): Promise<DataSource | undefined>;
    /**
     * Delete navigation property dataSource for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: DataSourceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * User source or SharePoint site data source as noncustodial data source.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: DataSourceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property dataSource in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DataSource, requestConfiguration?: DataSourceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a dataSourceRequestBuilder
     */
    withUrl(rawUrl: string): DataSourceRequestBuilder;
}
