import { type EdiscoveryReviewSetCollectionResponse } from '../../../../../models/security/';
import { type EdiscoveryReviewSet } from '../../../../../models/security/ediscoveryReviewSet';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { EdiscoveryReviewSetItemRequestBuilder } from './item/ediscoveryReviewSetItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ReviewSetsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ReviewSetsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ReviewSetsRequestBuilderGetQueryParameters;
}
export interface ReviewSetsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the reviewSets property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class ReviewSetsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the reviewSets property of the microsoft.graph.security.ediscoveryCase entity.
     * @param ediscoveryReviewSetId The unique identifier of ediscoveryReviewSet
     * @returns a EdiscoveryReviewSetItemRequestBuilder
     */
    byEdiscoveryReviewSetId(ediscoveryReviewSetId: string): EdiscoveryReviewSetItemRequestBuilder;
    /**
     * Instantiates a new ReviewSetsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of ediscoveryReviewSet objects associated with an eDiscovery case. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewSetCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-list-reviewsets?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ReviewSetsRequestBuilderGetRequestConfiguration | undefined): Promise<EdiscoveryReviewSetCollectionResponse | undefined>;
    /**
     * Create a new ediscoveryReviewSet object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewSet
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-post-reviewsets?view=graph-rest-1.0|Find more info here}
     */
    post(body: EdiscoveryReviewSet, requestConfiguration?: ReviewSetsRequestBuilderPostRequestConfiguration | undefined): Promise<EdiscoveryReviewSet | undefined>;
    /**
     * Get a list of ediscoveryReviewSet objects associated with an eDiscovery case. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ReviewSetsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new ediscoveryReviewSet object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EdiscoveryReviewSet, requestConfiguration?: ReviewSetsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a reviewSetsRequestBuilder
     */
    withUrl(rawUrl: string): ReviewSetsRequestBuilder;
}
