import { type EdiscoverySearchCollectionResponse } from '../../../../../models/security/';
import { type EdiscoverySearch } from '../../../../../models/security/ediscoverySearch';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { EdiscoverySearchItemRequestBuilder } from './item/ediscoverySearchItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SearchesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface SearchesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SearchesRequestBuilderGetQueryParameters;
}
export interface SearchesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the searches property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class SearchesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the searches property of the microsoft.graph.security.ediscoveryCase entity.
     * @param ediscoverySearchId The unique identifier of ediscoverySearch
     * @returns a EdiscoverySearchItemRequestBuilder
     */
    byEdiscoverySearchId(ediscoverySearchId: string): EdiscoverySearchItemRequestBuilder;
    /**
     * Instantiates a new SearchesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of ediscoverySearch resources from an eDiscoveryCase object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoverySearchCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-list-searches?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SearchesRequestBuilderGetRequestConfiguration | undefined): Promise<EdiscoverySearchCollectionResponse | undefined>;
    /**
     * Create a new ediscoverySearch object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoverySearch
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-post-searches?view=graph-rest-1.0|Find more info here}
     */
    post(body: EdiscoverySearch, requestConfiguration?: SearchesRequestBuilderPostRequestConfiguration | undefined): Promise<EdiscoverySearch | undefined>;
    /**
     * Get the list of ediscoverySearch resources from an eDiscoveryCase object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SearchesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new ediscoverySearch object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EdiscoverySearch, requestConfiguration?: SearchesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a searchesRequestBuilder
     */
    withUrl(rawUrl: string): SearchesRequestBuilder;
}
