import { type EdiscoveryCaseSettings } from '../../../../../models/security/ediscoveryCaseSettings';
import { MicrosoftGraphSecurityResetToDefaultRequestBuilder } from './microsoftGraphSecurityResetToDefault/microsoftGraphSecurityResetToDefaultRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SettingsRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SettingsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SettingsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SettingsRequestBuilderGetQueryParameters;
}
export interface SettingsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the settings property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class SettingsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the resetToDefault method.
     */
    get microsoftGraphSecurityResetToDefault(): MicrosoftGraphSecurityResetToDefaultRequestBuilder;
    /**
     * Instantiates a new SettingsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property settings for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SettingsRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an ediscoveryCaseSettings object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCaseSettings
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycasesettings-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SettingsRequestBuilderGetRequestConfiguration | undefined): Promise<EdiscoveryCaseSettings | undefined>;
    /**
     * Update the properties of an ediscoveryCaseSettings object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCaseSettings
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycasesettings-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EdiscoveryCaseSettings, requestConfiguration?: SettingsRequestBuilderPatchRequestConfiguration | undefined): Promise<EdiscoveryCaseSettings | undefined>;
    /**
     * Delete navigation property settings for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SettingsRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an ediscoveryCaseSettings object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SettingsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of an ediscoveryCaseSettings object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EdiscoveryCaseSettings, requestConfiguration?: SettingsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a settingsRequestBuilder
     */
    withUrl(rawUrl: string): SettingsRequestBuilder;
}
