import { type HostComponent } from '../../../../models/security/hostComponent';
import { HostRequestBuilder } from './host/hostRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface HostComponentItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface HostComponentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface HostComponentItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: HostComponentItemRequestBuilderGetQueryParameters;
}
export interface HostComponentItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the hostComponents property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostComponentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the host property of the microsoft.graph.security.hostComponent entity.
     */
    get host(): HostRequestBuilder;
    /**
     * Instantiates a new HostComponentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property hostComponents for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: HostComponentItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a hostComponent object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostComponent
     * @see {@link https://learn.microsoft.com/graph/api/security-hostcomponent-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: HostComponentItemRequestBuilderGetRequestConfiguration | undefined): Promise<HostComponent | undefined>;
    /**
     * Update the navigation property hostComponents in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostComponent
     */
    patch(body: HostComponent, requestConfiguration?: HostComponentItemRequestBuilderPatchRequestConfiguration | undefined): Promise<HostComponent | undefined>;
    /**
     * Delete navigation property hostComponents for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: HostComponentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a hostComponent object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: HostComponentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property hostComponents in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: HostComponent, requestConfiguration?: HostComponentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a HostComponentItemRequestBuilder
     */
    withUrl(rawUrl: string): HostComponentItemRequestBuilder;
}
