import { type HostSslCertificate } from '../../../../models/security/hostSslCertificate';
import { HostRequestBuilder } from './host/hostRequestBuilder';
import { SslCertificateRequestBuilder } from './sslCertificate/sslCertificateRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface HostSslCertificateItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface HostSslCertificateItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface HostSslCertificateItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: HostSslCertificateItemRequestBuilderGetQueryParameters;
}
export interface HostSslCertificateItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the hostSslCertificates property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostSslCertificateItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the host property of the microsoft.graph.security.hostSslCertificate entity.
     */
    get host(): HostRequestBuilder;
    /**
     * Provides operations to manage the sslCertificate property of the microsoft.graph.security.hostSslCertificate entity.
     */
    get sslCertificate(): SslCertificateRequestBuilder;
    /**
     * Instantiates a new HostSslCertificateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property hostSslCertificates for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: HostSslCertificateItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of a hostSslCertificate object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostSslCertificate
     * @see {@link https://learn.microsoft.com/graph/api/security-hostsslcertificate-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: HostSslCertificateItemRequestBuilderGetRequestConfiguration | undefined): Promise<HostSslCertificate | undefined>;
    /**
     * Update the navigation property hostSslCertificates in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostSslCertificate
     */
    patch(body: HostSslCertificate, requestConfiguration?: HostSslCertificateItemRequestBuilderPatchRequestConfiguration | undefined): Promise<HostSslCertificate | undefined>;
    /**
     * Delete navigation property hostSslCertificates for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: HostSslCertificateItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of a hostSslCertificate object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: HostSslCertificateItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property hostSslCertificates in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: HostSslCertificate, requestConfiguration?: HostSslCertificateItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a HostSslCertificateItemRequestBuilder
     */
    withUrl(rawUrl: string): HostSslCertificateItemRequestBuilder;
}
