import { type HostPairCollectionResponse } from '../../../../../models/security/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { HostPairItemRequestBuilder } from './item/hostPairItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ParentHostPairsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ParentHostPairsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ParentHostPairsRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the parentHostPairs property of the microsoft.graph.security.host entity.
 */
export declare class ParentHostPairsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the parentHostPairs property of the microsoft.graph.security.host entity.
     * @param hostPairId The unique identifier of hostPair
     * @returns a HostPairItemRequestBuilder
     */
    byHostPairId(hostPairId: string): HostPairItemRequestBuilder;
    /**
     * Instantiates a new ParentHostPairsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of hostPair resources associated with a host, where that host is the *child* and has an incoming pairing with a *parent*. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPairCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-host-list-parenthostpairs?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ParentHostPairsRequestBuilderGetRequestConfiguration | undefined): Promise<HostPairCollectionResponse | undefined>;
    /**
     * Get the list of hostPair resources associated with a host, where that host is the *child* and has an incoming pairing with a *parent*. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ParentHostPairsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a parentHostPairsRequestBuilder
     */
    withUrl(rawUrl: string): ParentHostPairsRequestBuilder;
}
