import { type HostReputation } from '../../../../../models/security/hostReputation';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ReputationRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ReputationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ReputationRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ReputationRequestBuilderGetQueryParameters;
}
export interface ReputationRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the reputation property of the microsoft.graph.security.host entity.
 */
export declare class ReputationRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ReputationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property reputation for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ReputationRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of a hostReputation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostReputation
     * @see {@link https://learn.microsoft.com/graph/api/security-host-get-reputation?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ReputationRequestBuilderGetRequestConfiguration | undefined): Promise<HostReputation | undefined>;
    /**
     * Update the navigation property reputation in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostReputation
     */
    patch(body: HostReputation, requestConfiguration?: ReputationRequestBuilderPatchRequestConfiguration | undefined): Promise<HostReputation | undefined>;
    /**
     * Delete navigation property reputation for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ReputationRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of a hostReputation object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ReputationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property reputation in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: HostReputation, requestConfiguration?: ReputationRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a reputationRequestBuilder
     */
    withUrl(rawUrl: string): ReputationRequestBuilder;
}
