import { type HostSslCertificateCollectionResponse } from '../../../../../models/security/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { HostSslCertificateItemRequestBuilder } from './item/hostSslCertificateItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SslCertificatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface SslCertificatesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SslCertificatesRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the sslCertificates property of the microsoft.graph.security.host entity.
 */
export declare class SslCertificatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the sslCertificates property of the microsoft.graph.security.host entity.
     * @param hostSslCertificateId The unique identifier of hostSslCertificate
     * @returns a HostSslCertificateItemRequestBuilder
     */
    byHostSslCertificateId(hostSslCertificateId: string): HostSslCertificateItemRequestBuilder;
    /**
     * Instantiates a new SslCertificatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of hostSslCertificate objects from the host navigation property. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostSslCertificateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-host-list-sslcertificates?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SslCertificatesRequestBuilderGetRequestConfiguration | undefined): Promise<HostSslCertificateCollectionResponse | undefined>;
    /**
     * Get a list of hostSslCertificate objects from the host navigation property. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SslCertificatesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sslCertificatesRequestBuilder
     */
    withUrl(rawUrl: string): SslCertificatesRequestBuilder;
}
