import { type ThreatIntelligence } from '../../models/security/threatIntelligence';
import { ArticleIndicatorsRequestBuilder } from './articleIndicators/articleIndicatorsRequestBuilder';
import { ArticlesRequestBuilder } from './articles/articlesRequestBuilder';
import { HostComponentsRequestBuilder } from './hostComponents/hostComponentsRequestBuilder';
import { HostCookiesRequestBuilder } from './hostCookies/hostCookiesRequestBuilder';
import { HostPairsRequestBuilder } from './hostPairs/hostPairsRequestBuilder';
import { HostsRequestBuilder } from './hosts/hostsRequestBuilder';
import { HostSslCertificatesRequestBuilder } from './hostSslCertificates/hostSslCertificatesRequestBuilder';
import { HostTrackersRequestBuilder } from './hostTrackers/hostTrackersRequestBuilder';
import { IntelligenceProfileIndicatorsRequestBuilder } from './intelligenceProfileIndicators/intelligenceProfileIndicatorsRequestBuilder';
import { IntelProfilesRequestBuilder } from './intelProfiles/intelProfilesRequestBuilder';
import { PassiveDnsRecordsRequestBuilder } from './passiveDnsRecords/passiveDnsRecordsRequestBuilder';
import { SslCertificatesRequestBuilder } from './sslCertificates/sslCertificatesRequestBuilder';
import { SubdomainsRequestBuilder } from './subdomains/subdomainsRequestBuilder';
import { VulnerabilitiesRequestBuilder } from './vulnerabilities/vulnerabilitiesRequestBuilder';
import { WhoisHistoryRecordsRequestBuilder } from './whoisHistoryRecords/whoisHistoryRecordsRequestBuilder';
import { WhoisRecordsRequestBuilder } from './whoisRecords/whoisRecordsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ThreatIntelligenceRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ThreatIntelligenceRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ThreatIntelligenceRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ThreatIntelligenceRequestBuilderGetQueryParameters;
}
export interface ThreatIntelligenceRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the threatIntelligence property of the microsoft.graph.security entity.
 */
export declare class ThreatIntelligenceRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the articleIndicators property of the microsoft.graph.security.threatIntelligence entity.
     */
    get articleIndicators(): ArticleIndicatorsRequestBuilder;
    /**
     * Provides operations to manage the articles property of the microsoft.graph.security.threatIntelligence entity.
     */
    get articles(): ArticlesRequestBuilder;
    /**
     * Provides operations to manage the hostComponents property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hostComponents(): HostComponentsRequestBuilder;
    /**
     * Provides operations to manage the hostCookies property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hostCookies(): HostCookiesRequestBuilder;
    /**
     * Provides operations to manage the hostPairs property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hostPairs(): HostPairsRequestBuilder;
    /**
     * Provides operations to manage the hosts property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hosts(): HostsRequestBuilder;
    /**
     * Provides operations to manage the hostSslCertificates property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hostSslCertificates(): HostSslCertificatesRequestBuilder;
    /**
     * Provides operations to manage the hostTrackers property of the microsoft.graph.security.threatIntelligence entity.
     */
    get hostTrackers(): HostTrackersRequestBuilder;
    /**
     * Provides operations to manage the intelligenceProfileIndicators property of the microsoft.graph.security.threatIntelligence entity.
     */
    get intelligenceProfileIndicators(): IntelligenceProfileIndicatorsRequestBuilder;
    /**
     * Provides operations to manage the intelProfiles property of the microsoft.graph.security.threatIntelligence entity.
     */
    get intelProfiles(): IntelProfilesRequestBuilder;
    /**
     * Provides operations to manage the passiveDnsRecords property of the microsoft.graph.security.threatIntelligence entity.
     */
    get passiveDnsRecords(): PassiveDnsRecordsRequestBuilder;
    /**
     * Provides operations to manage the sslCertificates property of the microsoft.graph.security.threatIntelligence entity.
     */
    get sslCertificates(): SslCertificatesRequestBuilder;
    /**
     * Provides operations to manage the subdomains property of the microsoft.graph.security.threatIntelligence entity.
     */
    get subdomains(): SubdomainsRequestBuilder;
    /**
     * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
     */
    get vulnerabilities(): VulnerabilitiesRequestBuilder;
    /**
     * Provides operations to manage the whoisHistoryRecords property of the microsoft.graph.security.threatIntelligence entity.
     */
    get whoisHistoryRecords(): WhoisHistoryRecordsRequestBuilder;
    /**
     * Provides operations to manage the whoisRecords property of the microsoft.graph.security.threatIntelligence entity.
     */
    get whoisRecords(): WhoisRecordsRequestBuilder;
    /**
     * Instantiates a new ThreatIntelligenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property threatIntelligence for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ThreatIntelligenceRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get threatIntelligence from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatIntelligence
     */
    get(requestConfiguration?: ThreatIntelligenceRequestBuilderGetRequestConfiguration | undefined): Promise<ThreatIntelligence | undefined>;
    /**
     * Update the navigation property threatIntelligence in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatIntelligence
     */
    patch(body: ThreatIntelligence, requestConfiguration?: ThreatIntelligenceRequestBuilderPatchRequestConfiguration | undefined): Promise<ThreatIntelligence | undefined>;
    /**
     * Delete navigation property threatIntelligence for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ThreatIntelligenceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get threatIntelligence from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ThreatIntelligenceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property threatIntelligence in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ThreatIntelligence, requestConfiguration?: ThreatIntelligenceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a threatIntelligenceRequestBuilder
     */
    withUrl(rawUrl: string): ThreatIntelligenceRequestBuilder;
}
