import { type WhoisRecord } from '../../../../models/security/whoisRecord';
import { HistoryRequestBuilder } from './history/historyRequestBuilder';
import { HostRequestBuilder } from './host/hostRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface WhoisRecordItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface WhoisRecordItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface WhoisRecordItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: WhoisRecordItemRequestBuilderGetQueryParameters;
}
export interface WhoisRecordItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the whoisRecords property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class WhoisRecordItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the history property of the microsoft.graph.security.whoisRecord entity.
     */
    get history(): HistoryRequestBuilder;
    /**
     * Provides operations to manage the host property of the microsoft.graph.security.whoisBaseRecord entity.
     */
    get host(): HostRequestBuilder;
    /**
     * Instantiates a new WhoisRecordItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property whoisRecords for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: WhoisRecordItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the specified whoisRecord resource.  Specify the desired whoisRecord in one of the following two ways:- Identify a host and get its current whoisRecord. - Specify an id value to get the corresponding whoisRecord. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WhoisRecord
     * @see {@link https://learn.microsoft.com/graph/api/security-whoisrecord-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: WhoisRecordItemRequestBuilderGetRequestConfiguration | undefined): Promise<WhoisRecord | undefined>;
    /**
     * Update the navigation property whoisRecords in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WhoisRecord
     */
    patch(body: WhoisRecord, requestConfiguration?: WhoisRecordItemRequestBuilderPatchRequestConfiguration | undefined): Promise<WhoisRecord | undefined>;
    /**
     * Delete navigation property whoisRecords for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: WhoisRecordItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the specified whoisRecord resource.  Specify the desired whoisRecord in one of the following two ways:- Identify a host and get its current whoisRecord. - Specify an id value to get the corresponding whoisRecord. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: WhoisRecordItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property whoisRecords in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WhoisRecord, requestConfiguration?: WhoisRecordItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WhoisRecordItemRequestBuilder
     */
    withUrl(rawUrl: string): WhoisRecordItemRequestBuilder;
}
