import { type RetentionEventCollectionResponse } from '../../../models/security/';
import { type RetentionEvent } from '../../../models/security/retentionEvent';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { RetentionEventItemRequestBuilder } from './item/retentionEventItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface RetentionEventsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface RetentionEventsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: RetentionEventsRequestBuilderGetQueryParameters;
}
export interface RetentionEventsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the retentionEvents property of the microsoft.graph.security.triggersRoot entity.
 */
export declare class RetentionEventsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the retentionEvents property of the microsoft.graph.security.triggersRoot entity.
     * @param retentionEventId The unique identifier of retentionEvent
     * @returns a RetentionEventItemRequestBuilder
     */
    byRetentionEventId(retentionEventId: string): RetentionEventItemRequestBuilder;
    /**
     * Instantiates a new RetentionEventsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the retentionEvent objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RetentionEventCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-retentionevent-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RetentionEventsRequestBuilderGetRequestConfiguration | undefined): Promise<RetentionEventCollectionResponse | undefined>;
    /**
     * Create a new retentionEvent object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RetentionEvent
     * @see {@link https://learn.microsoft.com/graph/api/security-retentionevent-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: RetentionEvent, requestConfiguration?: RetentionEventsRequestBuilderPostRequestConfiguration | undefined): Promise<RetentionEvent | undefined>;
    /**
     * Get a list of the retentionEvent objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RetentionEventsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new retentionEvent object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RetentionEvent, requestConfiguration?: RetentionEventsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a retentionEventsRequestBuilder
     */
    withUrl(rawUrl: string): RetentionEventsRequestBuilder;
}
