import { type TargetDeviceGroupCollectionResponse } from '../../../../models/';
import { type TargetDeviceGroup } from '../../../../models/targetDeviceGroup';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TargetDeviceGroupItemRequestBuilder } from './item/targetDeviceGroupItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TargetDeviceGroupsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TargetDeviceGroupsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TargetDeviceGroupsRequestBuilderGetQueryParameters;
}
export interface TargetDeviceGroupsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the targetDeviceGroups property of the microsoft.graph.remoteDesktopSecurityConfiguration entity.
 */
export declare class TargetDeviceGroupsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the targetDeviceGroups property of the microsoft.graph.remoteDesktopSecurityConfiguration entity.
     * @param targetDeviceGroupId The unique identifier of targetDeviceGroup
     * @returns a TargetDeviceGroupItemRequestBuilder
     */
    byTargetDeviceGroupId(targetDeviceGroupId: string): TargetDeviceGroupItemRequestBuilder;
    /**
     * Instantiates a new TargetDeviceGroupsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get targetDeviceGroups from servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TargetDeviceGroupCollectionResponse
     */
    get(requestConfiguration?: TargetDeviceGroupsRequestBuilderGetRequestConfiguration | undefined): Promise<TargetDeviceGroupCollectionResponse | undefined>;
    /**
     * Create new navigation property to targetDeviceGroups for servicePrincipals
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TargetDeviceGroup
     */
    post(body: TargetDeviceGroup, requestConfiguration?: TargetDeviceGroupsRequestBuilderPostRequestConfiguration | undefined): Promise<TargetDeviceGroup | undefined>;
    /**
     * Get targetDeviceGroups from servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TargetDeviceGroupsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to targetDeviceGroups for servicePrincipals
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TargetDeviceGroup, requestConfiguration?: TargetDeviceGroupsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a targetDeviceGroupsRequestBuilder
     */
    withUrl(rawUrl: string): TargetDeviceGroupsRequestBuilder;
}
