import { type AcquireAccessTokenPostRequestBody } from './acquireAccessTokenPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AcquireAccessTokenRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the acquireAccessToken method.
 */
export declare class AcquireAccessTokenRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AcquireAccessTokenRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Acquire an OAuth access token to authorize the Microsoft Entra provisioning service to provision users into an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronization-acquireaccesstoken?view=graph-rest-1.0|Find more info here}
     */
    post(body: AcquireAccessTokenPostRequestBody, requestConfiguration?: AcquireAccessTokenRequestBuilderPostRequestConfiguration | undefined): Promise<void>;
    /**
     * Acquire an OAuth access token to authorize the Microsoft Entra provisioning service to provision users into an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AcquireAccessTokenPostRequestBody, requestConfiguration?: AcquireAccessTokenRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a acquireAccessTokenRequestBuilder
     */
    withUrl(rawUrl: string): AcquireAccessTokenRequestBuilder;
}
