import { type SynchronizationSchema } from '../../../../../../models/synchronizationSchema';
import { DirectoriesRequestBuilder } from './directories/directoriesRequestBuilder';
import { FilterOperatorsRequestBuilder } from './filterOperators/filterOperatorsRequestBuilder';
import { FunctionsRequestBuilder } from './functions/functionsRequestBuilder';
import { ParseExpressionRequestBuilder } from './parseExpression/parseExpressionRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SchemaRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SchemaRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SchemaRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SchemaRequestBuilderGetQueryParameters;
}
export interface SchemaRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the schema property of the microsoft.graph.synchronizationTemplate entity.
 */
export declare class SchemaRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the directories property of the microsoft.graph.synchronizationSchema entity.
     */
    get directories(): DirectoriesRequestBuilder;
    /**
     * Provides operations to call the filterOperators method.
     */
    get filterOperators(): FilterOperatorsRequestBuilder;
    /**
     * Provides operations to call the functions method.
     */
    get functions(): FunctionsRequestBuilder;
    /**
     * Provides operations to call the parseExpression method.
     */
    get parseExpression(): ParseExpressionRequestBuilder;
    /**
     * Instantiates a new SchemaRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property schema for servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SchemaRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Default synchronization schema for the jobs based on this template.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationSchema
     */
    get(requestConfiguration?: SchemaRequestBuilderGetRequestConfiguration | undefined): Promise<SynchronizationSchema | undefined>;
    /**
     * Update the navigation property schema in servicePrincipals
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationSchema
     */
    patch(body: SynchronizationSchema, requestConfiguration?: SchemaRequestBuilderPatchRequestConfiguration | undefined): Promise<SynchronizationSchema | undefined>;
    /**
     * Delete navigation property schema for servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SchemaRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Default synchronization schema for the jobs based on this template.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SchemaRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property schema in servicePrincipals
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SynchronizationSchema, requestConfiguration?: SchemaRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a schemaRequestBuilder
     */
    withUrl(rawUrl: string): SchemaRequestBuilder;
}
