import { type ServicePrincipal } from '../models/servicePrincipal';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ServicePrincipalsWithAppIdRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ServicePrincipalsWithAppIdRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ServicePrincipalsWithAppIdRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ServicePrincipalsWithAppIdRequestBuilderGetQueryParameters;
}
export interface ServicePrincipalsWithAppIdRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of servicePrincipal entities.
 */
export declare class ServicePrincipalsWithAppIdRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ServicePrincipalsWithAppIdRequestBuilder and sets the default values.
     * @param appId Alternate key of servicePrincipal
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter, appId?: string | undefined);
    /**
     * Delete a servicePrincipal object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/serviceprincipal-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a servicePrincipal object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServicePrincipal
     * @see {@link https://learn.microsoft.com/graph/api/serviceprincipal-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderGetRequestConfiguration | undefined): Promise<ServicePrincipal | undefined>;
    /**
     * Update entity in servicePrincipals by appId
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServicePrincipal
     */
    patch(body: ServicePrincipal, requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderPatchRequestConfiguration | undefined): Promise<ServicePrincipal | undefined>;
    /**
     * Delete a servicePrincipal object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a servicePrincipal object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in servicePrincipals by appId
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ServicePrincipal, requestConfiguration?: ServicePrincipalsWithAppIdRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a servicePrincipalsWithAppIdRequestBuilder
     */
    withUrl(rawUrl: string): ServicePrincipalsWithAppIdRequestBuilder;
}
