import { type GrantPostRequestBody } from './grantPostRequestBody';
import { type GrantPostResponse } from './grantPostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface GrantRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the grant method.
 */
export declare class GrantRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new GrantRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Grant users access to a link represented by a permission][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GrantPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/permission-grant?view=graph-rest-1.0|Find more info here}
     */
    post(body: GrantPostRequestBody, requestConfiguration?: GrantRequestBuilderPostRequestConfiguration | undefined): Promise<GrantPostResponse | undefined>;
    /**
     * Grant users access to a link represented by a permission][]. This API is available in the following [national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: GrantPostRequestBody, requestConfiguration?: GrantRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a grantRequestBuilder
     */
    withUrl(rawUrl: string): GrantRequestBuilder;
}
