import { type Permission } from '../../../models/permission';
import { GrantRequestBuilder } from './grant/grantRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PermissionRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PermissionRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PermissionRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PermissionRequestBuilderGetQueryParameters;
}
export interface PermissionRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the permission property of the microsoft.graph.sharedDriveItem entity.
 */
export declare class PermissionRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the grant method.
     */
    get grant(): GrantRequestBuilder;
    /**
     * Instantiates a new PermissionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property permission for shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PermissionRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Used to access the permission representing the underlying sharing link
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Permission
     */
    get(requestConfiguration?: PermissionRequestBuilderGetRequestConfiguration | undefined): Promise<Permission | undefined>;
    /**
     * Update the navigation property permission in shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Permission
     */
    patch(body: Permission, requestConfiguration?: PermissionRequestBuilderPatchRequestConfiguration | undefined): Promise<Permission | undefined>;
    /**
     * Delete navigation property permission for shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PermissionRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Used to access the permission representing the underlying sharing link
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PermissionRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property permission in shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Permission, requestConfiguration?: PermissionRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a permissionRequestBuilder
     */
    withUrl(rawUrl: string): PermissionRequestBuilder;
}
