import { type SharedDriveItemCollectionResponse } from '../models/';
import { type SharedDriveItem } from '../models/sharedDriveItem';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { SharedDriveItemItemRequestBuilder } from './item/sharedDriveItemItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SharesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface SharesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SharesRequestBuilderGetQueryParameters;
}
export interface SharesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of sharedDriveItem entities.
 */
export declare class SharesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of sharedDriveItem entities.
     * @param sharedDriveItemId The unique identifier of sharedDriveItem
     * @returns a SharedDriveItemItemRequestBuilder
     */
    bySharedDriveItemId(sharedDriveItemId: string): SharedDriveItemItemRequestBuilder;
    /**
     * Instantiates a new SharesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Access a shared DriveItem or a collection of shared items by using a shareId or sharing URL. To use a sharing URL with this API, your app needs to transform the URL into a sharing token. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedDriveItemCollectionResponse
     */
    get(requestConfiguration?: SharesRequestBuilderGetRequestConfiguration | undefined): Promise<SharedDriveItemCollectionResponse | undefined>;
    /**
     * Add new entity to shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedDriveItem
     */
    post(body: SharedDriveItem, requestConfiguration?: SharesRequestBuilderPostRequestConfiguration | undefined): Promise<SharedDriveItem | undefined>;
    /**
     * Access a shared DriveItem or a collection of shared items by using a shareId or sharing URL. To use a sharing URL with this API, your app needs to transform the URL into a sharing token. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SharesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SharedDriveItem, requestConfiguration?: SharesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sharesRequestBuilder
     */
    withUrl(rawUrl: string): SharesRequestBuilder;
}
