import { type OnenotePage } from '../../../../../../../../../models/onenotePage';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { CopyToSectionRequestBuilder } from './copyToSection/copyToSectionRequestBuilder';
import { OnenotePatchContentRequestBuilder } from './onenotePatchContent/onenotePatchContentRequestBuilder';
import { ParentNotebookRequestBuilder } from './parentNotebook/parentNotebookRequestBuilder';
import { ParentSectionRequestBuilder } from './parentSection/parentSectionRequestBuilder';
import { PreviewRequestBuilder } from './preview/previewRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OnenotePageItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface OnenotePageItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface OnenotePageItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OnenotePageItemRequestBuilderGetQueryParameters;
}
export interface OnenotePageItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the pages property of the microsoft.graph.onenoteSection entity.
 */
export declare class OnenotePageItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the site entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Provides operations to call the copyToSection method.
     */
    get copyToSection(): CopyToSectionRequestBuilder;
    /**
     * Provides operations to call the onenotePatchContent method.
     */
    get onenotePatchContent(): OnenotePatchContentRequestBuilder;
    /**
     * Provides operations to manage the parentNotebook property of the microsoft.graph.onenotePage entity.
     */
    get parentNotebook(): ParentNotebookRequestBuilder;
    /**
     * Provides operations to manage the parentSection property of the microsoft.graph.onenotePage entity.
     */
    get parentSection(): ParentSectionRequestBuilder;
    /**
     * Provides operations to call the preview method.
     */
    get preview(): PreviewRequestBuilder;
    /**
     * Instantiates a new OnenotePageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property pages for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: OnenotePageItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The collection of pages in the section.  Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenotePage
     */
    get(requestConfiguration?: OnenotePageItemRequestBuilderGetRequestConfiguration | undefined): Promise<OnenotePage | undefined>;
    /**
     * Update the navigation property pages in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenotePage
     */
    patch(body: OnenotePage, requestConfiguration?: OnenotePageItemRequestBuilderPatchRequestConfiguration | undefined): Promise<OnenotePage | undefined>;
    /**
     * Delete navigation property pages for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: OnenotePageItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The collection of pages in the section.  Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OnenotePageItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property pages in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OnenotePage, requestConfiguration?: OnenotePageItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OnenotePageItemRequestBuilder
     */
    withUrl(rawUrl: string): OnenotePageItemRequestBuilder;
}
