import { type Onenote } from '../../../models/onenote';
import { NotebooksRequestBuilder } from './notebooks/notebooksRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PagesRequestBuilder } from './pages/pagesRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { SectionGroupsRequestBuilder } from './sectionGroups/sectionGroupsRequestBuilder';
import { SectionsRequestBuilder } from './sections/sectionsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OnenoteRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface OnenoteRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface OnenoteRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OnenoteRequestBuilderGetQueryParameters;
}
export interface OnenoteRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the onenote property of the microsoft.graph.site entity.
 */
export declare class OnenoteRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.
     */
    get notebooks(): NotebooksRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.onenote entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the pages property of the microsoft.graph.onenote entity.
     */
    get pages(): PagesRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.onenote entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to manage the sectionGroups property of the microsoft.graph.onenote entity.
     */
    get sectionGroups(): SectionGroupsRequestBuilder;
    /**
     * Provides operations to manage the sections property of the microsoft.graph.onenote entity.
     */
    get sections(): SectionsRequestBuilder;
    /**
     * Instantiates a new OnenoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property onenote for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: OnenoteRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Onenote
     */
    get(requestConfiguration?: OnenoteRequestBuilderGetRequestConfiguration | undefined): Promise<Onenote | undefined>;
    /**
     * Update the navigation property onenote in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Onenote
     */
    patch(body: Onenote, requestConfiguration?: OnenoteRequestBuilderPatchRequestConfiguration | undefined): Promise<Onenote | undefined>;
    /**
     * Delete navigation property onenote for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: OnenoteRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OnenoteRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property onenote in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Onenote, requestConfiguration?: OnenoteRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a onenoteRequestBuilder
     */
    withUrl(rawUrl: string): OnenoteRequestBuilder;
}
