import { type BookingBusiness } from '../../../models/bookingBusiness';
import { AppointmentsRequestBuilder } from './appointments/appointmentsRequestBuilder';
import { CalendarViewRequestBuilder } from './calendarView/calendarViewRequestBuilder';
import { CustomersRequestBuilder } from './customers/customersRequestBuilder';
import { CustomQuestionsRequestBuilder } from './customQuestions/customQuestionsRequestBuilder';
import { GetStaffAvailabilityRequestBuilder } from './getStaffAvailability/getStaffAvailabilityRequestBuilder';
import { PublishRequestBuilder } from './publish/publishRequestBuilder';
import { ServicesRequestBuilder } from './services/servicesRequestBuilder';
import { StaffMembersRequestBuilder } from './staffMembers/staffMembersRequestBuilder';
import { UnpublishRequestBuilder } from './unpublish/unpublishRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface BookingBusinessItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface BookingBusinessItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface BookingBusinessItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: BookingBusinessItemRequestBuilderGetQueryParameters;
}
export interface BookingBusinessItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the bookingBusinesses property of the microsoft.graph.solutionsRoot entity.
 */
export declare class BookingBusinessItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the appointments property of the microsoft.graph.bookingBusiness entity.
     */
    get appointments(): AppointmentsRequestBuilder;
    /**
     * Provides operations to manage the calendarView property of the microsoft.graph.bookingBusiness entity.
     */
    get calendarView(): CalendarViewRequestBuilder;
    /**
     * Provides operations to manage the customers property of the microsoft.graph.bookingBusiness entity.
     */
    get customers(): CustomersRequestBuilder;
    /**
     * Provides operations to manage the customQuestions property of the microsoft.graph.bookingBusiness entity.
     */
    get customQuestions(): CustomQuestionsRequestBuilder;
    /**
     * Provides operations to call the getStaffAvailability method.
     */
    get getStaffAvailability(): GetStaffAvailabilityRequestBuilder;
    /**
     * Provides operations to call the publish method.
     */
    get publish(): PublishRequestBuilder;
    /**
     * Provides operations to manage the services property of the microsoft.graph.bookingBusiness entity.
     */
    get services(): ServicesRequestBuilder;
    /**
     * Provides operations to manage the staffMembers property of the microsoft.graph.bookingBusiness entity.
     */
    get staffMembers(): StaffMembersRequestBuilder;
    /**
     * Provides operations to call the unpublish method.
     */
    get unpublish(): UnpublishRequestBuilder;
    /**
     * Instantiates a new BookingBusinessItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: BookingBusinessItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingBusiness
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: BookingBusinessItemRequestBuilderGetRequestConfiguration | undefined): Promise<BookingBusiness | undefined>;
    /**
     * Update the properties of a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingBusiness
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: BookingBusiness, requestConfiguration?: BookingBusinessItemRequestBuilderPatchRequestConfiguration | undefined): Promise<BookingBusiness | undefined>;
    /**
     * Delete a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: BookingBusinessItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: BookingBusinessItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a bookingBusiness object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: BookingBusiness, requestConfiguration?: BookingBusinessItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a BookingBusinessItemRequestBuilder
     */
    withUrl(rawUrl: string): BookingBusinessItemRequestBuilder;
}
