import { type BookingCustomerBase } from '../../../../../models/bookingCustomerBase';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface BookingCustomerBaseItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface BookingCustomerBaseItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface BookingCustomerBaseItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: BookingCustomerBaseItemRequestBuilderGetQueryParameters;
}
export interface BookingCustomerBaseItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the customers property of the microsoft.graph.bookingBusiness entity.
 */
export declare class BookingCustomerBaseItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new BookingCustomerBaseItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the specified bookingCustomer object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/bookingcustomer-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: BookingCustomerBaseItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of a bookingCustomer object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingCustomerBase
     * @see {@link https://learn.microsoft.com/graph/api/bookingcustomer-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: BookingCustomerBaseItemRequestBuilderGetRequestConfiguration | undefined): Promise<BookingCustomerBase | undefined>;
    /**
     * Update the properties of a bookingCustomer object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingCustomerBase
     * @see {@link https://learn.microsoft.com/graph/api/bookingcustomer-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: BookingCustomerBase, requestConfiguration?: BookingCustomerBaseItemRequestBuilderPatchRequestConfiguration | undefined): Promise<BookingCustomerBase | undefined>;
    /**
     * Delete the specified bookingCustomer object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: BookingCustomerBaseItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of a bookingCustomer object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: BookingCustomerBaseItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a bookingCustomer object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: BookingCustomerBase, requestConfiguration?: BookingCustomerBaseItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a BookingCustomerBaseItemRequestBuilder
     */
    withUrl(rawUrl: string): BookingCustomerBaseItemRequestBuilder;
}
