import { type BookingCurrencyCollectionResponse } from '../../models/';
import { type BookingCurrency } from '../../models/bookingCurrency';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { BookingCurrencyItemRequestBuilder } from './item/bookingCurrencyItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface BookingCurrenciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface BookingCurrenciesRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: BookingCurrenciesRequestBuilderGetQueryParameters;
}
export interface BookingCurrenciesRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the bookingCurrencies property of the microsoft.graph.solutionsRoot entity.
 */
export declare class BookingCurrenciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the bookingCurrencies property of the microsoft.graph.solutionsRoot entity.
     * @param bookingCurrencyId The unique identifier of bookingCurrency
     * @returns a BookingCurrencyItemRequestBuilder
     */
    byBookingCurrencyId(bookingCurrencyId: string): BookingCurrencyItemRequestBuilder;
    /**
     * Instantiates a new BookingCurrenciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of bookingCurrency objects available to a Microsoft Bookings business. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingCurrencyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/bookingcurrency-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: BookingCurrenciesRequestBuilderGetRequestConfiguration | undefined): Promise<BookingCurrencyCollectionResponse | undefined>;
    /**
     * Create new navigation property to bookingCurrencies for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingCurrency
     */
    post(body: BookingCurrency, requestConfiguration?: BookingCurrenciesRequestBuilderPostRequestConfiguration | undefined): Promise<BookingCurrency | undefined>;
    /**
     * Get a list of bookingCurrency objects available to a Microsoft Bookings business. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: BookingCurrenciesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to bookingCurrencies for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: BookingCurrency, requestConfiguration?: BookingCurrenciesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a bookingCurrenciesRequestBuilder
     */
    withUrl(rawUrl: string): BookingCurrenciesRequestBuilder;
}
