import { type SubscribedSku } from '../../models/subscribedSku';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SubscribedSkuItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface SubscribedSkuItemRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface SubscribedSkuItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: SubscribedSkuItemRequestBuilderGetQueryParameters;
}
export interface SubscribedSkuItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the collection of subscribedSku entities.
 */
export declare class SubscribedSkuItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new SubscribedSkuItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: SubscribedSkuItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get a specific commercial subscription that an organization has acquired. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubscribedSku
     * @see {@link https://learn.microsoft.com/graph/api/subscribedsku-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: SubscribedSkuItemRequestBuilderGetRequestConfiguration | undefined): Promise<SubscribedSku | undefined>;
    /**
     * Update entity in subscribedSkus
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubscribedSku
     */
    patch(body: SubscribedSku, requestConfiguration?: SubscribedSkuItemRequestBuilderPatchRequestConfiguration | undefined): Promise<SubscribedSku | undefined>;
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: SubscribedSkuItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get a specific commercial subscription that an organization has acquired. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: SubscribedSkuItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in subscribedSkus
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SubscribedSku, requestConfiguration?: SubscribedSkuItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SubscribedSkuItemRequestBuilder
     */
    withUrl(rawUrl: string): SubscribedSkuItemRequestBuilder;
}
