import { type DriveItem } from '../../../../../models/';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface FilesFolderRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface FilesFolderRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: FilesFolderRequestBuilderGetQueryParameters;
}
/**
 * Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
 */
export declare class FilesFolderRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the team entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Instantiates a new FilesFolderRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the metadata for the location where the files of a channel are stored.  This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItem
     * @see {@link https://learn.microsoft.com/graph/api/channel-get-filesfolder?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: FilesFolderRequestBuilderGetRequestConfiguration | undefined): Promise<DriveItem | undefined>;
    /**
     * Get the metadata for the location where the files of a channel are stored.  This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: FilesFolderRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filesFolderRequestBuilder
     */
    withUrl(rawUrl: string): FilesFolderRequestBuilder;
}
