import { type Schedule } from '../../../models/schedule';
import { OfferShiftRequestsRequestBuilder } from './offerShiftRequests/offerShiftRequestsRequestBuilder';
import { OpenShiftChangeRequestsRequestBuilder } from './openShiftChangeRequests/openShiftChangeRequestsRequestBuilder';
import { OpenShiftsRequestBuilder } from './openShifts/openShiftsRequestBuilder';
import { SchedulingGroupsRequestBuilder } from './schedulingGroups/schedulingGroupsRequestBuilder';
import { ShareRequestBuilder } from './share/shareRequestBuilder';
import { ShiftsRequestBuilder } from './shifts/shiftsRequestBuilder';
import { SwapShiftsChangeRequestsRequestBuilder } from './swapShiftsChangeRequests/swapShiftsChangeRequestsRequestBuilder';
import { TimeOffReasonsRequestBuilder } from './timeOffReasons/timeOffReasonsRequestBuilder';
import { TimeOffRequestsRequestBuilder } from './timeOffRequests/timeOffRequestsRequestBuilder';
import { TimesOffRequestBuilder } from './timesOff/timesOffRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ScheduleRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ScheduleRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ScheduleRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ScheduleRequestBuilderGetQueryParameters;
}
export interface ScheduleRequestBuilderPutRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the schedule property of the microsoft.graph.team entity.
 */
export declare class ScheduleRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the offerShiftRequests property of the microsoft.graph.schedule entity.
     */
    get offerShiftRequests(): OfferShiftRequestsRequestBuilder;
    /**
     * Provides operations to manage the openShiftChangeRequests property of the microsoft.graph.schedule entity.
     */
    get openShiftChangeRequests(): OpenShiftChangeRequestsRequestBuilder;
    /**
     * Provides operations to manage the openShifts property of the microsoft.graph.schedule entity.
     */
    get openShifts(): OpenShiftsRequestBuilder;
    /**
     * Provides operations to manage the schedulingGroups property of the microsoft.graph.schedule entity.
     */
    get schedulingGroups(): SchedulingGroupsRequestBuilder;
    /**
     * Provides operations to call the share method.
     */
    get share(): ShareRequestBuilder;
    /**
     * Provides operations to manage the shifts property of the microsoft.graph.schedule entity.
     */
    get shifts(): ShiftsRequestBuilder;
    /**
     * Provides operations to manage the swapShiftsChangeRequests property of the microsoft.graph.schedule entity.
     */
    get swapShiftsChangeRequests(): SwapShiftsChangeRequestsRequestBuilder;
    /**
     * Provides operations to manage the timeOffReasons property of the microsoft.graph.schedule entity.
     */
    get timeOffReasons(): TimeOffReasonsRequestBuilder;
    /**
     * Provides operations to manage the timeOffRequests property of the microsoft.graph.schedule entity.
     */
    get timeOffRequests(): TimeOffRequestsRequestBuilder;
    /**
     * Provides operations to manage the timesOff property of the microsoft.graph.schedule entity.
     */
    get timesOff(): TimesOffRequestBuilder;
    /**
     * Instantiates a new ScheduleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property schedule for teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ScheduleRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a schedule object. The schedule creation process conforms to the One API guideline for resource based long running operations (RELO).When clients use the PUT method, if the schedule is provisioned, the operation updates the schedule; otherwise, the operation starts the schedule provisioning process in the background. During schedule provisioning, clients can use the GET method to get the schedule and look at the provisionStatus property for the current state of the provisioning. If the provisioning failed, clients can get additional information from the provisionStatusCode property. Clients can also inspect the configuration of the schedule. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Schedule
     * @see {@link https://learn.microsoft.com/graph/api/schedule-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ScheduleRequestBuilderGetRequestConfiguration | undefined): Promise<Schedule | undefined>;
    /**
     * Update the navigation property schedule in teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Schedule
     */
    put(body: Schedule, requestConfiguration?: ScheduleRequestBuilderPutRequestConfiguration | undefined): Promise<Schedule | undefined>;
    /**
     * Delete navigation property schedule for teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ScheduleRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a schedule object. The schedule creation process conforms to the One API guideline for resource based long running operations (RELO).When clients use the PUT method, if the schedule is provisioned, the operation updates the schedule; otherwise, the operation starts the schedule provisioning process in the background. During schedule provisioning, clients can use the GET method to get the schedule and look at the provisionStatus property for the current state of the provisioning. If the provisioning failed, clients can get additional information from the provisionStatusCode property. Clients can also inspect the configuration of the schedule. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ScheduleRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property schedule in teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPutRequestInformation(body: Schedule, requestConfiguration?: ScheduleRequestBuilderPutRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a scheduleRequestBuilder
     */
    withUrl(rawUrl: string): ScheduleRequestBuilder;
}
