import { type Channel } from '../../../../../models/channel';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder } from './doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName/doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder';
import { FilesFolderRequestBuilder } from './filesFolder/filesFolderRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { ProvisionEmailRequestBuilder } from './provisionEmail/provisionEmailRequestBuilder';
import { RemoveEmailRequestBuilder } from './removeEmail/removeEmailRequestBuilder';
import { SharedWithTeamsRequestBuilder } from './sharedWithTeams/sharedWithTeamsRequestBuilder';
import { TabsRequestBuilder } from './tabs/tabsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ChannelItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface ChannelItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface ChannelItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ChannelItemRequestBuilderGetQueryParameters;
}
export interface ChannelItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the channels property of the microsoft.graph.deletedTeam entity.
 */
export declare class ChannelItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the completeMigration method.
     */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /**
     * Provides operations to call the doesUserHaveAccess method.
     */
    get doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName(): DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder;
    /**
     * Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
     */
    get filesFolder(): FilesFolderRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.channel entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the messages property of the microsoft.graph.channel entity.
     */
    get messages(): MessagesRequestBuilder;
    /**
     * Provides operations to call the provisionEmail method.
     */
    get provisionEmail(): ProvisionEmailRequestBuilder;
    /**
     * Provides operations to call the removeEmail method.
     */
    get removeEmail(): RemoveEmailRequestBuilder;
    /**
     * Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
     */
    get sharedWithTeams(): SharedWithTeamsRequestBuilder;
    /**
     * Provides operations to manage the tabs property of the microsoft.graph.channel entity.
     */
    get tabs(): TabsRequestBuilder;
    /**
     * Instantiates a new ChannelItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property channels for teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: ChannelItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The channels that are either shared with this deleted team or created in this deleted team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     */
    get(requestConfiguration?: ChannelItemRequestBuilderGetRequestConfiguration | undefined): Promise<Channel | undefined>;
    /**
     * Update the navigation property channels in teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     */
    patch(body: Channel, requestConfiguration?: ChannelItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Channel | undefined>;
    /**
     * Delete navigation property channels for teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: ChannelItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The channels that are either shared with this deleted team or created in this deleted team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ChannelItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property channels in teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Channel, requestConfiguration?: ChannelItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ChannelItemRequestBuilder
     */
    withUrl(rawUrl: string): ChannelItemRequestBuilder;
}
