import { type TeamsAppSettings } from '../../models/teamsAppSettings';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TeamsAppSettingsRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface TeamsAppSettingsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface TeamsAppSettingsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TeamsAppSettingsRequestBuilderGetQueryParameters;
}
export interface TeamsAppSettingsRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the teamsAppSettings property of the microsoft.graph.teamwork entity.
 */
export declare class TeamsAppSettingsRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new TeamsAppSettingsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property teamsAppSettings for teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: TeamsAppSettingsRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the tenant-wide teamsAppSettings for all Teams apps in the tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsAppSettings
     * @see {@link https://learn.microsoft.com/graph/api/teamsappsettings-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TeamsAppSettingsRequestBuilderGetRequestConfiguration | undefined): Promise<TeamsAppSettings | undefined>;
    /**
     * Update the tenant-wide teamsAppSettings for all Teams apps in the tenant. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsAppSettings
     * @see {@link https://learn.microsoft.com/graph/api/teamsappsettings-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: TeamsAppSettings, requestConfiguration?: TeamsAppSettingsRequestBuilderPatchRequestConfiguration | undefined): Promise<TeamsAppSettings | undefined>;
    /**
     * Delete navigation property teamsAppSettings for teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: TeamsAppSettingsRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the tenant-wide teamsAppSettings for all Teams apps in the tenant. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TeamsAppSettingsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the tenant-wide teamsAppSettings for all Teams apps in the tenant. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: TeamsAppSettings, requestConfiguration?: TeamsAppSettingsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a teamsAppSettingsRequestBuilder
     */
    withUrl(rawUrl: string): TeamsAppSettingsRequestBuilder;
}
