import { type DelegatedAdminRelationshipRequestCollectionResponse } from '../../../../models/';
import { type DelegatedAdminRelationshipRequest } from '../../../../models/delegatedAdminRelationshipRequest';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DelegatedAdminRelationshipRequestItemRequestBuilder } from './item/delegatedAdminRelationshipRequestItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface RequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface RequestsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: RequestsRequestBuilderGetQueryParameters;
}
export interface RequestsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the requests property of the microsoft.graph.delegatedAdminRelationship entity.
 */
export declare class RequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the requests property of the microsoft.graph.delegatedAdminRelationship entity.
     * @param delegatedAdminRelationshipRequestId The unique identifier of delegatedAdminRelationshipRequest
     * @returns a DelegatedAdminRelationshipRequestItemRequestBuilder
     */
    byDelegatedAdminRelationshipRequestId(delegatedAdminRelationshipRequestId: string): DelegatedAdminRelationshipRequestItemRequestBuilder;
    /**
     * Instantiates a new RequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the delegatedAdminRelationshipRequest objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminRelationshipRequestCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/delegatedadminrelationship-list-requests?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestsRequestBuilderGetRequestConfiguration | undefined): Promise<DelegatedAdminRelationshipRequestCollectionResponse | undefined>;
    /**
     * Create a new delegatedAdminRelationshipRequest object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminRelationshipRequest
     * @see {@link https://learn.microsoft.com/graph/api/delegatedadminrelationship-post-requests?view=graph-rest-1.0|Find more info here}
     */
    post(body: DelegatedAdminRelationshipRequest, requestConfiguration?: RequestsRequestBuilderPostRequestConfiguration | undefined): Promise<DelegatedAdminRelationshipRequest | undefined>;
    /**
     * Get a list of the delegatedAdminRelationshipRequest objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new delegatedAdminRelationshipRequest object. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DelegatedAdminRelationshipRequest, requestConfiguration?: RequestsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a requestsRequestBuilder
     */
    withUrl(rawUrl: string): RequestsRequestBuilder;
}
