"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TenantRelationshipsRequestBuilder = void 0;
const oDataError_1 = require("../models/oDataErrors/oDataError");
const tenantRelationship_1 = require("../models/tenantRelationship");
const delegatedAdminCustomersRequestBuilder_1 = require("./delegatedAdminCustomers/delegatedAdminCustomersRequestBuilder");
const delegatedAdminRelationshipsRequestBuilder_1 = require("./delegatedAdminRelationships/delegatedAdminRelationshipsRequestBuilder");
const findTenantInformationByDomainNameWithDomainNameRequestBuilder_1 = require("./findTenantInformationByDomainNameWithDomainName/findTenantInformationByDomainNameWithDomainNameRequestBuilder");
const findTenantInformationByTenantIdWithTenantIdRequestBuilder_1 = require("./findTenantInformationByTenantIdWithTenantId/findTenantInformationByTenantIdWithTenantIdRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the tenantRelationship singleton.
 */
class TenantRelationshipsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the delegatedAdminCustomers property of the microsoft.graph.tenantRelationship entity.
     */
    get delegatedAdminCustomers() {
        return new delegatedAdminCustomersRequestBuilder_1.DelegatedAdminCustomersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the delegatedAdminRelationships property of the microsoft.graph.tenantRelationship entity.
     */
    get delegatedAdminRelationships() {
        return new delegatedAdminRelationshipsRequestBuilder_1.DelegatedAdminRelationshipsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new TenantRelationshipsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/tenantRelationships{?%24select,%24expand}");
    }
    ;
    /**
     * Provides operations to call the findTenantInformationByDomainName method.
     * @param domainName Usage: domainName='{domainName}'
     * @returns a findTenantInformationByDomainNameWithDomainNameRequestBuilder
     */
    findTenantInformationByDomainNameWithDomainName(domainName) {
        if (!domainName)
            throw new Error("domainName cannot be undefined");
        return new findTenantInformationByDomainNameWithDomainNameRequestBuilder_1.FindTenantInformationByDomainNameWithDomainNameRequestBuilder(this.pathParameters, this.requestAdapter, domainName);
    }
    ;
    /**
     * Provides operations to call the findTenantInformationByTenantId method.
     * @param tenantId Usage: tenantId='{tenantId}'
     * @returns a findTenantInformationByTenantIdWithTenantIdRequestBuilder
     */
    findTenantInformationByTenantIdWithTenantId(tenantId) {
        if (!tenantId)
            throw new Error("tenantId cannot be undefined");
        return new findTenantInformationByTenantIdWithTenantIdRequestBuilder_1.FindTenantInformationByTenantIdWithTenantIdRequestBuilder(this.pathParameters, this.requestAdapter, tenantId);
    }
    ;
    /**
     * Get tenantRelationships
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantRelationship
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, tenantRelationship_1.createTenantRelationshipFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantRelationship
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, tenantRelationship_1.createTenantRelationshipFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get tenantRelationships
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Update tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, tenantRelationship_1.serializeTenantRelationship);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tenantRelationshipsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new TenantRelationshipsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.TenantRelationshipsRequestBuilder = TenantRelationshipsRequestBuilder;
// tslint:enable
// eslint-enable
