import { type Authentication } from '../../../models/authentication';
import { EmailMethodsRequestBuilder } from './emailMethods/emailMethodsRequestBuilder';
import { Fido2MethodsRequestBuilder } from './fido2Methods/fido2MethodsRequestBuilder';
import { MethodsRequestBuilder } from './methods/methodsRequestBuilder';
import { MicrosoftAuthenticatorMethodsRequestBuilder } from './microsoftAuthenticatorMethods/microsoftAuthenticatorMethodsRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PasswordMethodsRequestBuilder } from './passwordMethods/passwordMethodsRequestBuilder';
import { PhoneMethodsRequestBuilder } from './phoneMethods/phoneMethodsRequestBuilder';
import { SoftwareOathMethodsRequestBuilder } from './softwareOathMethods/softwareOathMethodsRequestBuilder';
import { TemporaryAccessPassMethodsRequestBuilder } from './temporaryAccessPassMethods/temporaryAccessPassMethodsRequestBuilder';
import { WindowsHelloForBusinessMethodsRequestBuilder } from './windowsHelloForBusinessMethods/windowsHelloForBusinessMethodsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AuthenticationRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface AuthenticationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface AuthenticationRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AuthenticationRequestBuilderGetQueryParameters;
}
export interface AuthenticationRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the authentication property of the microsoft.graph.user entity.
 */
export declare class AuthenticationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the emailMethods property of the microsoft.graph.authentication entity.
     */
    get emailMethods(): EmailMethodsRequestBuilder;
    /**
     * Provides operations to manage the fido2Methods property of the microsoft.graph.authentication entity.
     */
    get fido2Methods(): Fido2MethodsRequestBuilder;
    /**
     * Provides operations to manage the methods property of the microsoft.graph.authentication entity.
     */
    get methods(): MethodsRequestBuilder;
    /**
     * Provides operations to manage the microsoftAuthenticatorMethods property of the microsoft.graph.authentication entity.
     */
    get microsoftAuthenticatorMethods(): MicrosoftAuthenticatorMethodsRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.authentication entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the passwordMethods property of the microsoft.graph.authentication entity.
     */
    get passwordMethods(): PasswordMethodsRequestBuilder;
    /**
     * Provides operations to manage the phoneMethods property of the microsoft.graph.authentication entity.
     */
    get phoneMethods(): PhoneMethodsRequestBuilder;
    /**
     * Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.
     */
    get softwareOathMethods(): SoftwareOathMethodsRequestBuilder;
    /**
     * Provides operations to manage the temporaryAccessPassMethods property of the microsoft.graph.authentication entity.
     */
    get temporaryAccessPassMethods(): TemporaryAccessPassMethodsRequestBuilder;
    /**
     * Provides operations to manage the windowsHelloForBusinessMethods property of the microsoft.graph.authentication entity.
     */
    get windowsHelloForBusinessMethods(): WindowsHelloForBusinessMethodsRequestBuilder;
    /**
     * Instantiates a new AuthenticationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authentication for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: AuthenticationRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * The authentication methods that are supported for the user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Authentication
     */
    get(requestConfiguration?: AuthenticationRequestBuilderGetRequestConfiguration | undefined): Promise<Authentication | undefined>;
    /**
     * Update the navigation property authentication in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Authentication
     */
    patch(body: Authentication, requestConfiguration?: AuthenticationRequestBuilderPatchRequestConfiguration | undefined): Promise<Authentication | undefined>;
    /**
     * Delete navigation property authentication for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: AuthenticationRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The authentication methods that are supported for the user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AuthenticationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property authentication in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Authentication, requestConfiguration?: AuthenticationRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a authenticationRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationRequestBuilder;
}
