import { type ChatMessageInfo } from '../../../../../models/chatMessageInfo';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface LastMessagePreviewRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface LastMessagePreviewRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface LastMessagePreviewRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: LastMessagePreviewRequestBuilderGetQueryParameters;
}
export interface LastMessagePreviewRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the lastMessagePreview property of the microsoft.graph.chat entity.
 */
export declare class LastMessagePreviewRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new LastMessagePreviewRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property lastMessagePreview for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: LastMessagePreviewRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Preview of the last message sent in the chat. Null if no messages have been sent in the chat. Currently, only the list chats operation supports this property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessageInfo
     */
    get(requestConfiguration?: LastMessagePreviewRequestBuilderGetRequestConfiguration | undefined): Promise<ChatMessageInfo | undefined>;
    /**
     * Update the navigation property lastMessagePreview in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessageInfo
     */
    patch(body: ChatMessageInfo, requestConfiguration?: LastMessagePreviewRequestBuilderPatchRequestConfiguration | undefined): Promise<ChatMessageInfo | undefined>;
    /**
     * Delete navigation property lastMessagePreview for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: LastMessagePreviewRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Preview of the last message sent in the chat. Null if no messages have been sent in the chat. Currently, only the list chats operation supports this property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: LastMessagePreviewRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property lastMessagePreview in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ChatMessageInfo, requestConfiguration?: LastMessagePreviewRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a lastMessagePreviewRequestBuilder
     */
    withUrl(rawUrl: string): LastMessagePreviewRequestBuilder;
}
