import { type Channel } from '../../../../../models/channel';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder } from './doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName/doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder';
import { FilesFolderRequestBuilder } from './filesFolder/filesFolderRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { ProvisionEmailRequestBuilder } from './provisionEmail/provisionEmailRequestBuilder';
import { RemoveEmailRequestBuilder } from './removeEmail/removeEmailRequestBuilder';
import { SharedWithTeamsRequestBuilder } from './sharedWithTeams/sharedWithTeamsRequestBuilder';
import { TabsRequestBuilder } from './tabs/tabsRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PrimaryChannelRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PrimaryChannelRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PrimaryChannelRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PrimaryChannelRequestBuilderGetQueryParameters;
}
export interface PrimaryChannelRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.
 */
export declare class PrimaryChannelRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the completeMigration method.
     */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /**
     * Provides operations to call the doesUserHaveAccess method.
     */
    get doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName(): DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder;
    /**
     * Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
     */
    get filesFolder(): FilesFolderRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.channel entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the messages property of the microsoft.graph.channel entity.
     */
    get messages(): MessagesRequestBuilder;
    /**
     * Provides operations to call the provisionEmail method.
     */
    get provisionEmail(): ProvisionEmailRequestBuilder;
    /**
     * Provides operations to call the removeEmail method.
     */
    get removeEmail(): RemoveEmailRequestBuilder;
    /**
     * Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
     */
    get sharedWithTeams(): SharedWithTeamsRequestBuilder;
    /**
     * Provides operations to manage the tabs property of the microsoft.graph.channel entity.
     */
    get tabs(): TabsRequestBuilder;
    /**
     * Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property primaryChannel for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PrimaryChannelRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the default channel, General, of a team. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     * @see {@link https://learn.microsoft.com/graph/api/team-get-primarychannel?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: PrimaryChannelRequestBuilderGetRequestConfiguration | undefined): Promise<Channel | undefined>;
    /**
     * Update the navigation property primaryChannel in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     */
    patch(body: Channel, requestConfiguration?: PrimaryChannelRequestBuilderPatchRequestConfiguration | undefined): Promise<Channel | undefined>;
    /**
     * Delete navigation property primaryChannel for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PrimaryChannelRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the default channel, General, of a team. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PrimaryChannelRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property primaryChannel in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Channel, requestConfiguration?: PrimaryChannelRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a primaryChannelRequestBuilder
     */
    withUrl(rawUrl: string): PrimaryChannelRequestBuilder;
}
