import { type TimeOffReasonCollectionResponse } from '../../../../../../models/';
import { type TimeOffReason } from '../../../../../../models/timeOffReason';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TimeOffReasonItemRequestBuilder } from './item/timeOffReasonItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TimeOffReasonsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TimeOffReasonsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TimeOffReasonsRequestBuilderGetQueryParameters;
}
export interface TimeOffReasonsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the timeOffReasons property of the microsoft.graph.schedule entity.
 */
export declare class TimeOffReasonsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the timeOffReasons property of the microsoft.graph.schedule entity.
     * @param timeOffReasonId The unique identifier of timeOffReason
     * @returns a TimeOffReasonItemRequestBuilder
     */
    byTimeOffReasonId(timeOffReasonId: string): TimeOffReasonItemRequestBuilder;
    /**
     * Instantiates a new TimeOffReasonsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of timeOffReasons in a schedule. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOffReasonCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/schedule-list-timeoffreasons?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TimeOffReasonsRequestBuilderGetRequestConfiguration | undefined): Promise<TimeOffReasonCollectionResponse | undefined>;
    /**
     * Create a new timeOffReason. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOffReason
     * @see {@link https://learn.microsoft.com/graph/api/schedule-post-timeoffreasons?view=graph-rest-1.0|Find more info here}
     */
    post(body: TimeOffReason, requestConfiguration?: TimeOffReasonsRequestBuilderPostRequestConfiguration | undefined): Promise<TimeOffReason | undefined>;
    /**
     * Get the list of timeOffReasons in a schedule. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TimeOffReasonsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new timeOffReason. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TimeOffReason, requestConfiguration?: TimeOffReasonsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a timeOffReasonsRequestBuilder
     */
    withUrl(rawUrl: string): TimeOffReasonsRequestBuilder;
}
