import { type TeamworkTagMemberCollectionResponse } from '../../../../../../../models/';
import { type TeamworkTagMember } from '../../../../../../../models/teamworkTagMember';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TeamworkTagMemberItemRequestBuilder } from './item/teamworkTagMemberItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface MembersRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface MembersRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: MembersRequestBuilderGetQueryParameters;
}
export interface MembersRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the members property of the microsoft.graph.teamworkTag entity.
 */
export declare class MembersRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.teamworkTag entity.
     * @param teamworkTagMemberId The unique identifier of teamworkTagMember
     * @returns a TeamworkTagMemberItemRequestBuilder
     */
    byTeamworkTagMemberId(teamworkTagMemberId: string): TeamworkTagMemberItemRequestBuilder;
    /**
     * Instantiates a new MembersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the members of a standard tag in a team and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkTagMemberCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/teamworktagmember-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: MembersRequestBuilderGetRequestConfiguration | undefined): Promise<TeamworkTagMemberCollectionResponse | undefined>;
    /**
     * Create a new teamworkTagMember object in a team. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkTagMember
     * @see {@link https://learn.microsoft.com/graph/api/teamworktagmember-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: TeamworkTagMember, requestConfiguration?: MembersRequestBuilderPostRequestConfiguration | undefined): Promise<TeamworkTagMember | undefined>;
    /**
     * Get a list of the members of a standard tag in a team and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: MembersRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new teamworkTagMember object in a team. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TeamworkTagMember, requestConfiguration?: MembersRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a membersRequestBuilder
     */
    withUrl(rawUrl: string): MembersRequestBuilder;
}
