import { type TeamworkTagCollectionResponse } from '../../../../../models/';
import { type TeamworkTag } from '../../../../../models/teamworkTag';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { TeamworkTagItemRequestBuilder } from './item/teamworkTagItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TagsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface TagsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TagsRequestBuilderGetQueryParameters;
}
export interface TagsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the tags property of the microsoft.graph.team entity.
 */
export declare class TagsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the tags property of the microsoft.graph.team entity.
     * @param teamworkTagId The unique identifier of teamworkTag
     * @returns a TeamworkTagItemRequestBuilder
     */
    byTeamworkTagId(teamworkTagId: string): TeamworkTagItemRequestBuilder;
    /**
     * Instantiates a new TagsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the tag objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkTagCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/teamworktag-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: TagsRequestBuilderGetRequestConfiguration | undefined): Promise<TeamworkTagCollectionResponse | undefined>;
    /**
     * Create a standard tag for members in a team. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamworkTag
     * @see {@link https://learn.microsoft.com/graph/api/teamworktag-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: TeamworkTag, requestConfiguration?: TagsRequestBuilderPostRequestConfiguration | undefined): Promise<TeamworkTag | undefined>;
    /**
     * Get a list of the tag objects and their properties. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TagsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a standard tag for members in a team. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TeamworkTag, requestConfiguration?: TagsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tagsRequestBuilder
     */
    withUrl(rawUrl: string): TagsRequestBuilder;
}
