import { type Team } from '../../../../models/team';
import { AllChannelsRequestBuilder } from './allChannels/allChannelsRequestBuilder';
import { ArchiveRequestBuilder } from './archive/archiveRequestBuilder';
import { ChannelsRequestBuilder } from './channels/channelsRequestBuilder';
import { CloneRequestBuilder } from './clone/cloneRequestBuilder';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { IncomingChannelsRequestBuilder } from './incomingChannels/incomingChannelsRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PermissionGrantsRequestBuilder } from './permissionGrants/permissionGrantsRequestBuilder';
import { PhotoRequestBuilder } from './photo/photoRequestBuilder';
import { PrimaryChannelRequestBuilder } from './primaryChannel/primaryChannelRequestBuilder';
import { ScheduleRequestBuilder } from './schedule/scheduleRequestBuilder';
import { SendActivityNotificationRequestBuilder } from './sendActivityNotification/sendActivityNotificationRequestBuilder';
import { TagsRequestBuilder } from './tags/tagsRequestBuilder';
import { TemplateRequestBuilder } from './template/templateRequestBuilder';
import { UnarchiveRequestBuilder } from './unarchive/unarchiveRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface TeamItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface TeamItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface TeamItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: TeamItemRequestBuilderGetQueryParameters;
}
export interface TeamItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the joinedTeams property of the microsoft.graph.user entity.
 */
export declare class TeamItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the allChannels property of the microsoft.graph.team entity.
     */
    get allChannels(): AllChannelsRequestBuilder;
    /**
     * Provides operations to call the archive method.
     */
    get archive(): ArchiveRequestBuilder;
    /**
     * Provides operations to manage the channels property of the microsoft.graph.team entity.
     */
    get channels(): ChannelsRequestBuilder;
    /**
     * Provides operations to call the clone method.
     */
    get clone(): CloneRequestBuilder;
    /**
     * Provides operations to call the completeMigration method.
     */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /**
     * Provides operations to manage the group property of the microsoft.graph.team entity.
     */
    get group(): GroupRequestBuilder;
    /**
     * Provides operations to manage the incomingChannels property of the microsoft.graph.team entity.
     */
    get incomingChannels(): IncomingChannelsRequestBuilder;
    /**
     * Provides operations to manage the installedApps property of the microsoft.graph.team entity.
     */
    get installedApps(): InstalledAppsRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.team entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.team entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the permissionGrants property of the microsoft.graph.team entity.
     */
    get permissionGrants(): PermissionGrantsRequestBuilder;
    /**
     * Provides operations to manage the photo property of the microsoft.graph.team entity.
     */
    get photo(): PhotoRequestBuilder;
    /**
     * Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.
     */
    get primaryChannel(): PrimaryChannelRequestBuilder;
    /**
     * Provides operations to manage the schedule property of the microsoft.graph.team entity.
     */
    get schedule(): ScheduleRequestBuilder;
    /**
     * Provides operations to call the sendActivityNotification method.
     */
    get sendActivityNotification(): SendActivityNotificationRequestBuilder;
    /**
     * Provides operations to manage the tags property of the microsoft.graph.team entity.
     */
    get tags(): TagsRequestBuilder;
    /**
     * Provides operations to manage the template property of the microsoft.graph.team entity.
     */
    get template(): TemplateRequestBuilder;
    /**
     * Provides operations to call the unarchive method.
     */
    get unarchive(): UnarchiveRequestBuilder;
    /**
     * Instantiates a new TeamItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property joinedTeams for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: TeamItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get joinedTeams from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Team
     */
    get(requestConfiguration?: TeamItemRequestBuilderGetRequestConfiguration | undefined): Promise<Team | undefined>;
    /**
     * Update the navigation property joinedTeams in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Team
     */
    patch(body: Team, requestConfiguration?: TeamItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Team | undefined>;
    /**
     * Delete navigation property joinedTeams for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: TeamItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get joinedTeams from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: TeamItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property joinedTeams in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Team, requestConfiguration?: TeamItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a TeamItemRequestBuilder
     */
    withUrl(rawUrl: string): TeamItemRequestBuilder;
}
