import { type OutlookCategory } from '../../../../../models/outlookCategory';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface OutlookCategoryItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface OutlookCategoryItemRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface OutlookCategoryItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: OutlookCategoryItemRequestBuilderGetQueryParameters;
}
export interface OutlookCategoryItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the masterCategories property of the microsoft.graph.outlookUser entity.
 */
export declare class OutlookCategoryItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new OutlookCategoryItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the specified outlookCategory object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: OutlookCategoryItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get the properties and relationships of the specified outlookCategory object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookCategory
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: OutlookCategoryItemRequestBuilderGetRequestConfiguration | undefined): Promise<OutlookCategory | undefined>;
    /**
     * Update the writable property, color, of the specified outlookCategory object. You can't modify the displayName propertyonce you have created the category. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookCategory
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OutlookCategory, requestConfiguration?: OutlookCategoryItemRequestBuilderPatchRequestConfiguration | undefined): Promise<OutlookCategory | undefined>;
    /**
     * Delete the specified outlookCategory object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: OutlookCategoryItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of the specified outlookCategory object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: OutlookCategoryItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the writable property, color, of the specified outlookCategory object. You can't modify the displayName propertyonce you have created the category. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OutlookCategory, requestConfiguration?: OutlookCategoryItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OutlookCategoryItemRequestBuilder
     */
    withUrl(rawUrl: string): OutlookCategoryItemRequestBuilder;
}
