import { type SetPresencePostRequestBody } from './setPresencePostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface SetPresenceRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to call the setPresence method.
 */
export declare class SetPresenceRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new SetPresenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Set the state of a user's presence session as an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/presence-setpresence?view=graph-rest-1.0|Find more info here}
     */
    post(body: SetPresencePostRequestBody, requestConfiguration?: SetPresenceRequestBuilderPostRequestConfiguration | undefined): Promise<void>;
    /**
     * Set the state of a user's presence session as an application. This API is available in the following national cloud deployments.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SetPresencePostRequestBody, requestConfiguration?: SetPresenceRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a setPresenceRequestBuilder
     */
    withUrl(rawUrl: string): SetPresenceRequestBuilder;
}
