import { type AssociatedTeamInfoCollectionResponse } from '../../../../models/';
import { type AssociatedTeamInfo } from '../../../../models/associatedTeamInfo';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { AssociatedTeamInfoItemRequestBuilder } from './item/associatedTeamInfoItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface AssociatedTeamsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface AssociatedTeamsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: AssociatedTeamsRequestBuilderGetQueryParameters;
}
export interface AssociatedTeamsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the associatedTeams property of the microsoft.graph.userTeamwork entity.
 */
export declare class AssociatedTeamsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the associatedTeams property of the microsoft.graph.userTeamwork entity.
     * @param associatedTeamInfoId The unique identifier of associatedTeamInfo
     * @returns a AssociatedTeamInfoItemRequestBuilder
     */
    byAssociatedTeamInfoId(associatedTeamInfoId: string): AssociatedTeamInfoItemRequestBuilder;
    /**
     * Instantiates a new AssociatedTeamsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of teams in Microsoft Teams that a user is associated with.Currently, a user can be associated with a team in two different ways: This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AssociatedTeamInfoCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/associatedteaminfo-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: AssociatedTeamsRequestBuilderGetRequestConfiguration | undefined): Promise<AssociatedTeamInfoCollectionResponse | undefined>;
    /**
     * Create new navigation property to associatedTeams for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AssociatedTeamInfo
     */
    post(body: AssociatedTeamInfo, requestConfiguration?: AssociatedTeamsRequestBuilderPostRequestConfiguration | undefined): Promise<AssociatedTeamInfo | undefined>;
    /**
     * Get the list of teams in Microsoft Teams that a user is associated with.Currently, a user can be associated with a team in two different ways: This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: AssociatedTeamsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to associatedTeams for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AssociatedTeamInfo, requestConfiguration?: AssociatedTeamsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a associatedTeamsRequestBuilder
     */
    withUrl(rawUrl: string): AssociatedTeamsRequestBuilder;
}
