"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DetectedMalwareStateRequestBuilder = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const windowsDeviceMalwareState_1 = require("../../../../../models/windowsDeviceMalwareState");
const windowsDeviceMalwareStateCollectionResponse_1 = require("../../../../../models/windowsDeviceMalwareStateCollectionResponse");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const windowsDeviceMalwareStateItemRequestBuilder_1 = require("./item/windowsDeviceMalwareStateItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the detectedMalwareState property of the microsoft.graph.windowsProtectionState entity.
 */
class DetectedMalwareStateRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the detectedMalwareState property of the microsoft.graph.windowsProtectionState entity.
     * @param windowsDeviceMalwareStateId The unique identifier of windowsDeviceMalwareState
     * @returns a WindowsDeviceMalwareStateItemRequestBuilder
     */
    byWindowsDeviceMalwareStateId(windowsDeviceMalwareStateId) {
        if (!windowsDeviceMalwareStateId)
            throw new Error("windowsDeviceMalwareStateId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["windowsDeviceMalwareState%2Did"] = windowsDeviceMalwareStateId;
        return new windowsDeviceMalwareStateItemRequestBuilder_1.WindowsDeviceMalwareStateItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new DetectedMalwareStateRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/me/managedDevices/{managedDevice%2Did}/windowsProtectionState/detectedMalwareState{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * List properties and relationships of the windowsDeviceMalwareState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareStateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsDeviceMalwareStateCollectionResponse_1.createWindowsDeviceMalwareStateCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create a new windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareState
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-create?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsDeviceMalwareState_1.createWindowsDeviceMalwareStateFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * List properties and relationships of the windowsDeviceMalwareState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Create a new windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, windowsDeviceMalwareState_1.serializeWindowsDeviceMalwareState);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a detectedMalwareStateRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DetectedMalwareStateRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DetectedMalwareStateRequestBuilder = DetectedMalwareStateRequestBuilder;
// tslint:enable
// eslint-enable
