import { type Payload } from '../../../../models/payload';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PayloadItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface PayloadItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface PayloadItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PayloadItemRequestBuilderGetQueryParameters;
}
export interface PayloadItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class PayloadItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PayloadItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property payloads for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: PayloadItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Get payloads from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    get(requestConfiguration?: PayloadItemRequestBuilderGetRequestConfiguration | undefined): Promise<Payload | undefined>;
    /**
     * Update the navigation property payloads in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    patch(body: Payload, requestConfiguration?: PayloadItemRequestBuilderPatchRequestConfiguration | undefined): Promise<Payload | undefined>;
    /**
     * Delete navigation property payloads for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: PayloadItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get payloads from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PayloadItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property payloads in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Payload, requestConfiguration?: PayloadItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PayloadItemRequestBuilder
     */
    withUrl(rawUrl: string): PayloadItemRequestBuilder;
}
