import { type PayloadCollectionResponse } from '../../../models/';
import { type Payload } from '../../../models/payload';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { PayloadItemRequestBuilder } from './item/payloadItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface PayloadsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface PayloadsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: PayloadsRequestBuilderGetQueryParameters;
}
export interface PayloadsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class PayloadsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
     * @param payloadId The unique identifier of payload
     * @returns a PayloadItemRequestBuilder
     */
    byPayloadId(payloadId: string): PayloadItemRequestBuilder;
    /**
     * Instantiates a new PayloadsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get payloads from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PayloadCollectionResponse
     */
    get(requestConfiguration?: PayloadsRequestBuilderGetRequestConfiguration | undefined): Promise<PayloadCollectionResponse | undefined>;
    /**
     * Create new navigation property to payloads for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    post(body: Payload, requestConfiguration?: PayloadsRequestBuilderPostRequestConfiguration | undefined): Promise<Payload | undefined>;
    /**
     * Get payloads from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: PayloadsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to payloads for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Payload, requestConfiguration?: PayloadsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a payloadsRequestBuilder
     */
    withUrl(rawUrl: string): PayloadsRequestBuilder;
}
