"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArticlesRequestBuilder = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const articleCollectionResponse_1 = require("../../../../../models/security/articleCollectionResponse");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const articleItemRequestBuilder_1 = require("./item/articleItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the articles property of the microsoft.graph.security.vulnerability entity.
 */
class ArticlesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the articles property of the microsoft.graph.security.vulnerability entity.
     * @param articleId The unique identifier of article
     * @returns a ArticleItemRequestBuilder
     */
    byArticleId(articleId) {
        if (!articleId)
            throw new Error("articleId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["article%2Did"] = articleId;
        return new articleItemRequestBuilder_1.ArticleItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new ArticlesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/threatIntelligence/vulnerabilities/{vulnerability%2Did}/articles{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Articles related to this vulnerability.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ArticleCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, articleCollectionResponse_1.createArticleCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Articles related to this vulnerability.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        requestInfo.tryAddRequestHeaders("Accept", "application/json;q=1");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a articlesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ArticlesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ArticlesRequestBuilder = ArticlesRequestBuilder;
// tslint:enable
// eslint-enable
