import { type VulnerabilityComponentCollectionResponse } from '../../../../../models/security/';
import { type VulnerabilityComponent } from '../../../../../models/security/vulnerabilityComponent';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { VulnerabilityComponentItemRequestBuilder } from './item/vulnerabilityComponentItemRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface ComponentsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
export interface ComponentsRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: ComponentsRequestBuilderGetQueryParameters;
}
export interface ComponentsRequestBuilderPostRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the components property of the microsoft.graph.security.vulnerability entity.
 */
export declare class ComponentsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the components property of the microsoft.graph.security.vulnerability entity.
     * @param vulnerabilityComponentId The unique identifier of vulnerabilityComponent
     * @returns a VulnerabilityComponentItemRequestBuilder
     */
    byVulnerabilityComponentId(vulnerabilityComponentId: string): VulnerabilityComponentItemRequestBuilder;
    /**
     * Instantiates a new ComponentsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of vulnerabilityComponent objects related to a known vulnerability. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityComponentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-vulnerability-list-components?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: ComponentsRequestBuilderGetRequestConfiguration | undefined): Promise<VulnerabilityComponentCollectionResponse | undefined>;
    /**
     * Create new navigation property to components for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityComponent
     */
    post(body: VulnerabilityComponent, requestConfiguration?: ComponentsRequestBuilderPostRequestConfiguration | undefined): Promise<VulnerabilityComponent | undefined>;
    /**
     * Get a list of vulnerabilityComponent objects related to a known vulnerability. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: ComponentsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to components for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: VulnerabilityComponent, requestConfiguration?: ComponentsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a componentsRequestBuilder
     */
    withUrl(rawUrl: string): ComponentsRequestBuilder;
}
