import { type VulnerabilityComponent } from '../../../../../../models/security/vulnerabilityComponent';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestOption } from '@microsoft/kiota-abstractions';
export interface VulnerabilityComponentItemRequestBuilderDeleteRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
export interface VulnerabilityComponentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
export interface VulnerabilityComponentItemRequestBuilderGetRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
    /**
     * Request query parameters
     */
    queryParameters?: VulnerabilityComponentItemRequestBuilderGetQueryParameters;
}
export interface VulnerabilityComponentItemRequestBuilderPatchRequestConfiguration {
    /**
     * Request headers
     */
    headers?: Record<string, string[]>;
    /**
     * Request options
     */
    options?: RequestOption[];
}
/**
 * Provides operations to manage the components property of the microsoft.graph.security.vulnerability entity.
 */
export declare class VulnerabilityComponentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new VulnerabilityComponentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property components for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: VulnerabilityComponentItemRequestBuilderDeleteRequestConfiguration | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a vulnerabilityComponent object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityComponent
     * @see {@link https://learn.microsoft.com/graph/api/security-vulnerabilitycomponent-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: VulnerabilityComponentItemRequestBuilderGetRequestConfiguration | undefined): Promise<VulnerabilityComponent | undefined>;
    /**
     * Update the navigation property components in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityComponent
     */
    patch(body: VulnerabilityComponent, requestConfiguration?: VulnerabilityComponentItemRequestBuilderPatchRequestConfiguration | undefined): Promise<VulnerabilityComponent | undefined>;
    /**
     * Delete navigation property components for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: VulnerabilityComponentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a vulnerabilityComponent object. This API is available in the following national cloud deployments.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: VulnerabilityComponentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property components in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: VulnerabilityComponent, requestConfiguration?: VulnerabilityComponentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a VulnerabilityComponentItemRequestBuilder
     */
    withUrl(rawUrl: string): VulnerabilityComponentItemRequestBuilder;
}
